/* ============================================================
 * File  : tetrahedron.cpp
 * Author: Stephane Gibault
 * Date  : Sun Feb 4 2007
 * Description :
 *
 * 
 *  (C) 2007 by Stephane Gibault
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#include <QtOpenGL>
#include "tetrahedron.h"
#include <math.h>
#include <QtGui>
#include <cmath>

Tetrahedron::Tetrahedron(QWidget *parent, int parar, int paran)
    : QGLWidget(parent)
{
    qDebug() << "LAUNCH PARAMETERS = " << parar << " " << paran;
    if ( parar == 2 && paran == 2 )
    {
        setFormat(QGLFormat(QGL::DirectRendering | QGL::DepthBuffer | QGL::SampleBuffers));
    }
    else
    {
        if ( parar == 0 && paran == 2 )
        {
            setFormat(QGLFormat(QGL::IndirectRendering | QGL::DepthBuffer | QGL::SampleBuffers));
        }
        else
        {
            if ( parar == 0 && paran == 0 )
            {
                setFormat(QGLFormat(QGL::IndirectRendering | QGL::DepthBuffer));
            }
            else
            {
                setFormat(QGLFormat(QGL::DirectRendering | QGL::DepthBuffer));
            }
        }
    }

    this->setFocusPolicy(Qt::StrongFocus);
    this->setAcceptDrops(true);

    num_select = 0;
    nombre_diapos = 0;
    tool = 0;
    isback = 0;
    is_anaglyph = 0;
    wg_esp_ana = 10;
    scale_factor = 1;
    position_timeline = 10;
    str_trans = "";
    bcle_render = 1;
    is_mblur = 0;
    wg_has_mx = 0;
    wg_has_my = 0;
    wg_has_mz = 0;
    is_fog = 0;
    fog_red = 220;
    fog_green = 220;
    fog_blue = 220;
    wg_niv_qual = 0;
    wg_sav_niv_qual = 0;
    wg_nb_cube = 0;
    is_sample_layer = 0;
    alpha_blend = 0;
    wg_fd_tx = 1.0;
    wg_fd_ty = 1.0;
    lgt_trans = 1;
    lgt_trans_old = 0;

    must_update = 1;

    name_application = "2ManDVD";

    od_red = true;
    od_green = false;
    od_blue = true;

    og_red = false;
    og_green = true;
    og_blue = false;

    wg_path_images = QDir::homePath();
    back_color = "0:0:0";
    ratio_import=1.0;

    /*for(int i = 0; i < 20; i++)
    {
            Particles[i][0] = rand() % 5;
            Particles[i][1] = rand() % 2;
            Particles[i][2] = rand() % 6;
    }*/
    // *** INITIALISATION DES FLAKES ***

    /*int wl_i = 0;
    srand(time(NULL));
    while ( wl_i < 20 )
    {
            Particles[wl_i][0] = (float)(((float)rand() / ((float)RAND_MAX + 1) * 40)-20); //(float)(rand()%(40))-20;
            Particles[wl_i][1] = (float)(((float)rand() / ((float)RAND_MAX + 1) * 40)-20); //(float)(rand()%(40))-32;
            Particles[wl_i][2] = (float)(((float)rand() / ((float)RAND_MAX + 1) * 20)*-1); //(float)(rand()%(20))*-1;
            wl_i++;
    }*/


    load_image = new QAction(tr("Charger des images"), this);
    load_image->setIcon ( QIcon(":/Interface/Interface/open.png") );
    swap_image = new QAction(tr("Changer l'image de la diapositive"), this);
    swap_image->setIcon ( QIcon(":/Interface/Interface/open.png") );
    delete_image = new QAction(tr("Supprimer la diapositive"), this);
    delete_image->setIcon ( QIcon(":/Interface/Interface/trash.png") );
    init_image = new QAction(tr("Reinitialiser les coordonnees de la diapositive"), this);
    init_image->setIcon ( QIcon(":/Interface/Interface/coord.png") );
    edit_image = new QAction(tr("Decouper l'image"), this);
    edit_image->setIcon ( QIcon(":/Interface/Interface/contours.png") );

    load_cray_r = new QAction(tr("Crayon rouge"), this);
    load_cray_r->setIcon ( QIcon(":/Interface/Interface/cr.png") );
    load_cray_v = new QAction(tr("Crayon vert"), this);
    load_cray_v->setIcon ( QIcon(":/Interface/Interface/cv.png") );
    load_cray_b = new QAction(tr("Crayon bleu"), this);
    load_cray_b->setIcon ( QIcon(":/Interface/Interface/cb.png") );
    load_cray_w = new QAction(tr("Crayon blanc"), this);
    load_cray_w->setIcon ( QIcon(":/Interface/Interface/cw.png") );
    load_star_w = new QAction(tr("Homme des neiges"), this);
    load_star_w->setIcon ( QIcon(":/Interface/Interface/snowman.png") );
    load_cube = new QAction(tr("Cube (6 photos)"), this);
    load_cube->setIcon ( QIcon(":/Interface/Interface/cube.png") );
    load_earth = new QAction(tr("Earth"), this);
    load_earth->setIcon ( QIcon(":/Interface/Interface/Earth-icon.png") );
    load_plane = new QAction(tr("Avion en papier"), this);
    load_plane->setIcon ( QIcon(":/Interface/Interface/plane.png") );

    load_text = new QAction(tr("Texte 2D"), this);
    load_text->setIcon ( QIcon(":/Interface/Interface/subtitle.png") );

    custo_mask = new QAction(tr("Custmosiser le mask"), this);
    custo_mask->setIcon ( QIcon(":/Interface/Interface/customize.png") );

    load_cube_change = new QAction(tr("Changer les images du cube (6 photos)"), this);
    load_cube_change->setIcon ( QIcon(":/Interface/Interface/cube.png") );

    gb_image = new QAction(tr("Déplacer / Zoomer"), this);
    gb_image->setIcon ( QIcon(":/Interface/Interface/smile_grab.png") );

    gb_image_x = new QAction(tr("Déplacer axe x"), this);
    gb_image_x->setIcon ( QIcon(":/Interface/Interface/smile_grab.png") );
    gb_image_y = new QAction(tr("Déplacer axe y"), this);
    gb_image_y->setIcon ( QIcon(":/Interface/Interface/smile_grab.png") );

    rl_image = new QAction(tr("Rotation libre"), this);
    rl_image->setIcon ( QIcon(":/Interface/Interface/smile_rx.png") );
    rx_image = new QAction(tr("Tourner axe x"), this);
    rx_image->setIcon ( QIcon(":/Interface/Interface/smile_rx.png") );
    ry_image = new QAction(tr("Tourner axe y"), this);
    ry_image->setIcon ( QIcon(":/Interface/Interface/smile_ry.png") );
    rz_image = new QAction(tr("Tourner axe z"), this);
    rz_image->setIcon ( QIcon(":/Interface/Interface/smile_rz.png") );

    load_back_image = new QAction(tr("Charger une image d'arriere plan"), this);
    load_back_image->setIcon ( QIcon(":/Interface/Interface/btimg.png") );

    connect(load_image, SIGNAL(triggered()), this, SLOT(f_load_image()));
    connect(load_back_image, SIGNAL(triggered()), this, SLOT(f_load_background_1()));
    connect(edit_image, SIGNAL(triggered()), this, SLOT(f_edit_image()));
    connect(load_cray_r, SIGNAL(triggered()), this, SLOT(f_load_cray_r()));
    connect(load_cray_v, SIGNAL(triggered()), this, SLOT(f_load_cray_v()));
    connect(load_cray_b, SIGNAL(triggered()), this, SLOT(f_load_cray_b()));
    connect(load_cray_w, SIGNAL(triggered()), this, SLOT(f_load_cray_w()));
    connect(load_star_w, SIGNAL(triggered()), this, SLOT(f_load_load_star_w()));
    connect(load_cube, SIGNAL(triggered()), this, SLOT(f_load_image_for_cube()));
    connect(load_cube_change, SIGNAL(triggered()), this, SLOT(f_load_image_for_cube_change()));
    connect(load_earth, SIGNAL(triggered()), this, SLOT(f_load_earth()));
    connect(load_plane, SIGNAL(triggered()), this, SLOT(f_load_plane()));
    connect(load_text, SIGNAL(triggered()), this, SLOT(f_load_text()));

    connect(swap_image, SIGNAL(triggered()), this, SLOT(f_swap_image()));
    connect(delete_image, SIGNAL(triggered()), this, SLOT(f_delete_image()));
    connect(init_image, SIGNAL(triggered()), this, SLOT(f_init_image()));

    connect(gb_image, SIGNAL(triggered()), this, SLOT(f_change_tool_grab()));
    connect(gb_image_x, SIGNAL(triggered()), this, SLOT(f_change_tool_grab_x()));
    connect(gb_image_y, SIGNAL(triggered()), this, SLOT(f_change_tool_grab_y()));

    connect(rl_image, SIGNAL(triggered()), this, SLOT(f_change_tool_rotate_l()));
    connect(rx_image, SIGNAL(triggered()), this, SLOT(f_change_tool_rotate_x()));
    connect(ry_image, SIGNAL(triggered()), this, SLOT(f_change_tool_rotate_y()));
    connect(rz_image, SIGNAL(triggered()), this, SLOT(f_change_tool_rotate_z()));

    connect(custo_mask, SIGNAL(triggered()), this, SLOT(f_custo_mask()));

    connect(&proc_ffmpeg, SIGNAL(readyReadStandardOutput()), this, SLOT(f_read_ffmpeg()));
    connect(&proc_ffmpeg, SIGNAL(readyReadStandardError()), this, SLOT(f_read_ffmpeg()));

    f_init_tabcoo();

    // *** TEST FONCTIONS OPENGL ***
    qDebug() << "SYSTEM OVERLAY : " << QGLFormat::hasOpenGLOverlays();
    if ( format().directRendering() == true )
    {
            qDebug() << "DIRECT RENDERING : TRUE";
    }
    else
    {
            qDebug() << "DIRECT RENDERING : FALSE";
    }
    if ( format().doubleBuffer() == true )
    {
            qDebug() << "DOUBLE BUFFERING : TRUE";
    }
    else
    {
            qDebug() << "DOUBLE BUFFERING : FALSE <--> OOPS WARNING <-->";
    }
    if ( format().QGLFormat::hasOpenGL() == true )
    {
            qDebug() << "OPENGL SUPPORT : TRUE";
    }
    else
    {
            qDebug() << "OPENGL SUPPORT : FALSE <--> OOPS WARNING <-->";
    }
    if ( format().sampleBuffers() == true )
    {
            qDebug() << "OPENGL SAMPLE LAYER : TRUE ... YOU COULD USE ANTIALIASING";
            //f_init_gl(1);
    }
    else
    {
            qDebug() << "OPENGL SAMPLE LAYER : FALSE ... YOU COULDN T USE ANTIALIASING";
            //f_init_gl(0);
    }
}

void Tetrahedron::f_custo_mask()
{
    emit s_d_f_custo_mask();
}

// *** MENU CONTEXTUEL ***

void Tetrahedron::contextMenuEvent(QContextMenuEvent *event)
{
    if ( wg_nb_cube == 1 )
    {
        load_cube->setDisabled(true);
    }
    else
    {
        load_cube->setEnabled(true);
    }

    QMenu menu(this);
    if ( num_select == 0 )
    {
        menu.addAction(load_image);
        QMenu *menuobj = menu.addMenu(QIcon(":/Interface/Interface/new1.png"),tr("Insérer un objet"));
        menuobj->addAction(load_cray_r);
        menuobj->addAction(load_cray_v);
        menuobj->addAction(load_cray_b);
        menuobj->addAction(load_cray_w);

        menuobj->addSeparator();
        menuobj->addAction(load_star_w);

        menuobj->addSeparator();
        menuobj->addAction(load_cube);

        menuobj->addSeparator();
        menuobj->addAction(load_earth);

        menuobj->addSeparator();
        menuobj->addAction(load_plane);

        menuobj->addSeparator();
        menuobj->addAction(load_text);

        menu.addSeparator();
        menu.addAction(load_back_image);
    }
    else
    {
        if ( tab_diapo[num_select][0].mid(0,1) == "?" )
        {
            if ( tab_diapo[num_select][0].mid(0,2) == "?6" )
            {
                menu.addAction(load_cube_change);
                menu.addSeparator();
            }

            menu.addAction(delete_image);

            menu.addSeparator();

            QMenu *menualign = menu.addMenu(QIcon(":/Interface/Interface/smile_grab.png"),tr("Manipulation"));

            QMenu *menudep = menualign->addMenu(QIcon(":/Interface/Interface/smile_grab.png"),tr("Déplacement"));
            menudep->addAction(gb_image);
            menudep->addAction(gb_image_x);
            menudep->addAction(gb_image_y);


            menualign->addAction(rl_image);

            menualign->addAction(rx_image);
            menualign->addAction(ry_image);
            menualign->addAction(rz_image);
        }
        else
        {
            menu.addAction(swap_image);
            if ( tab_diapo[num_select][3] != "" )
            {
                menu.addAction(custo_mask);
            }
            menu.addSeparator();
            menu.addAction(load_image);

            QMenu *menuobj = menu.addMenu(QIcon(":/Interface/Interface/new1.png"),tr("Insérer un objet"));
            menuobj->addAction(load_cray_r);
            menuobj->addAction(load_cray_v);
            menuobj->addAction(load_cray_b);
            menuobj->addAction(load_cray_w);

            menuobj->addSeparator();
            menuobj->addAction(load_star_w);

            menuobj->addSeparator();
            menuobj->addAction(load_cube);

            menuobj->addSeparator();
            menuobj->addAction(load_earth);

            menuobj->addSeparator();
            menuobj->addAction(load_plane);

            menuobj->addSeparator();
            menuobj->addAction(load_text);

            menu.addSeparator();
            menu.addAction(delete_image);
            menu.addAction(init_image);

            QMenu *menualign = menu.addMenu(QIcon(":/Interface/Interface/smile_grab.png"),tr("Manipulation"));

            QMenu *menudep = menualign->addMenu(QIcon(":/Interface/Interface/smile_grab.png"),tr("Déplacement"));
            menudep->addAction(gb_image);
            menudep->addAction(gb_image_x);
            menudep->addAction(gb_image_y);


            menualign->addAction(rl_image);

            menualign->addAction(rx_image);
            menualign->addAction(ry_image);
            menualign->addAction(rz_image);

            menu.addSeparator();
            menu.addAction(edit_image);
        }
    }
    menu.exec(event->globalPos());
}

void Tetrahedron::f_load_cube(QString wl_totpath)
{
    if ( nombre_diapos+1 >= 20 )
    {
        QMessageBox::information(this, name_application, tr("Nombre maximum de photos par diapositive atteint"));
        return;
    }

    f_init_coo_one_slide(nombre_diapos+1);

    tab_diapo[nombre_diapos+1][0] = "?6" + wl_totpath;                                // *** NOM DU FICHIER DIAPO ***
    tab_diapo[nombre_diapos+1][1] = QString::number(0);                               // *** LARGEUR DE LA TEXTURE ***
    tab_diapo[nombre_diapos+1][2] = QString::number(0);                               // *** HAUTEUR DE LA TEXTURE ***
    tab_diapo[nombre_diapos+1][3] = "";
    tab_diapo[nombre_diapos+1][4] = "0:0";                                            // *** LUMIERE ET CONTRASTE ***
    tab_diapo[nombre_diapos+1][5] = "1.0";                                            // *** SCALE FACTOR ***
    tab_diapo[nombre_diapos+1][6] = "0";                                              // *** REFLECT ***
    tab_diapo[nombre_diapos+1][7] = "0/0/0/0";                                        // *** CROP ***
    tab_diapo[nombre_diapos+1][8] = "0";                                              // *** ORIENTATION EXIF ***

    tab_coo[nombre_diapos+1][0] = 0.0;      // *** X ***
    tab_coo[nombre_diapos+1][1] = 0.0;      // *** Y ***
    tab_coo[nombre_diapos+1][2] = -12.0;     // *** Z ***
    tab_coo[nombre_diapos+1][3] = 0.0;      // *** FREE ***
    tab_coo[nombre_diapos+1][4] = 0.0;      // *** FREE ***
    tab_coo[nombre_diapos+1][5] = 90.0;     // *** ROTATE X ***
    tab_coo[nombre_diapos+1][6] = 0.0;      // *** ROTATE Y ***
    tab_coo[nombre_diapos+1][7] = 0.0;      // *** ROTATE Z ***
    tab_coo[nombre_diapos+1][8] = 10;       // *** VISIBILITE ***
    tab_coo[nombre_diapos+1][9] = 0.0;      // *** TRANSPARENCE ***
    tab_coo[nombre_diapos+1][10] = 0.0;     // *** BLUR ***
    tab_coo[nombre_diapos+1][11] = -1;      // *** TRANS DIAPO ***

    tab_coo_timeline[nombre_diapos+1][0] = "10:0.0:0.0:-12.0:90.0:0.0:0.0:10:0:0";
    tab_coo_timeline[nombre_diapos+1][1] = "690:0.0:0.0:-12.0:90.0:0.0:0.0:10:0:0";

    nombre_diapos++;
    f_follow_timeline(position_timeline);
    wg_nb_cube = 1;

    emit add_diapo();
}

void Tetrahedron::f_load_earth()
{
    if ( nombre_diapos+1 >= 20 )
    {
        QMessageBox::information(this, name_application, tr("Nombre maximum de photos par diapositive atteint"));
        return;
    }

    f_init_coo_one_slide(nombre_diapos+1);

    tab_diapo[nombre_diapos+1][0] = "?7";                                             // *** NOM DU FICHIER DIAPO ***
    tab_diapo[nombre_diapos+1][1] = QString::number(0);                               // *** LARGEUR DE LA TEXTURE ***
    tab_diapo[nombre_diapos+1][2] = QString::number(0);                               // *** HAUTEUR DE LA TEXTURE ***
    tab_diapo[nombre_diapos+1][3] = "";
    tab_diapo[nombre_diapos+1][4] = "0:0";                                            // *** LUMIERE ET CONTRASTE ***
    tab_diapo[nombre_diapos+1][5] = "1.0";                                            // *** SCALE FACTOR ***
    tab_diapo[nombre_diapos+1][6] = "0";                                              // *** REFLECT ***
    tab_diapo[nombre_diapos+1][7] = "0/0/0/0";                                        // *** CROP ***
    tab_diapo[nombre_diapos+1][8] = "0";                                              // *** ORIENTATION EXIF ***

    tab_coo[nombre_diapos+1][0] = 0.0;      // *** X ***
    tab_coo[nombre_diapos+1][1] = 0.0;      // *** Y ***
    tab_coo[nombre_diapos+1][2] = -12.0;     // *** Z ***
    tab_coo[nombre_diapos+1][3] = 0.0;      // *** FREE ***
    tab_coo[nombre_diapos+1][4] = 0.0;      // *** FREE ***
    tab_coo[nombre_diapos+1][5] = 90.0;     // *** ROTATE X ***
    tab_coo[nombre_diapos+1][6] = 180.0;      // *** ROTATE Y ***
    tab_coo[nombre_diapos+1][7] = 0.0;      // *** ROTATE Z ***
    tab_coo[nombre_diapos+1][8] = 10;       // *** VISIBILITE ***
    tab_coo[nombre_diapos+1][9] = 0.0;      // *** TRANSPARENCE ***
    tab_coo[nombre_diapos+1][10] = 0.0;     // *** BLUR ***
    tab_coo[nombre_diapos+1][11] = -1;      // *** TRANS DIAPO ***

    tab_coo_timeline[nombre_diapos+1][0] = "10:0.0:0.0:-12.0:90.0:180.0:0.0:10:0:0";
    tab_coo_timeline[nombre_diapos+1][1] = "690:0.0:0.0:-12.0:90.0:180.0:0.0:10:0:0";

    nombre_diapos++;
    f_follow_timeline(position_timeline);

    emit add_diapo();
}

void Tetrahedron::f_load_plane()
{
    if ( nombre_diapos+1 >= 20 )
    {
        QMessageBox::information(this, name_application, tr("Nombre maximum de photos par diapositive atteint"));
        return;
    }

    f_init_coo_one_slide(nombre_diapos+1);

    tab_diapo[nombre_diapos+1][0] = "?8";                                             // *** NOM DU FICHIER DIAPO ***
    tab_diapo[nombre_diapos+1][1] = QString::number(0);                               // *** LARGEUR DE LA TEXTURE ***
    tab_diapo[nombre_diapos+1][2] = QString::number(0);                               // *** HAUTEUR DE LA TEXTURE ***
    tab_diapo[nombre_diapos+1][3] = "";
    tab_diapo[nombre_diapos+1][4] = "0:0";                                            // *** LUMIERE ET CONTRASTE ***
    tab_diapo[nombre_diapos+1][5] = "1.0";                                            // *** SCALE FACTOR ***
    tab_diapo[nombre_diapos+1][6] = "0";                                              // *** REFLECT ***
    tab_diapo[nombre_diapos+1][7] = "0/0/0/0";                                        // *** CROP ***
    tab_diapo[nombre_diapos+1][8] = "0";                                              // *** ORIENTATION EXIF ***

    tab_coo[nombre_diapos+1][0] = 0.0;      // *** X ***
    tab_coo[nombre_diapos+1][1] = 0.0;      // *** Y ***
    tab_coo[nombre_diapos+1][2] = -20.0;     // *** Z ***
    tab_coo[nombre_diapos+1][3] = 0.0;      // *** FREE ***
    tab_coo[nombre_diapos+1][4] = 0.0;      // *** FREE ***
    tab_coo[nombre_diapos+1][5] = -40.0;     // *** ROTATE X ***
    tab_coo[nombre_diapos+1][6] = 0.0;      // *** ROTATE Y ***
    tab_coo[nombre_diapos+1][7] = -40.0;      // *** ROTATE Z ***
    tab_coo[nombre_diapos+1][8] = 10;       // *** VISIBILITE ***
    tab_coo[nombre_diapos+1][9] = 0.0;      // *** TRANSPARENCE ***
    tab_coo[nombre_diapos+1][10] = 0.0;     // *** BLUR ***
    tab_coo[nombre_diapos+1][11] = -1;      // *** TRANS DIAPO ***

    tab_coo_timeline[nombre_diapos+1][0] = "10:0.0:0.0:-20.0:-40.0:0.0:-40.0:10:0:0";
    tab_coo_timeline[nombre_diapos+1][1] = "690:0.0:0.0:-20.0:-40.0:0.0:-40.0:10:0:0";

    nombre_diapos++;
    f_follow_timeline(position_timeline);

    emit add_diapo();
}

void Tetrahedron::f_load_object(QListWidgetItem* wname)
{
    if ( nombre_diapos >= 19 )
    {
        return;
    }

    QString wl_myfic = qApp->applicationDirPath()+"/Bibliotheque/Animations/"+ wname->text() + ".gif";
    QImage wl_img_texture;

    if ( wl_img_texture.load(wl_myfic) == true )
    {
        // *** CHARGEMENT DE LA TEXTURE ***
        //glDeleteTextures(1, &texture_diapo[nombre_diapos+1] );
        QImage wl_puis_001(1024,1024,QImage::Format_ARGB32_Premultiplied);

        if ( wl_img_texture.width() > wl_img_texture.height() )
        {
            wl_img_texture = wl_img_texture.scaledToWidth(1024,Qt::SmoothTransformation);
        }
        else
        {
            wl_img_texture = wl_img_texture.scaledToHeight(1024,Qt::SmoothTransformation);
        }

        wl_puis_001 = wl_img_texture.copy ( 0, 0, 1024, 1024); //1024, 1024);

        wg_table_photo[nombre_diapos+1] = wl_puis_001;

        f_init_coo_one_slide(nombre_diapos+1);

        int sens = f_load_exif(wl_myfic);

        tab_diapo[nombre_diapos+1][0] = wl_myfic;                                         // *** NOM DU FICHIER DIAPO ***
        tab_diapo[nombre_diapos+1][1] = QString::number(wl_img_texture.width());          // *** LARGEUR DE LA TEXTURE ***
        tab_diapo[nombre_diapos+1][2] = QString::number(wl_img_texture.height());         // *** HAUTEUR DE LA TEXTURE ***
        tab_diapo[nombre_diapos+1][3] = "";
        tab_diapo[nombre_diapos+1][4] = "0:0";                                            // *** LUMIERE ET CONTRASTE ***
        tab_diapo[nombre_diapos+1][5] = "0.5";                                            // *** SCALE FACTOR ***
        tab_diapo[nombre_diapos+1][6] = "0";                                              // *** REFLECT ***
        tab_diapo[nombre_diapos+1][7] = "0/0/0/0";                                        // *** CROP ***
        tab_diapo[nombre_diapos+1][8] = QString::number(sens);                            // *** ORIENTATION EXIF ***

        tab_coo[nombre_diapos+1][0] = 0.0;      // *** X ***
        tab_coo[nombre_diapos+1][1] = 0.0;      // *** Y ***
        tab_coo[nombre_diapos+1][2] = -3.8;     // *** Z ***
        tab_coo[nombre_diapos+1][3] = 0.0;      // *** FREE ***
        tab_coo[nombre_diapos+1][4] = 0.0;      // *** FREE ***
        tab_coo[nombre_diapos+1][5] = 0.0;      // *** ROTATE X ***
        tab_coo[nombre_diapos+1][6] = 0.0;      // *** ROTATE Y ***
        tab_coo[nombre_diapos+1][7] = 0.0;      // *** ROTATE Z ***
        tab_coo[nombre_diapos+1][8] = 10;       // *** VISIBILITE ***
        tab_coo[nombre_diapos+1][9] = 0.0;      // *** TRANSPARENCE ***
        tab_coo[nombre_diapos+1][10] = 0.0;     // *** BLUR ***
        tab_coo[nombre_diapos+1][11] = -1;      // *** TRANS DIAPO ***

        tab_coo_timeline[nombre_diapos+1][0] = "10:0.0:0.0:-3.8:0.0:0.0:0.0:10:0:0";
        tab_coo_timeline[nombre_diapos+1][1] = "690:0.0:0.0:-3.8:0.0:0.0:0.0:10:0:0";

        QImage f = QGLWidget::convertToGLFormat( wl_puis_001 );

        glDeleteTextures (1,&texture_diapo[nombre_diapos+1]);
        glGenTextures (1,&texture_diapo[nombre_diapos+1]);
        glBindTexture (GL_TEXTURE_2D, texture_diapo[nombre_diapos+1]);

        glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
        glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);

        glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, f.width(), f.height(),
                      0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits());

        tabgif[nombre_diapos+1].setFileName(wl_myfic);
        tabgif[nombre_diapos+1].setCacheMode( QMovie::CacheAll );
        tabgif[nombre_diapos+1].jumpToFrame( 0 );

        nombre_diapos++;
        //num_select = 0;
        f_follow_timeline(position_timeline);

        emit add_diapo();
    }
}

void Tetrahedron::f_load_object_from_drop(QString wname)
{
    if ( nombre_diapos >= 19 )
    {
        return;
    }

    QString wl_myfic = qApp->applicationDirPath()+"/Bibliotheque/Animations/"+ wname + ".gif";
    QImage wl_img_texture;

    if ( wl_img_texture.load(wl_myfic) == true )
    {
        // *** CHARGEMENT DE LA TEXTURE ***
        //glDeleteTextures(1, &texture_diapo[nombre_diapos+1] );
        QImage wl_puis_001(1024,1024,QImage::Format_ARGB32_Premultiplied);

        if ( wl_img_texture.width() > wl_img_texture.height() )
        {
            wl_img_texture = wl_img_texture.scaledToWidth(1024,Qt::SmoothTransformation);
        }
        else
        {
            wl_img_texture = wl_img_texture.scaledToHeight(1024,Qt::SmoothTransformation);
        }

        wl_puis_001 = wl_img_texture.copy ( 0, 0, 1024, 1024); //1024, 1024);

        wg_table_photo[nombre_diapos+1] = wl_puis_001;

        f_init_coo_one_slide(nombre_diapos+1);

        int sens = f_load_exif(wl_myfic);

        tab_diapo[nombre_diapos+1][0] = wl_myfic;                                         // *** NOM DU FICHIER DIAPO ***
        tab_diapo[nombre_diapos+1][1] = QString::number(wl_img_texture.width());          // *** LARGEUR DE LA TEXTURE ***
        tab_diapo[nombre_diapos+1][2] = QString::number(wl_img_texture.height());         // *** HAUTEUR DE LA TEXTURE ***
        tab_diapo[nombre_diapos+1][3] = "";
        tab_diapo[nombre_diapos+1][4] = "0:0";                                            // *** LUMIERE ET CONTRASTE ***
        tab_diapo[nombre_diapos+1][5] = "0.5";                                            // *** SCALE FACTOR ***
        tab_diapo[nombre_diapos+1][6] = "0";                                              // *** REFLECT ***
        tab_diapo[nombre_diapos+1][7] = "0/0/0/0";                                        // *** CROP ***
        tab_diapo[nombre_diapos+1][8] = QString::number(sens);                            // *** ORIENTATION EXIF ***

        tab_coo[nombre_diapos+1][0] = 0.0;      // *** X ***
        tab_coo[nombre_diapos+1][1] = 0.0;      // *** Y ***
        tab_coo[nombre_diapos+1][2] = -3.8;     // *** Z ***
        tab_coo[nombre_diapos+1][3] = 0.0;      // *** FREE ***
        tab_coo[nombre_diapos+1][4] = 0.0;      // *** FREE ***
        tab_coo[nombre_diapos+1][5] = 0.0;      // *** ROTATE X ***
        tab_coo[nombre_diapos+1][6] = 0.0;      // *** ROTATE Y ***
        tab_coo[nombre_diapos+1][7] = 0.0;      // *** ROTATE Z ***
        tab_coo[nombre_diapos+1][8] = 10;       // *** VISIBILITE ***
        tab_coo[nombre_diapos+1][9] = 0.0;      // *** TRANSPARENCE ***
        tab_coo[nombre_diapos+1][10] = 0.0;     // *** BLUR ***
        tab_coo[nombre_diapos+1][11] = -1;      // *** TRANS DIAPO ***

        tab_coo_timeline[nombre_diapos+1][0] = "10:0.0:0.0:-3.8:0.0:0.0:0.0:10:0:0";
        tab_coo_timeline[nombre_diapos+1][1] = "690:0.0:0.0:-3.8:0.0:0.0:0.0:10:0:0";

        QImage f = QGLWidget::convertToGLFormat( wl_puis_001 );

        glDeleteTextures (1,&texture_diapo[nombre_diapos+1]);
        glGenTextures (1,&texture_diapo[nombre_diapos+1]);
        glBindTexture (GL_TEXTURE_2D, texture_diapo[nombre_diapos+1]);

        glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
        glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);

        glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, f.width(), f.height(),
                      0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits());

        tabgif[nombre_diapos+1].setFileName(wl_myfic);
        tabgif[nombre_diapos+1].setCacheMode( QMovie::CacheAll );
        tabgif[nombre_diapos+1].jumpToFrame( 0 );

        nombre_diapos++;
        //num_select = 0;
        f_follow_timeline(position_timeline);

        emit add_diapo();
    }
}

void Tetrahedron::f_load_text()
{
    if ( nombre_diapos+1 >= 20 )
    {
        QMessageBox::information(this, name_application, tr("Nombre maximum de photos par diapositive atteint"));
        return;
    }

    QFont myfont;
    myfont.setPointSize( 1000 );

    int wl_larg_txt;
    int wl_height_txt;

    QFontMetrics fm(myfont);
    wl_larg_txt = fm.width("Text");

    /*if ( wl_larg_txt > 1000 )
    {
        float wl_fratio = (float)1000/(float)wl_larg_txt;
        int wl_fsize = 1000*wl_fratio;

        myfont.setPointSize(wl_fsize);
        QFontMetrics fm2(myfont);
        wl_larg_txt = fm2.width("Text");
        wl_height_txt = wl_fsize;
    }
    else
    {
        wl_larg_txt = fm.width("Text");
        wl_height_txt = 1000;
    }*/

    QString wl_tmps = "Text";

    if ( wl_larg_txt > 1000 )
    {
        float wl_fratio = (float)1000/(float)wl_larg_txt;
        int wl_fsize = 1000*wl_fratio;

        if ( wl_fsize + fm.descent() > 1024 )
        {
            wl_fsize = wl_fsize-fm.descent();
            wl_height_txt = 1024;
        }
        else
        {
            wl_height_txt = wl_fsize+fm.descent();
        }

        myfont.setPointSize(wl_fsize);
        QFontMetrics fm2(myfont);
        wl_larg_txt = fm2.width(wl_tmps);
    }
    else
    {
        wl_larg_txt = fm.width(wl_tmps);
        if ( 1000 + fm.descent() > 1024 )
        {
            myfont.setPointSize(1000-fm.descent());
            wl_height_txt = 1024;
        }
        else
        {
            wl_height_txt = 1024;
            myfont.setPointSize(wl_height_txt);
        }
    }

    QImage wl_img_001(1024,1024,QImage::Format_ARGB32_Premultiplied);
    wl_img_001.fill(0);

    QPainter p;
    p.begin(&wl_img_001);
    p.setFont(myfont);
    p.setPen(QColor(255,255,255));
    p.drawText(QRect(0,0,1024,wl_height_txt), Qt::AlignCenter,"Text");
    p.end();

    QImage f = QGLWidget::convertToGLFormat( wl_img_001 );

    glDeleteTextures (1,&texture_diapo[nombre_diapos+1]);
    glGenTextures (1,&texture_diapo[nombre_diapos+1]);
    glBindTexture (GL_TEXTURE_2D, texture_diapo[nombre_diapos+1]);

    glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
    glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);

    glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, f.width(), f.height(),
                  0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits());

    wg_table_photo[nombre_diapos+1] = wl_img_001;

    /*    QStringList wl_explode = tab_diapo[num_select][0].split("!;!",QString::KeepEmptyParts);

    QFont myfont;
    QPainter p;
    QImage wl_img_001(1024,1024,QImage::Format_ARGB32_Premultiplied);
    wl_img_001.fill(0);

    if ( wl_explode.at(2) != "NONE" )
    {
        myfont.setFamily(wl_explode.at(2));
    }

    myfont.setPointSize ( 1000 );

    int wl_larg_txt;
    int wl_height_txt;

    QStringList wl_explode2 = wl_explode.at(1).split("*^*",QString::KeepEmptyParts);

    int wl_r = wl_explode2.at(0).toInt();
    int wl_g = wl_explode2.at(1).toInt();
    int wl_b = wl_explode2.at(2).toInt();

    if ( wl_explode.at(3).mid(0,1) == "1" )
    {
        myfont.setBold(true);
    }

    if ( wl_explode.at(3).mid(1,1) == "1" )
    {
        myfont.setItalic(true);
    }

    if ( wl_explode.at(3).mid(2,1) == "1" )
    {
        myfont.setUnderline(true);
    }

    QString wl_tmps = wl_explode.at(0);

    wl_tmps.replace( "md*%", "$" );
    wl_tmps.replace( "ms*%", "!:!" );
    wl_tmps.replace( "mp*%", ":" );

    QFontMetrics fm(myfont);
    wl_larg_txt = fm.width(wl_tmps.mid(2,wl_tmps.length()));

    //qDebug() << fm.descent();

    if ( wl_larg_txt > 1000 )
    {
        float wl_fratio = (float)1000/(float)wl_larg_txt;
        int wl_fsize = 1000*wl_fratio;

        if ( wl_fsize + fm.descent() > 1024 )
        {
            wl_fsize = wl_fsize-fm.descent();
            wl_height_txt = 1024;
        }
        else
        {
            wl_height_txt = wl_fsize+fm.descent();
        }

        myfont.setPointSize(wl_fsize);
        QFontMetrics fm2(myfont);
        wl_larg_txt = fm2.width(wl_tmps.mid(2,wl_tmps.length()));
    }
    else
    {
        wl_larg_txt = fm.width(wl_tmps.mid(2,wl_tmps.length()));
        if ( 1000 + fm.descent() > 1024 )
        {
            myfont.setPointSize(1000-fm.descent());
            wl_height_txt = 1024;
        }
        else
        {
            wl_height_txt = 1024;
            myfont.setPointSize(wl_height_txt);
        }
    }

    p.begin(&wl_img_001);
    p.setFont(myfont);
    p.setPen(QColor(wl_r,wl_g,wl_b));
    p.drawText(QRect(0,0,1024,wl_height_txt), Qt::AlignHCenter | Qt::AlignTop,wl_tmps.mid(2,wl_explode.at(0).length()));
    p.end();*/

    f_init_coo_one_slide(nombre_diapos+1);

    tab_diapo[nombre_diapos+1][0] = "?9Text!;!255*^*255*^*255!;!NONE!;!000";          // *** NOM DU FICHIER DIAPO ***
    tab_diapo[nombre_diapos+1][1] = QString::number(1024);                            // *** LARGEUR DE LA TEXTURE ***
    tab_diapo[nombre_diapos+1][2] = QString::number(wl_height_txt);                   // *** HAUTEUR DE LA TEXTURE ***
    tab_diapo[nombre_diapos+1][3] = "";
    tab_diapo[nombre_diapos+1][4] = "0:0";                                            // *** LUMIERE ET CONTRASTE ***
    tab_diapo[nombre_diapos+1][5] = "0.5";                                            // *** SCALE FACTOR ***
    tab_diapo[nombre_diapos+1][6] = "0";                                              // *** REFLECT ***
    tab_diapo[nombre_diapos+1][7] = "0/0/0/0";                                        // *** CROP ***
    tab_diapo[nombre_diapos+1][8] = "0";                                              // *** ORIENTATION EXIF ***

    tab_coo[nombre_diapos+1][0] = 0.0;      // *** X ***
    tab_coo[nombre_diapos+1][1] = 0.0;      // *** Y ***
    tab_coo[nombre_diapos+1][2] = -3.7;     // *** Z ***
    tab_coo[nombre_diapos+1][3] = 0.0;      // *** FREE ***
    tab_coo[nombre_diapos+1][4] = 0.0;      // *** FREE ***
    tab_coo[nombre_diapos+1][5] = 0.0;     // *** ROTATE X ***
    tab_coo[nombre_diapos+1][6] = 0.0;      // *** ROTATE Y ***
    tab_coo[nombre_diapos+1][7] = 0.0;      // *** ROTATE Z ***
    tab_coo[nombre_diapos+1][8] = 10;       // *** VISIBILITE ***
    tab_coo[nombre_diapos+1][9] = 0.0;      // *** TRANSPARENCE ***
    tab_coo[nombre_diapos+1][10] = 0.0;     // *** BLUR ***
    tab_coo[nombre_diapos+1][11] = -1;      // *** TRANS DIAPO ***

    tab_coo_timeline[nombre_diapos+1][0] = "10:0.0:0.0:-3.7:0.0:0.0:0.0:10:0:0";
    tab_coo_timeline[nombre_diapos+1][1] = "690:0.0:0.0:-3.7:0.0:0.0:0.0:10:0:0";

    nombre_diapos++;
    f_follow_timeline(position_timeline);

    emit add_diapo();
}

void Tetrahedron::f_txt_changed(QString txtslide)
{
    if ( must_update == 0 )
    {
        return;
    }

    QStringList wl_explode = tab_diapo[num_select][0].split("!;!",QString::KeepEmptyParts);

    txtslide.replace( "$", "md*%");
    txtslide.replace( "!:!", "ms*%");
    txtslide.replace( ":", "mp*%");

    tab_diapo[num_select][0] = "?9" + txtslide + + "!;!" + wl_explode.at(1) + "!;!" + wl_explode.at(2) + "!;!" + wl_explode.at(3);

    f_reload_text();
}

void Tetrahedron::f_font_slidetxt(QFont nfont)
{
    if ( must_update == 0 || num_select == 0 )
    {
        return;
    }

    QStringList wl_explode = tab_diapo[num_select][0].split("!;!",QString::KeepEmptyParts);

    tab_diapo[num_select][0] = wl_explode.at(0) + "!;!" + wl_explode.at(1) + "!;!" + nfont.toString() + "!;!" + wl_explode.at(3);

    f_reload_text();
}

void Tetrahedron::f_bt_bold_txtslide()
{
    if ( must_update == 0 || num_select == 0 )
    {
        return;
    }

    QStringList wl_explode = tab_diapo[num_select][0].split("!;!",QString::KeepEmptyParts);

    if ( wl_explode.at(3).mid(0,1) == "0" )
    {
        tab_diapo[num_select][0] = wl_explode.at(0) + "!;!" + wl_explode.at(1) + "!;!" + wl_explode.at(2) + "!;!1" + wl_explode.at(3).mid(1,2);
    }
    else
    {
        tab_diapo[num_select][0] = wl_explode.at(0) + "!;!" + wl_explode.at(1) + "!;!" + wl_explode.at(2) + "!;!0" + wl_explode.at(3).mid(1,2);
    }

    f_reload_text();
}

void Tetrahedron::f_bt_italic_txtslide()
{
    if ( must_update == 0 || num_select == 0 )
    {
        return;
    }

    QStringList wl_explode = tab_diapo[num_select][0].split("!;!",QString::KeepEmptyParts);

    if ( wl_explode.at(3).mid(1,1) == "0" )
    {
        tab_diapo[num_select][0] = wl_explode.at(0) + "!;!" + wl_explode.at(1) + "!;!" + wl_explode.at(2) + "!;!" + wl_explode.at(3).mid(0,1) + "1" + wl_explode.at(3).mid(2,1);
    }
    else
    {
        tab_diapo[num_select][0] = wl_explode.at(0) + "!;!" + wl_explode.at(1) + "!;!" + wl_explode.at(2) + "!;!" + wl_explode.at(3).mid(0,1) + "0" + wl_explode.at(3).mid(2,1);
    }

    f_reload_text();

}

void Tetrahedron::f_bt_underline_txtslide()
{
    if ( must_update == 0 || num_select == 0 )
    {
        return;
    }

    QStringList wl_explode = tab_diapo[num_select][0].split("!;!",QString::KeepEmptyParts);

    if ( wl_explode.at(3).mid(2,1) == "0" )
    {
        tab_diapo[num_select][0] = wl_explode.at(0) + "!;!" + wl_explode.at(1) + "!;!" + wl_explode.at(2) + "!;!" + wl_explode.at(3).mid(0,2) + "1";
    }
    else
    {
        tab_diapo[num_select][0] = wl_explode.at(0) + "!;!" + wl_explode.at(1) + "!;!" + wl_explode.at(2) + "!;!" + wl_explode.at(3).mid(0,2) + "0";
    }

    f_reload_text();
}

void Tetrahedron::f_reload_text()
{   
    QStringList wl_explode = tab_diapo[num_select][0].split("!;!",QString::KeepEmptyParts);

    QFont myfont;
    QPainter p;
    QImage wl_img_001(1024,1024,QImage::Format_ARGB32_Premultiplied);
    wl_img_001.fill(0);

    if ( wl_explode.at(2) != "NONE" )
    {
        myfont.setFamily(wl_explode.at(2));
    }

    myfont.setPointSize ( 1000 );

    int wl_larg_txt;
    int wl_height_txt;

    QStringList wl_explode2 = wl_explode.at(1).split("*^*",QString::KeepEmptyParts);

    int wl_r = wl_explode2.at(0).toInt();
    int wl_g = wl_explode2.at(1).toInt();
    int wl_b = wl_explode2.at(2).toInt();

    if ( wl_explode.at(3).mid(0,1) == "1" )
    {
        myfont.setBold(true);
    }

    if ( wl_explode.at(3).mid(1,1) == "1" )
    {
        myfont.setItalic(true);
    }

    if ( wl_explode.at(3).mid(2,1) == "1" )
    {
        myfont.setUnderline(true);
    }

    QString wl_tmps = wl_explode.at(0);

    wl_tmps.replace( "md*%", "$" );
    wl_tmps.replace( "ms*%", "!:!" );
    wl_tmps.replace( "mp*%", ":" );

    QFontMetrics fm(myfont);
    wl_larg_txt = fm.width(wl_tmps.mid(2,wl_tmps.length()));

    //qDebug() << fm.descent();

    if ( wl_larg_txt > 1000 )
    {
        float wl_fratio = (float)1000/(float)wl_larg_txt;
        int wl_fsize = 1000*wl_fratio;

        if ( wl_fsize + fm.descent() > 1024 )
        {
            wl_fsize = wl_fsize-fm.descent();
            wl_height_txt = 1024;
        }
        else
        {
            wl_height_txt = wl_fsize+fm.descent();
        }

        myfont.setPointSize(wl_fsize);
        QFontMetrics fm2(myfont);
        wl_larg_txt = fm2.width(wl_tmps.mid(2,wl_tmps.length()));
    }
    else
    {
        wl_larg_txt = fm.width(wl_tmps.mid(2,wl_tmps.length()));
        if ( 1000 + fm.descent() > 1024 )
        {
            myfont.setPointSize(1000-fm.descent());
            wl_height_txt = 1024;
        }
        else
        {
            wl_height_txt = 1024;
            myfont.setPointSize(wl_height_txt);
        }
    }
    
    p.begin(&wl_img_001);
    p.setFont(myfont);
    p.setPen(QColor(wl_r,wl_g,wl_b));
    p.drawText(QRect(0,0,1024,wl_height_txt), Qt::AlignHCenter | Qt::AlignTop,wl_tmps.mid(2,wl_explode.at(0).length()));
    p.end();

    if ( tab_coo[num_select][10] > 0 )
    {
        wl_img_001 = blur_shadow(wl_img_001, tab_coo[num_select][10]);
    }

    QImage f = QGLWidget::convertToGLFormat( wl_img_001 );

    glDeleteTextures (1,&texture_diapo[num_select]);
    glGenTextures (1,&texture_diapo[num_select]);
    glBindTexture (GL_TEXTURE_2D, texture_diapo[num_select]);

    glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
    glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);

    glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, f.width(), f.height(),
                  0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits());

    wg_table_photo[num_select] = wl_img_001;

    tab_diapo[num_select][0] = "?9" + wl_explode.at(0).mid(2,wl_explode.at(0).length()) + "!;!" + wl_explode2.at(0) + "*^*" + wl_explode2.at(1) + "*^*" + wl_explode2.at(2) + "!;!" + wl_explode.at(2) + "!;!" + wl_explode.at(3);
    tab_diapo[num_select][1] = QString::number(1024);
    tab_diapo[num_select][2] = QString::number(wl_height_txt);

    updateGL();
}

void Tetrahedron::f_load_cray_r()
{
    if ( nombre_diapos+1 >= 20 )
    {
        QMessageBox::information(this, name_application, tr("Nombre maximum de photos par diapositive atteint"));
        return;
    }

    f_init_coo_one_slide(nombre_diapos+1);

    tab_diapo[nombre_diapos+1][0] = "?1";                                             // *** NOM DU FICHIER DIAPO ***
    tab_diapo[nombre_diapos+1][1] = QString::number(0);                               // *** LARGEUR DE LA TEXTURE ***
    tab_diapo[nombre_diapos+1][2] = QString::number(0);                               // *** HAUTEUR DE LA TEXTURE ***
    tab_diapo[nombre_diapos+1][3] = "";
    tab_diapo[nombre_diapos+1][4] = "0:0";                                            // *** LUMIERE ET CONTRASTE ***
    tab_diapo[nombre_diapos+1][5] = "1.0";                                            // *** SCALE FACTOR ***
    tab_diapo[nombre_diapos+1][6] = "0";                                              // *** REFLECT ***
    tab_diapo[nombre_diapos+1][7] = "0/0/0/0";                                        // *** CROP ***
    tab_diapo[nombre_diapos+1][8] = "0";                                              // *** ORIENTATION EXIF ***

    tab_coo[nombre_diapos+1][0] = 0.0;      // *** X ***
    tab_coo[nombre_diapos+1][1] = 0.0;      // *** Y ***
    tab_coo[nombre_diapos+1][2] = -12.0;     // *** Z ***
    tab_coo[nombre_diapos+1][3] = 0.0;      // *** FREE ***
    tab_coo[nombre_diapos+1][4] = 0.0;      // *** FREE ***
    tab_coo[nombre_diapos+1][5] = 90.0;     // *** ROTATE X ***
    tab_coo[nombre_diapos+1][6] = 0.0;      // *** ROTATE Y ***
    tab_coo[nombre_diapos+1][7] = 0.0;      // *** ROTATE Z ***
    tab_coo[nombre_diapos+1][8] = 10;       // *** VISIBILITE ***
    tab_coo[nombre_diapos+1][9] = 0.0;      // *** TRANSPARENCE ***
    tab_coo[nombre_diapos+1][10] = 0.0;     // *** BLUR ***
    tab_coo[nombre_diapos+1][11] = -1;      // *** TRANS DIAPO ***

    tab_coo_timeline[nombre_diapos+1][0] = "10:0.0:0.0:-12.0:90.0:0.0:0.0:10:0:0";
    tab_coo_timeline[nombre_diapos+1][1] = "690:0.0:0.0:-12.0:90.0:0.0:0.0:10:0:0";

    nombre_diapos++;
    f_follow_timeline(position_timeline);

    emit add_diapo();
}

void Tetrahedron::f_load_cray_v()
{
    if ( nombre_diapos+1 >= 20 )
    {
        QMessageBox::information(this, name_application, tr("Nombre maximum de photos par diapositive atteint"));
        return;
    }

    f_init_coo_one_slide(nombre_diapos+1);

    tab_diapo[nombre_diapos+1][0] = "?2";                                             // *** NOM DU FICHIER DIAPO ***
    tab_diapo[nombre_diapos+1][1] = QString::number(0);                               // *** LARGEUR DE LA TEXTURE ***
    tab_diapo[nombre_diapos+1][2] = QString::number(0);                               // *** HAUTEUR DE LA TEXTURE ***
    tab_diapo[nombre_diapos+1][3] = "";
    tab_diapo[nombre_diapos+1][4] = "0:0";                                            // *** LUMIERE ET CONTRASTE ***
    tab_diapo[nombre_diapos+1][5] = "1.0";                                            // *** SCALE FACTOR ***
    tab_diapo[nombre_diapos+1][6] = "0";                                              // *** REFLECT ***
    tab_diapo[nombre_diapos+1][7] = "0/0/0/0";                                        // *** CROP ***
    tab_diapo[nombre_diapos+1][8] = "0";                                              // *** ORIENTATION EXIF ***

    tab_coo[nombre_diapos+1][0] = 0.0;      // *** X ***
    tab_coo[nombre_diapos+1][1] = 0.0;      // *** Y ***
    tab_coo[nombre_diapos+1][2] = -12.0;    // *** Z ***
    tab_coo[nombre_diapos+1][3] = 0.0;      // *** FREE ***
    tab_coo[nombre_diapos+1][4] = 0.0;      // *** FREE ***
    tab_coo[nombre_diapos+1][5] = 90.0;     // *** ROTATE X ***
    tab_coo[nombre_diapos+1][6] = 0.0;      // *** ROTATE Y ***
    tab_coo[nombre_diapos+1][7] = 0.0;      // *** ROTATE Z ***
    tab_coo[nombre_diapos+1][8] = 10;       // *** VISIBILITE ***
    tab_coo[nombre_diapos+1][9] = 0.0;      // *** TRANSPARENCE ***
    tab_coo[nombre_diapos+1][10] = 0.0;     // *** BLUR ***
    tab_coo[nombre_diapos+1][11] = -1;      // *** TRANS DIAPO ***

    tab_coo_timeline[nombre_diapos+1][0] = "10:0.0:0.0:-12.0:90.0:0.0:0.0:10:0:0";
    tab_coo_timeline[nombre_diapos+1][1] = "690:0.0:0.0:-12.0:90.0:0.0:0.0:10:0:0";

    nombre_diapos++;
    f_follow_timeline(position_timeline);

    emit add_diapo();
}

void Tetrahedron::f_load_cray_b()
{
    if ( nombre_diapos+1 >= 20 )
    {
        QMessageBox::information(this, name_application, tr("Nombre maximum de photos par diapositive atteint"));
        return;
    }

    f_init_coo_one_slide(nombre_diapos+1);

    tab_diapo[nombre_diapos+1][0] = "?3";                                             // *** NOM DU FICHIER DIAPO ***
    tab_diapo[nombre_diapos+1][1] = QString::number(0);                               // *** LARGEUR DE LA TEXTURE ***
    tab_diapo[nombre_diapos+1][2] = QString::number(0);                               // *** HAUTEUR DE LA TEXTURE ***
    tab_diapo[nombre_diapos+1][3] = "";
    tab_diapo[nombre_diapos+1][4] = "0:0";                                            // *** LUMIERE ET CONTRASTE ***
    tab_diapo[nombre_diapos+1][5] = "1.0";                                            // *** SCALE FACTOR ***
    tab_diapo[nombre_diapos+1][6] = "0";                                              // *** REFLECT ***
    tab_diapo[nombre_diapos+1][7] = "0/0/0/0";                                        // *** CROP ***
    tab_diapo[nombre_diapos+1][8] = "0";                                              // *** ORIENTATION EXIF ***

    tab_coo[nombre_diapos+1][0] = 0.0;      // *** X ***
    tab_coo[nombre_diapos+1][1] = 0.0;      // *** Y ***
    tab_coo[nombre_diapos+1][2] = -12.0;     // *** Z ***
    tab_coo[nombre_diapos+1][3] = 0.0;      // *** FREE ***
    tab_coo[nombre_diapos+1][4] = 0.0;      // *** FREE ***
    tab_coo[nombre_diapos+1][5] = 90.0;     // *** ROTATE X ***
    tab_coo[nombre_diapos+1][6] = 0.0;      // *** ROTATE Y ***
    tab_coo[nombre_diapos+1][7] = 0.0;      // *** ROTATE Z ***
    tab_coo[nombre_diapos+1][8] = 10;       // *** VISIBILITE ***
    tab_coo[nombre_diapos+1][9] = 0.0;      // *** TRANSPARENCE ***
    tab_coo[nombre_diapos+1][10] = 0.0;     // *** BLUR ***
    tab_coo[nombre_diapos+1][11] = -1;      // *** TRANS DIAPO ***

    tab_coo_timeline[nombre_diapos+1][0] = "10:0.0:0.0:-12.0:90.0:0.0:0.0:10:0:0";
    tab_coo_timeline[nombre_diapos+1][1] = "690:0.0:0.0:-12.0:90.0:0.0:0.0:10:0:0";

    nombre_diapos++;
    f_follow_timeline(position_timeline);

    emit add_diapo();
}

void Tetrahedron::f_load_cray_w()
{
    if ( nombre_diapos+1 >= 20 )
    {
        QMessageBox::information(this, name_application, tr("Nombre maximum de photos par diapositive atteint"));
        return;
    }

    f_init_coo_one_slide(nombre_diapos+1);

    tab_diapo[nombre_diapos+1][0] = "?4";                                             // *** NOM DU FICHIER DIAPO ***
    tab_diapo[nombre_diapos+1][1] = QString::number(0);                               // *** LARGEUR DE LA TEXTURE ***
    tab_diapo[nombre_diapos+1][2] = QString::number(0);                               // *** HAUTEUR DE LA TEXTURE ***
    tab_diapo[nombre_diapos+1][3] = "";
    tab_diapo[nombre_diapos+1][4] = "0:0";                                            // *** LUMIERE ET CONTRASTE ***
    tab_diapo[nombre_diapos+1][5] = "1.0";                                            // *** SCALE FACTOR ***
    tab_diapo[nombre_diapos+1][6] = "0";                                              // *** REFLECT ***
    tab_diapo[nombre_diapos+1][7] = "0/0/0/0";                                        // *** CROP ***
    tab_diapo[nombre_diapos+1][8] = "0";                                              // *** ORIENTATION EXIF ***

    tab_coo[nombre_diapos+1][0] = 0.0;      // *** X ***
    tab_coo[nombre_diapos+1][1] = 0.0;      // *** Y ***
    tab_coo[nombre_diapos+1][2] = -12.0;     // *** Z ***
    tab_coo[nombre_diapos+1][3] = 0.0;      // *** FREE ***
    tab_coo[nombre_diapos+1][4] = 0.0;      // *** FREE ***
    tab_coo[nombre_diapos+1][5] = 90.0;     // *** ROTATE X ***
    tab_coo[nombre_diapos+1][6] = 0.0;      // *** ROTATE Y ***
    tab_coo[nombre_diapos+1][7] = 0.0;      // *** ROTATE Z ***
    tab_coo[nombre_diapos+1][8] = 10;       // *** VISIBILITE ***
    tab_coo[nombre_diapos+1][9] = 0.0;      // *** TRANSPARENCE ***
    tab_coo[nombre_diapos+1][10] = 0.0;     // *** BLUR ***
    tab_coo[nombre_diapos+1][11] = -1;      // *** TRANS DIAPO ***

    tab_coo_timeline[nombre_diapos+1][0] = "10:0.0:0.0:-12.0:90.0:0.0:0.0:10:0:0";
    tab_coo_timeline[nombre_diapos+1][1] = "690:0.0:0.0:-12.0:90.0:0.0:0.0:10:0:0";

    nombre_diapos++;
    f_follow_timeline(position_timeline);

    emit add_diapo();
}

void Tetrahedron::f_load_load_star_w()
{
    tab_diapo[nombre_diapos+1][0] = "?5";                                             // *** NOM DU FICHIER DIAPO ***
    tab_diapo[nombre_diapos+1][1] = QString::number(0);                               // *** LARGEUR DE LA TEXTURE ***
    tab_diapo[nombre_diapos+1][2] = QString::number(0);                               // *** HAUTEUR DE LA TEXTURE ***
    tab_diapo[nombre_diapos+1][3] = "";
    tab_diapo[nombre_diapos+1][4] = "0:0";                                            // *** LUMIERE ET CONTRASTE ***
    tab_diapo[nombre_diapos+1][5] = "1.0";                                            // *** SCALE FACTOR ***
    tab_diapo[nombre_diapos+1][6] = "0";                                              // *** REFLECT ***
    tab_diapo[nombre_diapos+1][7] = "0/0/0/0";                                        // *** CROP ***
    tab_diapo[nombre_diapos+1][8] = "0";                                              // *** ORIENTATION EXIF ***

    tab_coo[nombre_diapos+1][0] = 0.0;      // *** X ***
    tab_coo[nombre_diapos+1][1] = 0.0;      // *** Y ***
    tab_coo[nombre_diapos+1][2] = -3.8;     // *** Z ***
    tab_coo[nombre_diapos+1][3] = 0.0;      // *** FREE ***
    tab_coo[nombre_diapos+1][4] = 0.0;      // *** FREE ***
    tab_coo[nombre_diapos+1][5] = 0.0;     // *** ROTATE X ***
    tab_coo[nombre_diapos+1][6] = 0.0;      // *** ROTATE Y ***
    tab_coo[nombre_diapos+1][7] = 0.0;      // *** ROTATE Z ***
    tab_coo[nombre_diapos+1][8] = 10;       // *** VISIBILITE ***
    tab_coo[nombre_diapos+1][9] = 0.0;      // *** TRANSPARENCE ***
    tab_coo[nombre_diapos+1][10] = 0.0;     // *** BLUR ***

    tab_coo_timeline[nombre_diapos+1][0] = "10:0.0:0.0:-12.0:0.0:0.0:0.0:10:0:0";
    tab_coo_timeline[nombre_diapos+1][1] = "690:0.0:0.0:-12.0:0.0:0.0:0.0:10:0:0";

    nombre_diapos++;
    f_follow_timeline(position_timeline);

    emit add_diapo();
}

void Tetrahedron::f_edit_image()
{
    emit s_edit_image();
}

void Tetrahedron::f_init_image()
{
    tab_coo[num_select][0] = 0.0;      // *** X ***
    tab_coo[num_select][1] = 0.0;      // *** Y ***
    tab_coo[num_select][2] = -3.8;     // *** Z ***
    //tab_coo[num_select][3] = 0.0;      // *** FREE ***
    //tab_coo[num_select][4] = 0.0;      // *** FREE ***
    tab_coo[num_select][5] = 0.0;      // *** ROTATE X ***
    tab_coo[num_select][6] = 0.0;      // *** ROTATE Y ***
    tab_coo[num_select][7] = 0.0;      // *** ROTATE Z ***
    tab_coo[num_select][8] = 1.0;      // *** VISIBILITE ***
    tab_coo[num_select][9] = 0.0;      // *** TRANSPARENCE ***

    tab_coo_timeline[num_select][0] = "10:0.0:0.0:-3.8:0.0:0.0:0.0:1:0:0";
    tab_coo_timeline[num_select][1] = "690:0.0:0.0:-3.8:0.0:0.0:0.0:1:0:0";
    tab_coo_timeline[num_select][2] = "";

    dia_select(num_select);
    updateGL();
}

void Tetrahedron::f_load_image()
{
    myfileopen *hdlfopen = new myfileopen(this);
    hdlfopen->setDirectory(wg_path_images);
    hdlfopen->source = 1;
    num_select = 0;
    hdlfopen->setFileMode(QFileDialog::ExistingFiles);
    hdlfopen->setWindowTitle(tr("Diapositive"));
    hdlfopen->setFilter("(*.PNG *.png *.jpg *.JPG *.jeg *.JPEG *.gif *.GIF)");
    connect(hdlfopen, SIGNAL(change_image(QString)),this, SLOT(f_open_ipreview(QString)));
    hdlfopen->show();
    connect(hdlfopen, SIGNAL(filesSelected( const QStringList )),this, SLOT(f_load_image_step_2( const QStringList )));
    connect(hdlfopen, SIGNAL(f_close()),this, SLOT(f_hide_preview()));
    connect(hdlfopen, SIGNAL(finished(int)),this, SLOT(f_hide_preview()));
}

void Tetrahedron::f_load_image_for_cube()
{
    myfileopen *hdlfopen = new myfileopen(this);
    hdlfopen->setDirectory(wg_path_images);
    hdlfopen->source = 1;
    num_select = 0;
    hdlfopen->setFileMode(QFileDialog::ExistingFiles);
    hdlfopen->setWindowTitle(tr("Selectionner jusqu a 6 images pour votre cube"));
    hdlfopen->setFilter("(*.PNG *.png *.jpg *.JPG *.jeg *.JPEG)");
    connect(hdlfopen, SIGNAL(change_image(QString)),this, SLOT(f_open_ipreview(QString)));
    hdlfopen->show();
    connect(hdlfopen, SIGNAL(filesSelected( const QStringList )),this, SLOT(f_load_image_step_2_cube( const QStringList )));
    connect(hdlfopen, SIGNAL(f_close()),this, SLOT(f_hide_preview()));
    connect(hdlfopen, SIGNAL(finished(int)),this, SLOT(f_hide_preview()));
}

void Tetrahedron::f_load_image_for_cube_change()
{
    myfileopen *hdlfopen = new myfileopen(this);
    hdlfopen->setDirectory(wg_path_images);
    hdlfopen->source = 1;
    num_select = 0;
    hdlfopen->setFileMode(QFileDialog::ExistingFiles);
    hdlfopen->setWindowTitle(tr("Selectionner jusqu a 6 images pour votre cube"));
    hdlfopen->setFilter("(*.PNG *.png *.jpg *.JPG *.jeg *.JPEG)");
    connect(hdlfopen, SIGNAL(change_image(QString)),this, SLOT(f_open_ipreview(QString)));
    hdlfopen->show();
    connect(hdlfopen, SIGNAL(filesSelected( const QStringList )),this, SLOT(f_load_image_step_2_cube_change( const QStringList )));
    connect(hdlfopen, SIGNAL(f_close()),this, SLOT(f_hide_preview()));
    connect(hdlfopen, SIGNAL(finished(int)),this, SLOT(f_hide_preview()));
}

void Tetrahedron::f_load_image_step_2_cube( const QStringList wl_slmyfic)
{
    QString wl_myfic = wl_slmyfic.at(0);

    int i = wl_myfic.lastIndexOf( '/' );
    wg_path_images = wl_myfic.mid(0, i);

    QImage wl_img_texture;
    QImage wl_puis_001(1024,1024,QImage::Format_ARGB32_Premultiplied);
    int wl_int_001 = 0;

    QString wl_totpath = "";

    while ( wl_int_001 < wl_slmyfic.count() && wl_int_001 < 6 )
    {
        wl_myfic = wl_slmyfic.at(wl_int_001);
        wl_totpath = wl_totpath + wl_myfic + ")(";
        if ( wl_img_texture.load(wl_myfic) == true )
        {
            if ( wl_img_texture.width() < wl_img_texture.height() )
            {
                wl_img_texture = wl_img_texture.scaledToWidth(1024,Qt::SmoothTransformation);
            }
            else
            {
                wl_img_texture = wl_img_texture.scaledToHeight(1024,Qt::SmoothTransformation);
            }

            wl_puis_001 = wl_img_texture.copy ( 0, 0, 1024, 1024);

            QImage f = QGLWidget::convertToGLFormat( wl_puis_001 );

            glDeleteTextures (1,&texture_diapo_cube[wl_int_001]);
            glGenTextures (1,&texture_diapo_cube[wl_int_001]);
            glBindTexture (GL_TEXTURE_2D, texture_diapo_cube[wl_int_001]);

            glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
            glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);

            glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, f.width(), f.height(),
                          0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits());
        }
        wl_int_001++;
    }

    while ( wl_int_001 < 6 )
    {
        QImage f = QGLWidget::convertToGLFormat( wl_puis_001 );

        glDeleteTextures (1,&texture_diapo_cube[wl_int_001]);
        glGenTextures (1,&texture_diapo_cube[wl_int_001]);
        glBindTexture (GL_TEXTURE_2D, texture_diapo_cube[wl_int_001]);

        glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
        glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);

        glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, f.width(), f.height(),
                      0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits());

        wl_totpath = wl_totpath + wl_myfic + ")(";

        wl_int_001++;
    }

    f_load_cube(wl_totpath);
    //updateGL();
}

void Tetrahedron::f_load_image_step_2_cube_change( const QStringList wl_slmyfic)
{
    QString wl_myfic = wl_slmyfic.at(0);

    int i = wl_myfic.lastIndexOf( '/' );
    wg_path_images = wl_myfic.mid(0, i);

    QImage wl_img_texture;
    QImage wl_puis_001(1024,1024,QImage::Format_ARGB32_Premultiplied);
    int wl_int_001 = 0;

    QString wl_totpath = "";

    while ( wl_int_001 < wl_slmyfic.count() && wl_int_001 < 6 )
    {
        wl_myfic = wl_slmyfic.at(wl_int_001);
        wl_totpath = wl_totpath + wl_myfic + ")(";
        if ( wl_img_texture.load(wl_myfic) == true )
        {
            if ( wl_img_texture.width() < wl_img_texture.height() )
            {
                wl_img_texture = wl_img_texture.scaledToWidth(1024,Qt::SmoothTransformation);
            }
            else
            {
                wl_img_texture = wl_img_texture.scaledToHeight(1024,Qt::SmoothTransformation);
            }

            wl_puis_001 = wl_img_texture.copy ( 0, 0, 1024, 1024);

            QImage f = QGLWidget::convertToGLFormat( wl_puis_001 );

            glDeleteTextures (1,&texture_diapo_cube[wl_int_001]);
            glGenTextures (1,&texture_diapo_cube[wl_int_001]);
            glBindTexture (GL_TEXTURE_2D, texture_diapo_cube[wl_int_001]);

            glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
            glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);

            glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, f.width(), f.height(),
                          0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits());
        }
        wl_int_001++;
    }

    while ( wl_int_001 < 6 )
    {
        QImage f = QGLWidget::convertToGLFormat( wl_puis_001 );

        glDeleteTextures (1,&texture_diapo_cube[wl_int_001]);
        glGenTextures (1,&texture_diapo_cube[wl_int_001]);
        glBindTexture (GL_TEXTURE_2D, texture_diapo_cube[wl_int_001]);

        glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
        glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);

        glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, f.width(), f.height(),
                      0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits());

        wl_totpath = wl_totpath + wl_myfic + ")(";

        wl_int_001++;
    }

    tab_diapo[num_select+1][0] = "?6" + wl_totpath;                                // *** NOM DU FICHIER DIAPO ***;

    updateGL();
}

void Tetrahedron::f_swap_image()
{
    myfileopen *hdlfopen = new myfileopen(this);
    hdlfopen->setDirectory(wg_path_images);
    hdlfopen->source = 1;
    hdlfopen->setWindowTitle(tr("Diapositive"));
    hdlfopen->setFilter("(*.PNG *.png *.jpg *.JPG *.jeg *.JPEG)");
    connect(hdlfopen, SIGNAL(change_image(QString)),this, SLOT(f_open_ipreview(QString)));
    hdlfopen->show();
    connect(hdlfopen, SIGNAL(filesSelected( const QStringList )),this, SLOT(f_load_image_step_2( const QStringList )));
    connect(hdlfopen, SIGNAL(f_close()),this, SLOT(f_hide_preview()));
    connect(hdlfopen, SIGNAL(finished(int)),this, SLOT(f_hide_preview()));
}

void Tetrahedron::f_load_background_1()
{
    myfileopen *hdlfopen = new myfileopen(this);
    hdlfopen->setDirectory(wg_path_images);
    hdlfopen->source = 1;
    hdlfopen->setWindowTitle(tr("Image d'arriere plan"));
    hdlfopen->setFilter("(*.PNG *.png *.jpg *.JPG *.jeg *.JPEG)");
    connect(hdlfopen, SIGNAL(change_image(QString)),this, SLOT(f_open_ipreview(QString)));
    hdlfopen->show();
    connect(hdlfopen, SIGNAL(filesSelected( const QStringList )),this, SLOT(f_load_background( const QStringList )));
    connect(hdlfopen, SIGNAL(f_close()),this, SLOT(f_hide_preview()));
    connect(hdlfopen, SIGNAL(finished(int)),this, SLOT(f_hide_preview()));
}

void Tetrahedron::f_load_background( const QStringList wl_slmyfic)
{
    QString wl_myfic = wl_slmyfic.at(0);

    int i = wl_myfic.lastIndexOf( '/' );
    wg_path_images = wl_myfic.mid(0, i);

    QImage wl_img_texture;

    if ( wl_img_texture.load(wl_myfic) == true )
    {
        //qDebug() << wl_img_texture.width() << " " << wl_img_texture.height();
        if ( wl_img_texture.width() > wl_img_texture.height() )
        {
            wl_img_texture = wl_img_texture.scaledToWidth(1024,Qt::SmoothTransformation);
        }
        else
        {
            wl_img_texture = wl_img_texture.scaledToHeight(1024,Qt::SmoothTransformation);
        }

        QImage wl_puis_001(1024,1024,QImage::Format_ARGB32_Premultiplied);
        wl_puis_001 = wl_img_texture.copy ( 0, 0, 1024, 1024);

        wg_fd_tx = (float)wl_img_texture.width()/(float)1024;
        wg_fd_ty = (float)wl_img_texture.height()/(float)1024;

        //qDebug() << wg_fd_tx << " " << wg_fd_ty;

        QImage f = QGLWidget::convertToGLFormat( wl_puis_001 );

        glDeleteTextures (1,&texture_diapo[41]);
        glGenTextures (1,&texture_diapo[41]);
        glBindTexture (GL_TEXTURE_2D, texture_diapo[41]);

        glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
        glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);

        glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, f.width(), f.height(),
                      0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits());

        isback = 1;
        back_color = wl_myfic;
        updateGL();
        emit update_preview();
    }
}


void Tetrahedron::f_hide_preview()
{
    emit hide_preview();
}

int Tetrahedron::f_load_exif(QString wl_ig)
{
    int sens = 0;
    wg_string_003 = "";

    QFile wmyficext;
    QTextStream outext(&wmyficext);

    wmyficext.setFileName(QDir::homePath() + "/.mdvexif.sh");
    wmyficext.open( QIODevice::WriteOnly );
    outext << "export LANG=en_EN.utf-8" << endl;
    outext << "exif -t 0x0112 " + wl_ig << endl;
    //outext << "rm -f " + QDir::homePath() + "/.mdvexif.sh" << endl;
    outext << "exit" << endl;
    wmyficext.close();
    QString programf = "bash";
    QStringList argumentsf;
    argumentsf << QDir::homePath() + "/.mdvexif.sh";

    proc_ffmpeg.setProcessChannelMode(QProcess::MergedChannels);
    proc_ffmpeg.start(programf,argumentsf);

    proc_ffmpeg.waitForFinished(-1);
    QByteArray buffer(proc_ffmpeg.readAllStandardOutput());
    wg_string_003 = wg_string_003 + buffer;

    int wl_int_001 =  wg_string_003.lastIndexOf( "left - bottom", -1, Qt::CaseInsensitive );
    if ( wl_int_001 > -1 )
    {
        sens = 1;
    }

    wl_int_001 =  wg_string_003.lastIndexOf( "right - top", -1, Qt::CaseInsensitive );
    if ( wl_int_001 > -1 )
    {
        sens = 2;
    }

    return sens;
}

void Tetrahedron::f_read_ffmpeg()
{
        QByteArray buffer(proc_ffmpeg.readAllStandardOutput());
        wg_string_003 = wg_string_003 + buffer;
}

void Tetrahedron::f_load_image_step_2(const QStringList wl_slmyfic)
{
    int wl_int_001 = 0;
    QString wl_myfic;
    QImage wl_img_texture;
    QImage f;
    int i;

    wl_myfic = wl_slmyfic.at(wl_int_001);

    i = wl_myfic.lastIndexOf( '/' );
    if ( i >= 0 )
    {
        wg_path_images = wl_myfic.mid(0, i);
    }

    while ( wl_int_001 < wl_slmyfic.count() && nombre_diapos+1 < 20 )
    {
        if ( wl_int_001 > 0 ) // *** PIEGE POUR IMPORT MULTIPLE DE PHOTOS ***
        {
            num_select = 0;
        }
        wl_myfic = wl_slmyfic.at(wl_int_001);

        //i = wl_myfic.lastIndexOf( '/' );
        //wg_path_images = wl_myfic.mid(0, i);

        if ( wl_img_texture.load(wl_myfic) == true )
        {
            if ( num_select == 0 ) // *** NOUVELLE DIAPOSITIVE ***
            {
                // *** CHARGEMENT DE LA TEXTURE ***
                //glDeleteTextures(1, &texture_diapo[nombre_diapos+1] );
                QImage wl_puis_001(1024,1024,QImage::Format_ARGB32_Premultiplied);

                if ( wl_img_texture.width() > wl_img_texture.height() )
                {
                    wl_img_texture = wl_img_texture.scaledToWidth(1024,Qt::SmoothTransformation);
                }
                else
                {
                    wl_img_texture = wl_img_texture.scaledToHeight(1024,Qt::SmoothTransformation);
                }

                wl_puis_001 = wl_img_texture.copy ( 0, 0, 1024, 1024); //1024, 1024);

                wg_table_photo[nombre_diapos+1] = wl_puis_001;

                f_init_coo_one_slide(nombre_diapos+1);

                int sens = f_load_exif(wl_myfic);

                tab_diapo[nombre_diapos+1][0] = wl_myfic;                                         // *** NOM DU FICHIER DIAPO ***
                tab_diapo[nombre_diapos+1][1] = QString::number(wl_img_texture.width());          // *** LARGEUR DE LA TEXTURE ***
                tab_diapo[nombre_diapos+1][2] = QString::number(wl_img_texture.height());         // *** HAUTEUR DE LA TEXTURE ***
                tab_diapo[nombre_diapos+1][3] = "";
                tab_diapo[nombre_diapos+1][4] = "0:0";                                            // *** LUMIERE ET CONTRASTE ***
                tab_diapo[nombre_diapos+1][5] = "1.0";                                            // *** SCALE FACTOR ***
                tab_diapo[nombre_diapos+1][6] = "0";                                              // *** REFLECT ***
                tab_diapo[nombre_diapos+1][7] = "0/0/0/0";                                        // *** CROP ***
                tab_diapo[nombre_diapos+1][8] = QString::number(sens);                            // *** ORIENTATION EXIF ***

                tab_coo[nombre_diapos+1][0] = 0.0;      // *** X ***
                tab_coo[nombre_diapos+1][1] = 0.0;      // *** Y ***
                tab_coo[nombre_diapos+1][2] = -3.8;     // *** Z ***
                tab_coo[nombre_diapos+1][3] = 0.0;      // *** FREE ***
                tab_coo[nombre_diapos+1][4] = 0.0;      // *** FREE ***
                tab_coo[nombre_diapos+1][5] = 0.0;      // *** ROTATE X ***               
                tab_coo[nombre_diapos+1][6] = 0.0;      // *** ROTATE Y ***
                tab_coo[nombre_diapos+1][7] = 0.0;      // *** ROTATE Z ***
                tab_coo[nombre_diapos+1][8] = 10;       // *** VISIBILITE ***
                tab_coo[nombre_diapos+1][9] = 0.0;      // *** TRANSPARENCE ***
                tab_coo[nombre_diapos+1][10] = 0.0;     // *** BLUR ***
                tab_coo[nombre_diapos+1][11] = -1;      // *** TRANS DIAPO ***

                tab_coo_timeline[nombre_diapos+1][0] = "10:0.0:0.0:-3.8:0.0:0.0:0.0:10:0:0";
                tab_coo_timeline[nombre_diapos+1][1] = "690:0.0:0.0:-3.8:0.0:0.0:0.0:10:0:0";

                f = QGLWidget::convertToGLFormat( wl_puis_001 );

                glDeleteTextures (1,&texture_diapo[nombre_diapos+1]);
                glGenTextures (1,&texture_diapo[nombre_diapos+1]);
                glBindTexture (GL_TEXTURE_2D, texture_diapo[nombre_diapos+1]);

                glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
                glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);

                glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, f.width(), f.height(),
                              0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits());

                if ( wl_myfic.right(4) == ".gif" || wl_myfic.right(4) == ".GIF" )
                {
                    tabgif[nombre_diapos+1].setFileName(wl_myfic);
                    tabgif[nombre_diapos+1].setCacheMode( QMovie::CacheAll );
                    tabgif[nombre_diapos+1].jumpToFrame( 0 );
                }

                nombre_diapos++;
                //num_select = 0;
                f_follow_timeline(position_timeline);

                emit add_diapo();
                //this->repaint();
            }
            else // *** CHANGEMENT DE TEXTURE ***
            {
                // *** CHARGEMENT DE LA TEXTURE ***
                glDeleteTextures(1, &texture_diapo[num_select] );
                QImage wl_puis_001(1024,1024,QImage::Format_ARGB32_Premultiplied);

                if ( wl_img_texture.width() > wl_img_texture.height() )
                {
                    wl_img_texture = wl_img_texture.scaledToWidth(1024,Qt::SmoothTransformation);
                }
                else
                {
                    wl_img_texture = wl_img_texture.scaledToHeight(1024,Qt::SmoothTransformation);
                }
                wl_img_texture = wl_img_texture.convertToFormat ( QImage::Format_ARGB32, Qt::AutoColor );

                QStringList wg_str_001 = tab_diapo[num_select][4].split(":",QString::SkipEmptyParts);

                if ( wg_str_001.at(0).toInt() != 0 || wg_str_001.at(1).toInt() != 0 )
                {
                    wg_img_smile_effect = wl_img_texture;
                    f_effect_run(wg_str_001.at(0).toInt(), wg_str_001.at(1).toInt());
                    wl_img_texture = wg_img_smile_effect;
                }

                if ( tab_diapo[num_select][3] != "" )
                {
                    QStringList wl_explode = tab_diapo[num_select][3].split("%*",QString::KeepEmptyParts);

                    QImage wl_image_2(qApp->applicationDirPath()+"/Bibliotheque/Masks/"+wl_explode.at(0)+".png");
                    wl_image_2 = wl_image_2.scaled(1024, 1024);
                    wl_image_2 = wl_image_2.convertToFormat ( QImage::Format_ARGB32, Qt::AutoColor ); //_Premultiplied

                    QPainter g;

                    QPainter::CompositionMode mode = (QPainter::CompositionMode)6;

                    g.begin(&wl_img_texture);
                    g.setCompositionMode ( mode );
                    g.drawImage(QRect(0,0,-1,-1),wl_image_2);

                    QString wl_str_001 = qApp->applicationDirPath() + "/Bibliotheque/Masks/2t_" + wl_explode.at(0) + ".png";
                    QImage wl_over_mask;

                    if ( wl_over_mask.load(wl_str_001) == true )
                    {
                        wl_over_mask = wl_over_mask.scaled(1024, 1024);
                        wl_over_mask = f_mutation_overmask( wl_over_mask, wl_explode.at(1) + "%*" + wl_explode.at(2) + "%*" + wl_explode.at(3) + "%*" + wl_explode.at(4) );
                        wl_over_mask = wl_over_mask.convertToFormat ( QImage::Format_ARGB32, Qt::AutoColor ); //_Premultiplied
                        g.setCompositionMode ( (QPainter::CompositionMode)0 );
                        g.drawImage(QRect(0,0,-1,-1),wl_over_mask);
                    }

                    g.end();
                }

                if ( tab_coo[num_select][10] > 0 )
                {
                    wl_img_texture = blur_shadow(wl_img_texture, tab_coo[num_select][10]);
                }

                wl_puis_001 = wl_img_texture.copy ( 0, 0, 1024, 1024);
                wg_table_photo[num_select] = wl_puis_001;

                int sens = f_load_exif(wl_myfic);

                tab_diapo[num_select][0] = wl_myfic;                                         // *** NOM DU FICHIER DIAPO ***
                tab_diapo[num_select][1] = QString::number(wl_img_texture.width());          // *** LARGEUR DE LA TEXTURE ***
                tab_diapo[num_select][2] = QString::number(wl_img_texture.height());         // *** HAUTEUR DE LA TEXTURE ***
                tab_diapo[num_select][4] = "0:0";
                tab_diapo[num_select][7] = "0/0/0/0";                                        // *** CROP ***
                tab_diapo[num_select][8] = QString::number(sens);                            // *** ORIENTATION EXIF ***

                QImage f = QGLWidget::convertToGLFormat( wl_puis_001 );

                glDeleteTextures (1,&texture_diapo[num_select]);
                glGenTextures (1,&texture_diapo[num_select]);
                glBindTexture (GL_TEXTURE_2D, texture_diapo[num_select]);

                glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
                glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);

                glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, f.width(), f.height(),
                              0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits());

                if ( wl_myfic.right(4) == ".gif" || wl_myfic.right(4) == ".GIF" )
                {
                    tabgif[num_select].setFileName(wl_myfic);
                    tabgif[num_select].setCacheMode( QMovie::CacheAll );
                    tabgif[num_select].jumpToFrame( 0 );
                }

                //this->repaint();
                emit update_diapo();
            }
        }
        wl_int_001++;
    }
    emit update_preview();
    emit hide_preview();

    if ( nombre_diapos+1 >= 20 )
    {
        QMessageBox::information(this, name_application, tr("Nombre maximum de photos par diapositive atteint"));
    }
}

void Tetrahedron::f_open_ipreview(QString wlfile)
{
    emit dia_of_preview(wlfile);
}

//

void Tetrahedron::initializeGL()
{
        qglClearColor(Qt::black);
        //glClearAccum(0.0, 0.0, 0.0, 1.0);
        glClear(GL_DEPTH_BUFFER_BIT|GL_COLOR_BUFFER_BIT);

        //glEnable( GL_DEPTH_TEST );
        //glEnable( GL_NORMALIZE );

        glEnable( GL_DEPTH_TEST );
        glEnable( GL_NORMALIZE );
        glDisable( GL_DITHER );
	glDisable( GL_SMOOTH );
	//
        //glShadeModel(GL_SMOOTH);
        glShadeModel(GL_FLAT);
        glEnable( GL_ALPHA_TEST );
	glEnable( GL_BLEND );
        glDisable( GL_STENCIL_TEST );

        glDisable(GL_FOG);
        glDepthMask(GL_FALSE);
        //glDepthMask(GL_TRUE);
	glAlphaFunc(GL_GREATER, 0.0f);

        //glColorMaterial ( GL_FRONT_AND_BACK, GL_AMBIENT_AND_DIFFUSE ); //GL_EMISSION ) ;
        //glColorMaterial ( GL_FRONT_AND_BACK, GL_EMISSION );
        glEnable( GL_COLOR_MATERIAL );

        glEnable(GL_MULTISAMPLE_ARB);
        glHint(GL_SAMPLE_BUFFERS_ARB,1);

        //glEnable(GL_COLOR_MATERIAL);
        glDisable(GL_POINT_SMOOTH);
        glDisable(GL_LINE_SMOOTH);
        glHint(GL_POINT_SMOOTH_HINT, GL_FASTEST);
        glHint(GL_LINE_SMOOTH_HINT, GL_FASTEST);
        //glHint(GL_POLYGON_SMOOTH_HINT, GL_FASTEST);

        glHint(GL_PERSPECTIVE_CORRECTION_HINT, GL_NICEST);
        glHint(GL_TEXTURE_COMPRESSION_HINT, GL_NICEST);
        glHint(GL_FRAGMENT_SHADER_DERIVATIVE_HINT, GL_NICEST);

        qglClearColor(Qt::black);

        //glDepthMask(1); // *** TODO ***

	//
    	glMatrixMode(GL_MODELVIEW);
        glEnable(GL_TEXTURE_2D);

        // *** CHARGEMENT TEXTURE SELECTION ***
        glDeleteTextures(1, &texture_diapo[42] );
        QImage wl_puis_001(128,128,QImage::Format_ARGB32_Premultiplied);
        QImage wl_img_texture(":/Interface/Interface/edition.png");

        wl_puis_001 = wl_img_texture.copy ( 0, 0, 1024, 1024);

        QPainter p;
        p.begin(&wl_puis_001);

        QPen pen;

        pen.setStyle(Qt::DashDotLine);
        pen.setWidth(1);
        pen.setBrush(QColor(255,0,0));
        pen.setCapStyle(Qt::RoundCap);
        pen.setJoinStyle(Qt::RoundJoin);

        p.setPen(pen);
        p.drawRect(0,0,wl_puis_001.width()-1,wl_puis_001.height()-1);
        p.end();

        QImage f = QGLWidget::convertToGLFormat( wl_puis_001 );

        glDeleteTextures (1,&texture_diapo[42]);
        glGenTextures (1,&texture_diapo[42]);
        glBindTexture (GL_TEXTURE_2D, texture_diapo[42]);

        glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
        glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);

        glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, f.width(), f.height(),
                      0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits());

        // *** CHARGEMENT TEXTURE POUR ETOILE ***
        /*glDeleteTextures(1, &texture_diapo[43] );
        QImage wl_puis_002(512,512,QImage::Format_ARGB32_Premultiplied);
        wl_img_texture.load(":/Interface/Interface/blob.png");

        wl_puis_002 = wl_img_texture.copy ( 0, 0, 1024, 1024);

        f = QGLWidget::convertToGLFormat( wl_puis_002 );

        glGenTextures (1,&texture_diapo[43]);
        glBindTexture (GL_TEXTURE_2D, texture_diapo[43]);

        glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
        glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);

        glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, f.width(), f.height(),
                      0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits());*/

        // *** CHARGEMENT TEXTURE POUR EARTH ***
        glDeleteTextures(1, &texture_diapo[44] );
        QImage wl_puis_003(512,512,QImage::Format_ARGB32_Premultiplied);
        wl_img_texture.load(":/Interface/Interface/EarthMap.jpg");

        wl_puis_003 = wl_img_texture.copy ( 0, 0, 1024, 1024);

        f = QGLWidget::convertToGLFormat( wl_puis_003 );

        glDeleteTextures (1,&texture_diapo[44]);
        glGenTextures (1,&texture_diapo[44]);
        glBindTexture (GL_TEXTURE_2D, texture_diapo[44]);

        glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
        glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);

        glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, f.width(), f.height(),
                      0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits());
}

void Tetrahedron::quality_high()
{
        /*if ( is_sample_layer == 1 )
        {
            this->setFormat(QGLFormat(QGL::SampleBuffers));
        }*/
        glEnable( GL_SMOOTH );
        glEnable(GL_POINT_SMOOTH);
        glEnable(GL_LINE_SMOOTH);

        glHint(GL_POINT_SMOOTH_HINT, GL_NICEST);
        glHint(GL_LINE_SMOOTH_HINT, GL_NICEST);
        glHint(GL_POLYGON_SMOOTH_HINT, GL_NICEST);

        //glEnable(GL_BLEND);

        wg_niv_qual = 1;

        //resize(this->width(),this->height());
}

void Tetrahedron::quality_low()
{
        /*if ( is_sample_layer == 1 )
        {
            this->setFormat(QGLFormat(QGL::NoSampleBuffers));
        }*/
        glDisable( GL_SMOOTH );
        glDisable(GL_POINT_SMOOTH);
        glDisable(GL_LINE_SMOOTH);

        glHint(GL_POINT_SMOOTH_HINT, GL_FASTEST);
        glHint(GL_LINE_SMOOTH_HINT, GL_FASTEST);
        glHint(GL_POLYGON_SMOOTH_HINT, GL_FASTEST);

        //glDisable(GL_BLEND);

        wg_niv_qual = 0;

        //resize(this->width(),this->height());
}

void Tetrahedron::resizeGL(int width, int height)
{
    	glViewport(0, 0, width, height);
    	glMatrixMode(GL_PROJECTION);
	glLoadIdentity();
    	GLfloat szx = GLfloat(width) / GLfloat(height);
    	glFrustum(-szx, szx, -1.0, 1.0, 1.9, 30.1);
    	glMatrixMode(GL_MODELVIEW);
}

void Tetrahedron::paintGL()
{
    	glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
    	draw();
}

void Tetrahedron::mousePressEvent(QMouseEvent *event)
{
        int x,y;
        x = event->x();
        y = event->y();

        /*if ( event->button() == Qt::RightButton )
        {
            return;
        }*/

        /*GLuint buff[64] = {0};
        GLint hits, view[4];
        glSelectBuffer(64, buff);
        glGetIntegerv(GL_VIEWPORT, view);
        glRenderMode(GL_SELECT);
        glInitNames();
        glPushName(0);
        glMatrixMode(GL_PROJECTION);
        glPushMatrix();
        glLoadIdentity();
        gluPickMatrix(event->x(), event->y(), 10.0, 10.0, view);
        gluPerspective(60, (float)view[2]/(float)view[3], 0.0001, 1000.0);
        glMatrixMode(GL_MODELVIEW);
        draw();
        glMatrixMode(GL_PROJECTION);
        glPopMatrix();
        hits = glRenderMode(GL_RENDER);
        num_select = (GLubyte)buff[3];

        tab_coo[num_select][3] = event->pos().x();
        tab_coo[num_select][4] = event->pos().y();
        glMatrixMode(GL_MODELVIEW);
        this->repaint();

        emit dia_select(num_select);*/

        glDisable(GL_TEXTURE_2D);
        glDisable(GL_DITHER);
        if ( is_fog > 0 )
        {
            glDisable(GL_FOG);
        }
        //glDisable(GL_LIGHTING);

        draw_select();

        glEnable(GL_TEXTURE_2D);
        glEnable(GL_DITHER);
        if ( is_fog > 0 )
        {
            //GLfloat fogColor[4] = {(float)fog_red/(float)255, (float)fog_green/(float)255, (float)fog_blue/(float)255, 0.8};

            glEnable (GL_FOG);
            //glFogi (GL_FOG_MODE,  GL_EXP2);
            //glFogfv (GL_FOG_COLOR, fogColor);
            //glFogf (GL_FOG_DENSITY, 0.3f);
            //glHint (GL_FOG_HINT, GL_NICEST);
            //glFogf(GL_FOG_START, -6.0f);
            //glFogf(GL_FOG_END, -20.0f);
        }

        GLint viewport[4];
        GLubyte pixel[3];

        glGetIntegerv(GL_VIEWPORT,viewport);

        glReadPixels(x,viewport[3]-y,1,1,GL_RGB,GL_UNSIGNED_BYTE,(void *)pixel);
        //glReadPixels(x,y,1,1,GL_RGB,GL_UNSIGNED_BYTE,(void *)pixel);

        int wl_cur_select = num_select;

        num_select = (pixel[0]-10)/10;

        if ( wl_cur_select != num_select )
        {
            if ( num_select > 0 )
            {
                //tab_coo[num_select][3] = event->pos().x();
                //tab_coo[num_select][4] = event->pos().y();

                emit dia_select(num_select);
            }
            else
            {
                num_select = 0;
                emit dia_select(num_select);
            }
        }

        lastPos = event->pos();

        //glEnable(GL_LIGHTING);
        //updateGL();
        updateGL();

        //emit update_preview();
}

void Tetrahedron::mouseMoveEvent(QMouseEvent *event)
{
        /*if ( event->button() != Qt::LeftButton )
        {
            return;
        }*/
        //GLfloat dx = GLfloat(event->x() - tab_coo[num_select][3]) / width();
        //GLfloat dy = GLfloat(event->y() - tab_coo[num_select][4]) / height();
        GLfloat dx;
        GLfloat dy;

        if ( wg_has_mx == 0 && wg_has_my == 0 && wg_has_mz == 0 )
        {
            dx = GLfloat(event->x() - lastPos.x()) / width();
            dy = GLfloat(event->y() - lastPos.y()) / height();
        }
        else
        {
            if ( wg_has_mx == 1 )
            {
                dx = GLfloat(event->x() - lastPos.x()) / width();
                dy = GLfloat(lastPos.y()/ height());
            }
            else
            {
                if ( wg_has_my == 1 )
                {
                    dy = GLfloat(event->y() - lastPos.y()) / height();
                    dx = GLfloat(lastPos.x()/ width());
                }
            }
        }

        //qDebug() << tool << " " << event->x() << " " << lastPos.x() << " " << width() << "  -  " << event->y() << " " << lastPos.y() << " " << height();

        if ( tool == 0 )
        {
            if (event->buttons() & Qt::LeftButton)
            {
                tab_coo[num_select][0]+= dx*10;
                tab_coo[num_select][1]-= dy*10;
            }
        }
        else
        {
            if ( tool < 4 )
            {
                if ( event->x() > lastPos.x() )
                {
                        tab_coo[num_select][4+tool] = tab_coo[num_select][4+tool] + (1 * (event->x() - lastPos.x()));
                }
                else
                {
                        tab_coo[num_select][4+tool] = tab_coo[num_select][4+tool] - (1 * (lastPos.x() - event->x()));
                }
            }
            else
            {
                if ( event->x() > lastPos.x() )
                {
                        tab_coo[num_select][5] = tab_coo[num_select][5] + (1 * (event->x() - lastPos.x()));
                }
                else
                {
                        tab_coo[num_select][5] = tab_coo[num_select][5] - (1 * (lastPos.x() - event->x()));
                }
                if ( event->y() > lastPos.y() )
                {
                        tab_coo[num_select][6] = tab_coo[num_select][6] + (1 * (event->y() - lastPos.y()));
                }
                else
                {
                        tab_coo[num_select][6] = tab_coo[num_select][6] - (1 * (lastPos.y() - event->y()));
                }
                if ( event->x() > lastPos.y() )
                {
                        tab_coo[num_select][7] = tab_coo[num_select][7] + (1 * (event->x() - lastPos.x()));
                }
                else
                {
                        tab_coo[num_select][7] = tab_coo[num_select][7] - (1 * (lastPos.x() - event->x()));
                }
            }
        }
        //tab_coo[num_select][3] = event->pos().x();
        //tab_coo[num_select][4] = event->pos().y();
        updateGL();

        emit update_coo();

        lastPos = event->pos();
}

void Tetrahedron::wheelEvent(QWheelEvent *event)
{
        if ( num_select > 0 )
        {
            if ( event->delta() > 0 )
            {
                    if ( tab_coo[num_select][2] < -2.2 )
                    {
                            tab_coo[num_select][2]+= 0.1;
                    }
            }
            else
            {
                    if ( tab_coo[num_select][2] > -29.6 )
                    {
                            tab_coo[num_select][2]+= - 0.1;
                    }
            }
            updateGL();
        }
}

// *****************************
// *** FONCTIONS D'AFFICHAGE ***
// *****************************

void Tetrahedron::draw()
{
    if ( bcle_render == 1 )
    {
            glClearAccum(0.0, 0.0, 0.0, 1.0);
            glClear(GL_DEPTH_BUFFER_BIT);
    }

    //glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
    glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT | GL_STENCIL_BUFFER_BIT);
    //glMatrixMode( GL_MODELVIEW );

    int wl_int_001 = 1;
    int wl_int_003 = 1;
    float wdecal = 0;
    float wl_x;

    glInitNames();
    glPushName(-1);

    glEnable(GL_BLEND);
    //glBlendFunc(GL_ONE, GL_ZERO);
    glColor4f(1.0f,1.0f,1.0f,(float)((float)100-(float)tab_coo[wl_int_003][9])/(float)100);
    glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);

    glEnable(GL_CULL_FACE);

    if ( isback == 1 )
    {
        if ( is_anaglyph > 0 )
        {
            for ( int wtest = 0; wtest < 2; wtest++ )
            {
                glColor3f(1.0f,1.0f,1.0f);

                if ( wtest == 0 )
                {
                    glColorMask(og_red, og_green, og_blue, GL_TRUE);
                    //wdecal = -0.01*wg_esp_ana;
                }
                if ( wtest == 1 )
                {
                    glColorMask(od_red, od_green, od_blue, GL_TRUE);
                    wdecal = +0.01*wg_esp_ana;
                }

                glLoadIdentity();

                if ( wtest == 0 )
                {
                    glTranslatef(0.0f,0.0f,-30.0f);
                }
                else
                {
                    glTranslatef(0.0f+wdecal,0.0f,-30.0f);
                }

                glLoadName(0);
                glBindTexture( GL_TEXTURE_2D, texture_diapo[41] );

                if ( wg_fd_tx == wg_fd_ty )
                {
                    ratio_import=1.5;
                }
                else
                {
                    ratio_import = wg_fd_tx/wg_fd_ty;
                }

                glBegin(GL_QUADS);

                //qDebug() << wg_fd_tx << " " << wg_fd_ty;

                glTexCoord2f(wg_fd_tx, -wg_fd_ty);
                glVertex3f(19.0f*ratio_import , -19.0f , 0.0f);

                glTexCoord2f(wg_fd_tx, 0.0);
                glVertex3f(19.0f*ratio_import , 19.0f , 0.0f);

                glTexCoord2f(0.0, 0.0);
                glVertex3f(-19.0f*ratio_import , 19.0f , 0.0f);

                glTexCoord2f(0.0, -wg_fd_ty);
                glVertex3f(-19.0f*ratio_import , -19.0f , 0.0f);

                glEnd();
            }
        }
        else
        {
            glColor3f(1.0f,1.0f,1.0f);

            glLoadIdentity();
            glLoadName(0);
            glBindTexture( GL_TEXTURE_2D, texture_diapo[41] );

            glTranslatef(0.0f,0.0f,-30.0f);

            if ( wg_fd_tx == wg_fd_ty )
            {
                ratio_import=1.5;
            }
            else
            {
                ratio_import = wg_fd_tx/wg_fd_ty;
            }

            glBegin(GL_QUADS);

            //qDebug() << wg_fd_tx << " " << wg_fd_ty;

            glTexCoord2f(wg_fd_tx, -wg_fd_ty);
            glVertex3f(19.0f*ratio_import , -19.0f , 0.0f);

            glTexCoord2f(wg_fd_tx, 0.0);
            glVertex3f(19.0f*ratio_import , 19.0f , 0.0f);

            glTexCoord2f(0.0, 0.0);
            glVertex3f(-19.0f*ratio_import , 19.0f , 0.0f);

            glTexCoord2f(0.0, -wg_fd_ty);
            glVertex3f(-19.0f*ratio_import , -19.0f , 0.0f);

            glEnd();
        }
    }
    else
    {
        glColor3f(1.0f,1.0f,1.0f);

        glLoadIdentity();
        glLoadName(0);
        glBindTexture( GL_TEXTURE_2D, texture_diapo[41] );

        glTranslatef(0.0f,0.0f,-30.0f);

        if ( this->width() == 720 )
        {
            ratio_import=1.0;
        }
        else
        {
            ratio_import=1.778;
        }

        glBegin(GL_QUADS);

        glColor3f(0.0f,0.0f,0.0f);
        glVertex3f(19.75f*ratio_import , -15.8f , 0.0f);

        glColor3f(0.0f,0.0f,0.0f);
        glVertex3f(19.75f*ratio_import , 15.8f , 0.0f);

        glColor3f(0.0f,0.0f,0.0f);
        glVertex3f(-19.75f*ratio_import , 15.8f , 0.0f);

        glColor3f(0.0f,0.0f,0.0f);
        glVertex3f(-19.75f*ratio_import , -15.8f , 0.0f);

        glEnd();
    }

    glDisable(GL_CULL_FACE);

    // *** CLASSEMENT ORDRE Z ***

    while ( wl_int_001 < nombre_diapos+1 )
    {
        tab_order[wl_int_001][0] = 10;
        tab_order[wl_int_001][1] = 0;
        wl_int_001++;
    }

    wl_int_001 = 1;
    int wl_int_002;
    while ( wl_int_001 < nombre_diapos+1 )
    {
        wl_int_002 = 1;
        while ( tab_coo[wl_int_001][2] > tab_order[wl_int_002][0] && tab_order[wl_int_002][1] != 0 )
        {
            wl_int_002++;
        }

        if ( tab_order[wl_int_002][1] < 1 )
        {
            tab_order[wl_int_002][0] = tab_coo[wl_int_001][2];
            tab_order[wl_int_002][1] = wl_int_001;
        }
        else
        {
            wl_int_003 = wl_int_002;
            while ( tab_order[wl_int_003][1] > 0 )
            {
                wl_int_003++;
            }
            while ( wl_int_003 > wl_int_002 )
            {
                tab_order[wl_int_003][0] = tab_order[wl_int_003-1][0];
                tab_order[wl_int_003][1] = tab_order[wl_int_003-1][1];
                wl_int_003--;
            }
            tab_order[wl_int_002][0] = tab_coo[wl_int_001][2];
            tab_order[wl_int_002][1] = wl_int_001;
        }
        wl_int_001++;
    }

    wl_int_001 = 1;
    /*while ( wl_int_001 < nombre_diapos+1 )
    {
        qDebug() << tab_order[wl_int_001][0] << " " << tab_order[wl_int_001][1];
        wl_int_001++;
    }
    wl_int_001 = 1;*/

    if ( is_anaglyph > 0 )
    {
        for ( int wtest = 0; wtest < 2; wtest++ )
        {
            if ( wtest == 0 )
            {
                glColorMask(og_red, og_green, og_blue, GL_TRUE);
                //wdecal = -0.01*wg_esp_ana;
            }
            if ( wtest == 1 )
            {
                glColorMask(od_red, od_green, od_blue, GL_TRUE);
                wdecal = +0.01*wg_esp_ana;
            }

            wl_int_001 = 1;

            QString wl_strtr;

            while ( wl_int_001 < nombre_diapos+1 )
            {
                wl_int_003 = tab_order[wl_int_001][1];

                if ( tab_msk[wl_int_003] == true )
                {
                    if ( tab_diapo[wl_int_003][0].mid(0,1) != "?" || tab_diapo[wl_int_003][0].mid(0,2) == "?9" )
                    {
                        scale_factor = tab_diapo[wl_int_003][5].toFloat();

                        glLoadIdentity();
                        //glColor3f(1.0f,1.0f,1.0f);

                        if ( wtest == 0 )
                        {
                            glTranslatef(tab_coo[wl_int_003][0], tab_coo[wl_int_003][1], tab_coo[wl_int_003][2]);
                            glRotatef(tab_coo[wl_int_003][5], 1.0, 0.0, 0.0);
                            glRotatef(tab_coo[wl_int_003][6], 0.0, 1.0, 0.0);
                            //glRotatef(tab_coo[wl_int_003][7], 0.0, 0.0, 1.0);
                            if ( tab_diapo[wl_int_003][8] == "1" )
                            {
                                glRotatef(tab_coo[wl_int_003][7]+90, 0.0, 0.0, 1.0);
                            }
                            else
                            {
                                if ( tab_diapo[wl_int_003][8] == "2" )
                                {
                                    glRotatef(tab_coo[wl_int_003][7]-90, 0.0, 0.0, 1.0);
                                }
                                else
                                {
                                    glRotatef(tab_coo[wl_int_003][7], 0.0, 0.0, 1.0);
                                }
                            }
                        }
                        else
                        {
                            glTranslatef(tab_coo[wl_int_003][0], tab_coo[wl_int_003][1], tab_coo[wl_int_003][2]);
                            glRotatef(tab_coo[wl_int_003][5], 1.0, 0.0, 0.0);
                            glRotatef(tab_coo[wl_int_003][6], 0.0, 1.0, 0.0);
                            //glRotatef(tab_coo[wl_int_003][7], 0.0, 0.0, 1.0);
                            if ( tab_diapo[wl_int_003][8] == "1" )
                            {
                                glRotatef(tab_coo[wl_int_003][7]+90, 0.0, 0.0, 1.0);
                            }
                            else
                            {
                                if ( tab_diapo[wl_int_003][8] == "2" )
                                {
                                    glRotatef(tab_coo[wl_int_003][7]-90, 0.0, 0.0, 1.0);
                                }
                                else
                                {
                                    glRotatef(tab_coo[wl_int_003][7], 0.0, 0.0, 1.0);
                                }
                            }
                            if ( tab_diapo[wl_int_003][8] == "0" )
                            {
                                glTranslatef(wdecal, 0.0, 0.0);
                            }
                            else
                            {
                                glTranslatef(0.0, wdecal, 0.0);
                            }
                        }

                        glLoadName(wl_int_003);

                        if ( tab_coo[wl_int_003][11] >= 0 && wtest == 0 )
                        {
                            //qDebug() << "APPMSK=" << wl_int_003 << " " << tab_coo[wl_int_003][11];
                            f_apply_mask(wl_int_003,tab_coo[wl_int_003][11]);
                        }

                        glBindTexture( GL_TEXTURE_2D, texture_diapo[wl_int_003] );
                        //qDebug() << "TRA=" << tab_coo[wl_int_003][9];
                        glColor4f(1.0f,1.0f,1.0f,(float)((float)100-(float)tab_coo[wl_int_003][9])/(float)100);
                        glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);

                        glBegin(GL_QUADS);

                        wl_strtr = QString::number(tab_coo[wl_int_003][8]);

                        if ( wl_strtr.mid(0,1).toInt() < 2 || tab_coo[wl_int_003][11] >= 0 )
                        {
                            if ( tab_diapo[wl_int_003][7] == "0/0/0/0" )
                            {
                                wl_x = (float)(0-(2 * (tab_diapo[wl_int_003][1].toFloat() / tab_diapo[wl_int_003][2].toFloat()))) * -1;
                            }
                            else
                            {
                                QStringList wl_explode = tab_diapo[wl_int_003][7].split("/",QString::KeepEmptyParts);

                                wl_x = (float)(0-(2 * ((wl_explode.at(2).toFloat()-wl_explode.at(0).toFloat()) / (wl_explode.at(3).toFloat()-wl_explode.at(1).toFloat())))) * -1;
                            }

                            if ( wl_int_003 == num_select )
                            {
                                tab_coo_select[0][0] = tab_coo[wl_int_003][0];
                                tab_coo_select[0][1] = tab_coo[wl_int_003][1];
                                tab_coo_select[0][2] = tab_coo[wl_int_003][2];
                                tab_coo_select[0][5] = tab_coo[wl_int_003][5];
                                tab_coo_select[0][6] = tab_coo[wl_int_003][6];
                                tab_coo_select[0][7] = tab_coo[wl_int_003][7];
                                tab_coo_select[0][8] = scale_factor*.8;
                                tab_coo_select[0][9] = wl_x;
                            }
                            /*glTexCoord2f(1.0, 0.0);
                            glVertex3f(wl_x*scale_factor , -2.0f*scale_factor , 0.0f);

                            glTexCoord2f(1.0, 1.0);
                            glVertex3f(wl_x*scale_factor , 2.0f*scale_factor , 0.0f);

                            glTexCoord2f(0.0, 1.0);
                            glVertex3f(-wl_x*scale_factor , 2.0f*scale_factor , 0.0f);

                            glTexCoord2f(0.0, 0.0);
                            glVertex3f(-wl_x*scale_factor , -2.0f*scale_factor , 0.0f);*/

                            if ( tab_diapo[wl_int_003][1].toFloat() > tab_diapo[wl_int_003][2].toFloat() )
                            {
                                wg_tx = 1.0;
                                wg_ty = (float)((float)tab_diapo[wl_int_003][2].toFloat()/(float)1024);
                            }
                            else
                            {
                                wg_ty = 1.0;
                                wg_tx = (float)((float)tab_diapo[wl_int_003][1].toFloat()/(float)1024);
                            }

                            //glBindTexture( GL_TEXTURE_2D, texture_diapo[wl_int_003] );
                            glTexCoord2f(wg_tx, -wg_ty);
                            glVertex3f(wl_x*scale_factor , -2.0f*scale_factor , 0.0f);

                            glTexCoord2f(wg_tx, 0.0);
                            glVertex3f(wl_x*scale_factor , 2.0f*scale_factor , 0.0f);

                            glTexCoord2f(0.0, 0.0);
                            glVertex3f(-wl_x*scale_factor , 2.0f*scale_factor , 0.0f);

                            glTexCoord2f(0.0, -wg_ty);
                            glVertex3f(-wl_x*scale_factor , -2.0f*scale_factor , 0.0f);
                        }

                        glEnd();

                        if ( tab_diapo[wl_int_003][6] != "0" ) // *** REFLECT ***
                        {
                            if ( tab_diapo[wl_int_003][8] == "1" )
                            {
                                glRotatef(tab_coo[wl_int_003][7]-180, 0.0, 0.0, 1.0);
                                glTranslatef(+(wl_x*2)*scale_factor, 0.0, 0.0);
                                glScalef(1.0, -1.0, 1.0);

                                glShadeModel(GL_SMOOTH);

                                glBegin(GL_QUADS);

                                if ( wl_strtr.mid(0,1).toInt() < 2 || tab_coo[wl_int_003][11] >= 0 )
                                {
                                    /*glColor4f(1.0,1.0,1.0,0.0);
                                    glTexCoord2f(1.0, 0.0);
                                    glVertex3f(wl_x*scale_factor , -2.0f*scale_factor , 0.0f);

                                    glColor4f(1.0,1.0,1.0,0.0);
                                    glTexCoord2f(1.0, 1.0);
                                    glVertex3f(wl_x*scale_factor , 2.0f*scale_factor , 0.0f);

                                    glColor4f(1.0,1.0,1.0,0.4*((float)((float)100-(float)tab_coo[wl_int_003][9])/(float)100));
                                    glTexCoord2f(0.0, 1.0);
                                    glVertex3f(-wl_x*scale_factor , 2.0f*scale_factor , 0.0f);

                                    glColor4f(1.0,1.0,1.0,0.4*((float)((float)100-(float)tab_coo[wl_int_003][9])/(float)100));
                                    glTexCoord2f(0.0, 0.0);
                                    glVertex3f(-wl_x*scale_factor , -2.0f*scale_factor , 0.0f);*/

                                    glColor4f(1.0,1.0,1.0,0.0);
                                    //glTexCoord2f(1.0, 0.0);
                                    glTexCoord2f(wg_tx, -wg_ty);
                                    glVertex3f(wl_x*scale_factor , -2.0f*scale_factor , 0.0f);

                                    glColor4f(1.0,1.0,1.0,0.0);
                                    //glTexCoord2f(1.0, 1.0);
                                    glTexCoord2f(wg_tx, 0.0);
                                    glVertex3f(wl_x*scale_factor , 2.0f*scale_factor , 0.0f);

                                    glColor4f(1.0,1.0,1.0,0.4*((float)((float)100-(float)tab_coo[wl_int_003][9])/(float)100));
                                    //glTexCoord2f(0.0, 1.0);
                                    glTexCoord2f(0.0, 0.0);
                                    glVertex3f(-wl_x*scale_factor , 2.0f*scale_factor , 0.0f);

                                    glColor4f(1.0,1.0,1.0,0.4*((float)((float)100-(float)tab_coo[wl_int_003][9])/(float)100));
                                    //glTexCoord2f(0.0, 0.0);
                                    glTexCoord2f(0.0, -wg_ty);
                                    glVertex3f(-wl_x*scale_factor , -2.0f*scale_factor , 0.0f);
                                }
                            }
                            else
                            {
                                if ( tab_diapo[wl_int_003][8] == "2" )
                                {
                                    glRotatef(tab_coo[wl_int_003][7]+180, 0.0, 0.0, 1.0);
                                    glTranslatef(-(wl_x*1.5)*scale_factor, 0.0, 0.0);
                                    glScalef(1.0, -1.0, 1.0);

                                    glShadeModel(GL_SMOOTH);

                                    glBegin(GL_QUADS);

                                    if ( wl_strtr.mid(0,1).toInt() < 2 || tab_coo[wl_int_003][11] >= 0 )
                                    {
                                        glColor4f(1.0,1.0,1.0,0.4*((float)((float)100-(float)tab_coo[wl_int_003][9])/(float)100));
                                        glTexCoord2f(wg_tx, -wg_ty);
                                        glVertex3f(wl_x*scale_factor/2 , -2.0f*scale_factor , 0.0f);

                                        glColor4f(1.0,1.0,1.0,0.4*((float)((float)100-(float)tab_coo[wl_int_003][9])/(float)100));
                                        glTexCoord2f(wg_tx, 0.0);
                                        glVertex3f(wl_x*scale_factor/2 , 2.0f*scale_factor , 0.0f);

                                        glColor4f(1.0,1.0,1.0,0.0);
                                        glTexCoord2f(wg_tx/2, 0.0);

                                        glVertex3f(-wl_x*scale_factor/2 , 2.0f*scale_factor , 0.0f);

                                        glColor4f(1.0,1.0,1.0,0.0);
                                        glTexCoord2f(wg_tx/2, -wg_ty);
                                        glVertex3f(-wl_x*scale_factor/2 , -2.0f*scale_factor , 0.0f);
                                    }
                                }
                                else
                                {
                                    glTranslatef(0.0, -3.0f*scale_factor, 0.0);
                                    glScalef(1.0, -1.0, 1.0);

                                    glShadeModel(GL_SMOOTH);

                                    glBegin(GL_QUADS);

                                    if ( wl_strtr.mid(0,1).toInt() < 2 || tab_coo[wl_int_003][11] >= 0 )
                                    {
                                        glColor4f(1.0,1.0,1.0,0.4*((float)((float)100-(float)tab_coo[wl_int_003][9])/(float)100));
                                        glTexCoord2f(wg_tx, -wg_ty);
                                        glVertex3f(wl_x*scale_factor , -1.0f*scale_factor , 0.0f);

                                        glColor4f(1.0,1.0,1.0,0.0);
                                        glTexCoord2f(wg_tx, -wg_ty/2);
                                        glVertex3f(wl_x*scale_factor , 1.0f*scale_factor , 0.0f);

                                        glColor4f(1.0,1.0,1.0,0.0);
                                        glTexCoord2f(0.0, -wg_ty/2);
                                        glVertex3f(-wl_x*scale_factor , 1.0f*scale_factor , 0.0f);

                                        glColor4f(1.0,1.0,1.0,0.4*((float)((float)100-(float)tab_coo[wl_int_003][9])/(float)100));
                                        glTexCoord2f(0.0, -wg_ty);
                                        glVertex3f(-wl_x*scale_factor , -1.0f*scale_factor , 0.0f);
                                    }
                                }
                            }

                            glEnd();
                            glShadeModel(GL_FLAT);
                        }

                        /*if ( tab_diapo[wl_int_003][6] != "0" ) // *** REFLECT ***
                        {
                            glTranslatef(0.0, -3.0f*scale_factor, 0.0);
                            glScalef(1.0, -1.0, 1.0);

                            glShadeModel(GL_SMOOTH);

                            //glColor4f(1.0f,1.0f,1.0f,(float)((float)100-(float)tab_coo[wl_int_003][9])/(float)100);
                            //glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
                            glBegin(GL_QUADS);

                            if ( tab_coo[wl_int_003][8] > 0 )
                            {

                                //float wl_x = (float)(0-(2 * (tab_diapo[wl_int_003][1].toFloat() / tab_diapo[wl_int_003][2].toFloat()))) * -1;
                                if ( tab_diapo[wl_int_003][7] == "0/0/0/0" )
                                {
                                    wl_x = (float)(0-(2 * (tab_diapo[wl_int_003][1].toFloat() / tab_diapo[wl_int_003][2].toFloat()))) * -1;
                                }
                                else
                                {
                                    QStringList wl_explode = tab_diapo[wl_int_003][7].split("/",QString::KeepEmptyParts);

                                    wl_x = (float)(0-(2 * ((wl_explode.at(2).toFloat()-wl_explode.at(0).toFloat()) / (wl_explode.at(3).toFloat()-wl_explode.at(1).toFloat())))) * -1;
                                }

                                glColor4f(1.0,1.0,1.0,0.4*((float)((float)100-(float)tab_coo[wl_int_003][9])/(float)100));
                                glTexCoord2f(1.0, 0.0);
                                glVertex3f(wl_x*scale_factor , -1.0f*scale_factor , 0.0f);

                                glColor4f(1.0,1.0,1.0,0.0);
                                glTexCoord2f(1.0, 0.4);
                                glVertex3f(wl_x*scale_factor , 1.0f*scale_factor , 0.0f);

                                glColor4f(1.0,1.0,1.0,0.0);
                                glTexCoord2f(0.0, 0.4);
                                glVertex3f(-wl_x*scale_factor , 1.0f*scale_factor , 0.0f);

                                glColor4f(1.0,1.0,1.0,0.4*((float)((float)100-(float)tab_coo[wl_int_003][9])/(float)100));
                                glTexCoord2f(0.0, 0.0);
                                glVertex3f(-wl_x*scale_factor , -1.0f*scale_factor , 0.0f);
                            }

                            glEnd();
                            glShadeModel(GL_FLAT);
                        }*/
                    }
                    else
                    {
                        // *********************
                        // *** AUTRES OBJETS ***
                        // *********************
                        scale_factor = tab_diapo[wl_int_003][5].toFloat();

                        if ( wl_int_003 == num_select )
                        {
                            tab_coo_select[0][0] = tab_coo[wl_int_003][0];
                            tab_coo_select[0][1] = tab_coo[wl_int_003][1];
                            tab_coo_select[0][2] = tab_coo[wl_int_003][2];
                            tab_coo_select[0][5] = tab_coo[wl_int_003][5];
                            tab_coo_select[0][6] = tab_coo[wl_int_003][6];
                            tab_coo_select[0][7] = tab_coo[wl_int_003][7];
                            tab_coo_select[0][8] = scale_factor*.8;
                        }

                        glEnable( GL_LIGHTING ) ;
                        glEnable( GL_LIGHT0 );
                        glDisable(GL_TEXTURE_2D);

                        glColor3f(1.0f,1.0f,1.0f);
                        glLoadIdentity();
                        glEnable(GL_CULL_FACE);
                        GLfloat light_position[] = { 1.0, 1.0, 1.0, 0.0 };

                        if ( wtest == 0 )
                        {
                            glTranslatef(tab_coo[wl_int_003][0], tab_coo[wl_int_003][1], tab_coo[wl_int_003][2]);
                            glRotatef(tab_coo[wl_int_003][5], 1.0, 0.0, 0.0);
                            glRotatef(tab_coo[wl_int_003][6], 0.0, 1.0, 0.0);
                            glRotatef(tab_coo[wl_int_003][7], 0.0, 0.0, 1.0);

                        }
                        else
                        {
                            glTranslatef(tab_coo[wl_int_003][0], tab_coo[wl_int_003][1], tab_coo[wl_int_003][2]);
                            glRotatef(tab_coo[wl_int_003][5], 1.0, 0.0, 0.0);
                            glRotatef(tab_coo[wl_int_003][6], 0.0, 1.0, 0.0);
                            glRotatef(tab_coo[wl_int_003][7], 0.0, 0.0, 1.0);
                            glTranslatef(wdecal, 0.0, 0.0);
                        }

                        if ( tab_diapo[wl_int_003][0].mid(1,1) == "1" )
                        {
                            glLoadName(wl_int_003);

                            glColorMaterial ( GL_FRONT_AND_BACK, GL_AMBIENT_AND_DIFFUSE );
                            glLightfv(GL_LIGHT0, GL_POSITION, light_position);

                            GLfloat light_ambient[] = { 0.4, 0.0, 0.0, 1.0};
                            glLightfv(GL_LIGHT0, GL_AMBIENT, light_ambient);

                            glTranslatef(0, 0, -2.5*scale_factor);

                            glColor3ub(200,0,0);
                            quadric = gluNewQuadric();
                            gluQuadricNormals(quadric, GLU_SMOOTH );

                            gluCylinder(quadric, .5*scale_factor, .5*scale_factor, 5*scale_factor, 8, 2);

                            glTranslatef(0, 0, 5*scale_factor);
                            glColor3ub(240,215,160);
                            gluCylinder(quadric, .5*scale_factor, 0*scale_factor, 1*scale_factor, 8, 2);

                            glTranslatef(0, 0, 0.5*scale_factor);
                            glColor3ub(200,0,0);
                            gluCylinder(quadric, .25*scale_factor, 0*scale_factor, 0.5*scale_factor, 10, 2);

                            glTranslatef(0, 0, -5.5*scale_factor);
                            glColor3ub(200,0,0);
                            glRotatef(180, 0, 1, 0);
                            gluDisk(quadric,0,0.5*scale_factor,8*scale_factor,8*scale_factor);

                            glDisable(GL_CULL_FACE);
                            glDisable( GL_LIGHTING ) ;
                            glDisable( GL_LIGHT0 );
                        }
                        else
                        {
                            if ( tab_diapo[wl_int_003][0].mid(1,1) == "2" )
                            {
                                glLoadName(wl_int_003);

                                glColorMaterial ( GL_FRONT_AND_BACK, GL_AMBIENT_AND_DIFFUSE );
                                glLightfv(GL_LIGHT0, GL_POSITION, light_position);

                                GLfloat light_ambient[] = { 0.0, 0.4, 0.0, 1.0};
                                glLightfv(GL_LIGHT0, GL_AMBIENT, light_ambient);

                                glTranslatef(0, 0, -2.5*scale_factor);

                                glColor3ub(0,200,0);
                                quadric = gluNewQuadric();
                                gluQuadricNormals(quadric, GLU_SMOOTH );

                                gluCylinder(quadric, .5*scale_factor, .5*scale_factor, 5*scale_factor, 8, 2);

                                glTranslatef(0, 0, 5*scale_factor);
                                glColor3ub(240,215,160);
                                gluCylinder(quadric, .5*scale_factor, 0*scale_factor, 1*scale_factor, 8, 2);

                                glTranslatef(0, 0, 0.5*scale_factor);
                                glColor3ub(0,200,0);
                                gluCylinder(quadric, .25*scale_factor, 0*scale_factor, 0.5*scale_factor, 10, 2);

                                glTranslatef(0, 0, -5.5*scale_factor);
                                glColor3ub(0,200,0);
                                glRotatef(180, 0, 1, 0);
                                gluDisk(quadric,0,0.5*scale_factor,8*scale_factor,8*scale_factor);

                                glDisable(GL_CULL_FACE);
                                glDisable( GL_LIGHTING ) ;
                                glDisable( GL_LIGHT0 );
                            }
                            else
                            {
                                if ( tab_diapo[wl_int_003][0].mid(1,1) == "3" )
                                {
                                    glLoadName(wl_int_003);

                                    glColorMaterial ( GL_FRONT_AND_BACK, GL_AMBIENT_AND_DIFFUSE );
                                    glLightfv(GL_LIGHT0, GL_POSITION, light_position);

                                    GLfloat light_ambient[] = { 0.0, 0.0, 0.4, 1.0};
                                    glLightfv(GL_LIGHT0, GL_AMBIENT, light_ambient);

                                    glTranslatef(0, 0, -2.5*scale_factor);

                                    glColor3ub(0,0,200);
                                    quadric = gluNewQuadric();
                                    gluQuadricNormals(quadric, GLU_SMOOTH );

                                    gluCylinder(quadric, .5*scale_factor, .5*scale_factor, 5*scale_factor, 8, 2);

                                    glTranslatef(0, 0, 5*scale_factor);
                                    glColor3ub(240,215,160);
                                    gluCylinder(quadric, .5*scale_factor, 0*scale_factor, 1*scale_factor, 8, 2);

                                    glTranslatef(0, 0, 0.5*scale_factor);
                                    glColor3ub(0,0,200);
                                    gluCylinder(quadric, .25*scale_factor, 0*scale_factor, 0.5*scale_factor, 10, 2);

                                    glTranslatef(0, 0, -5.5*scale_factor);
                                    glColor3ub(0,0,200);
                                    glRotatef(180, 0, 1, 0);
                                    gluDisk(quadric,0,0.5*scale_factor,8*scale_factor,8*scale_factor);

                                    glDisable(GL_CULL_FACE);
                                    glDisable( GL_LIGHTING ) ;
                                    glDisable( GL_LIGHT0 );
                                }
                                else
                                {
                                    if ( tab_diapo[wl_int_003][0].mid(1,1) == "4" )
                                    {
                                        glLoadName(wl_int_003);

                                        glColorMaterial ( GL_FRONT_AND_BACK, GL_AMBIENT_AND_DIFFUSE );
                                        glLightfv(GL_LIGHT0, GL_POSITION, light_position);

                                        GLfloat light_ambient[] = { 0.4, 0.4, 0.4, 1.0};
                                        glLightfv(GL_LIGHT0, GL_AMBIENT, light_ambient);

                                        glTranslatef(0, 0, -2.5*scale_factor);

                                        glColor3ub(200,200,200);
                                        quadric = gluNewQuadric();
                                        gluQuadricNormals(quadric, GLU_SMOOTH );

                                        gluCylinder(quadric, .5*scale_factor, .5*scale_factor, 5*scale_factor, 8, 2);

                                        glTranslatef(0, 0, 5*scale_factor);
                                        glColor3ub(240,215,160);
                                        gluCylinder(quadric, .5*scale_factor, 0*scale_factor, 1*scale_factor, 8, 2);

                                        glTranslatef(0, 0, 0.5*scale_factor);
                                        glColor3ub(200,200,200);
                                        gluCylinder(quadric, .25*scale_factor, 0*scale_factor, 0.5*scale_factor, 10, 2);

                                        glTranslatef(0, 0, -5.5*scale_factor);
                                        glColor3ub(200,200,200);
                                        glRotatef(180, 0, 1, 0);
                                        gluDisk(quadric,0,0.5*scale_factor,8*scale_factor,8*scale_factor);

                                        glDisable(GL_CULL_FACE);
                                        glDisable( GL_LIGHTING ) ;
                                        glDisable( GL_LIGHT0 );
                                    }
                                    else
                                    {
                                        if ( tab_diapo[wl_int_003][0].mid(1,1) == "5" ) // *** HOMME DES NEIGES ANAGLYPH ***
                                        {                                           
                                            glEnable( GL_LIGHTING ) ;
                                            glEnable( GL_LIGHT0 );
                                            glDisable(GL_TEXTURE_2D);
                                            glEnable(GL_CULL_FACE);

                                            glColor3f(1.0f,1.0f,1.0f);
                                            glEnable(GL_CULL_FACE);
                                            GLfloat light_position[] = { 1.0, 1.0, 1.0, 0.0 };

                                            glLoadName(wl_int_003);

                                            glColorMaterial ( GL_FRONT_AND_BACK, GL_AMBIENT_AND_DIFFUSE );
                                            glLightfv(GL_LIGHT0, GL_POSITION, light_position);

                                            GLfloat light_ambient[] = { 0.4, 0.4, 0.4, 1.0};
                                            glLightfv(GL_LIGHT0, GL_AMBIENT, light_ambient);

                                            glColor3f(1.0f, 1.0f, 1.0f);
                                            quadric = gluNewQuadric();
                                            gluQuadricNormals(quadric, GLU_SMOOTH );

                                            glTranslatef(0.0f ,0.75f*scale_factor, 0.0f);
                                            gluSphere(quadric,0.75f*scale_factor,32,32);

                                            glTranslatef(0.0f, 0.95f*scale_factor, 0.0f);
                                            gluSphere(quadric,0.25f*scale_factor,32,32);

                                            glColor3f(0.0f,0.0f,0.0f);
                                            glTranslatef(0.1f*scale_factor, 0.0f, 0.18f*scale_factor);
                                            gluSphere(quadric,0.05f*scale_factor,10,10);
                                            glTranslatef(-0.2f*scale_factor, 0.0f, 0.0f);
                                            gluSphere(quadric,0.05f*scale_factor,10,10);

                                            glColor3f(1.0f, 0.5f , 0.5f);
                                            glTranslatef(0.1f*scale_factor, -0.08f*scale_factor, 0.0f);
                                            glRotatef(0.0f,1.0f, 0.0f, 0.0f);
                                            gluCylinder(quadric, 0.06*scale_factor, 0.0, 0.2*scale_factor, 8, 2);

                                            glDisable( GL_LIGHTING ) ;
                                            glDisable( GL_LIGHT0 );
                                            glEnable(GL_TEXTURE_2D);
                                            glDisable(GL_CULL_FACE);
                                        }
                                        else
                                        {                                           
                                            if ( tab_diapo[wl_int_003][0].mid(1,1) == "6" )
                                            {
                                                glDisable( GL_LIGHTING ) ;
                                                glDisable( GL_LIGHT0 );
                                                glEnable(GL_TEXTURE_2D);

                                                glLoadName(wl_int_003);

                                                // *** FACE ARRIERE ***

                                                glBindTexture( GL_TEXTURE_2D, texture_diapo_cube[0] );

                                                glBegin(GL_QUADS);

                                                glColor4f(1.0,1.0,1.0,1.0);
                                                glTexCoord2f(0.0, 1.0);
                                                glVertex3f(-1.0f * scale_factor, -1.0f * scale_factor, -1.0f * scale_factor );

                                                glColor4f(1.0,1.0,1.0,1.0);
                                                glTexCoord2f(0.0, 0.0);
                                                glVertex3f(-1.0f * scale_factor,  1.0f * scale_factor, -1.0f * scale_factor );

                                                glColor4f(1.0,1.0,1.0,1.0);
                                                glTexCoord2f(1.0, 0.0);
                                                glVertex3f( 1.0f * scale_factor,  1.0f * scale_factor, -1.0f * scale_factor );

                                                glColor4f(1.0,1.0,1.0,1.0);
                                                glTexCoord2f(1.0, 1.0);
                                                glVertex3f( 1.0f * scale_factor, -1.0f * scale_factor, -1.0f * scale_factor );

                                                glEnd();

                                                // *** FACE DU HAUT ***
                                                glBindTexture( GL_TEXTURE_2D, texture_diapo_cube[1] );

                                                glBegin(GL_QUADS);

                                                glColor4f(1.0,1.0,1.0,1.0);
                                                glTexCoord2f(0.0, 1.0);
                                                glVertex3f(-1.0f * scale_factor,  1.0f * scale_factor , -1.0f * scale_factor );

                                                glColor4f(1.0,1.0,1.0,1.0);
                                                glTexCoord2f(0.0, 0.0);
                                                glVertex3f(-1.0f * scale_factor,  1.0f * scale_factor ,  1.0f * scale_factor );

                                                glColor4f(1.0,1.0,1.0,1.0);
                                                glTexCoord2f(1.0, 0.0);
                                                glVertex3f( 1.0f * scale_factor,  1.0f * scale_factor ,  1.0f * scale_factor );

                                                glColor4f(1.0,1.0,1.0,1.0);
                                                glTexCoord2f(1.0, 1.0);
                                                glVertex3f( 1.0f * scale_factor,  1.0f * scale_factor , -1.0f * scale_factor );

                                                glEnd();

                                                // *** FACE DU BAS ***
                                                glBindTexture( GL_TEXTURE_2D, texture_diapo_cube[2] );

                                                glBegin(GL_QUADS);

                                                glColor4f(1.0,1.0,1.0,1.0);
                                                glTexCoord2f(1.0, 1.0);
                                                glVertex3f(-1.0f * scale_factor , -1.0f * scale_factor , -1.0f * scale_factor );

                                                glColor4f(1.0,1.0,1.0,1.0);
                                                glTexCoord2f(0.0, 1.0);
                                                glVertex3f( 1.0f * scale_factor , -1.0f * scale_factor , -1.0f * scale_factor );

                                                glColor4f(1.0,1.0,1.0,1.0);
                                                glTexCoord2f(0.0, 0.0);
                                                glVertex3f( 1.0f * scale_factor , -1.0f * scale_factor ,  1.0f * scale_factor );

                                                glColor4f(1.0,1.0,1.0,1.0);
                                                glTexCoord2f(1.0, 0.0);
                                                glVertex3f(-1.0f * scale_factor , -1.0f * scale_factor ,  1.0f * scale_factor );

                                                glEnd();

                                                // *** FACE DE GAUCHE ***
                                                glBindTexture( GL_TEXTURE_2D, texture_diapo_cube[3] );

                                                glBegin(GL_QUADS);

                                                glColor4f(1.0,1.0,1.0,1.0);
                                                glTexCoord2f(0.0, 1.0);

                                                glVertex3f(-1.0f * scale_factor , -1.0f * scale_factor, -1.0f * scale_factor );

                                                glColor4f(1.0,1.0,1.0,1.0);
                                                glTexCoord2f(0.0, 0.0);
                                                glVertex3f(-1.0f * scale_factor , -1.0f * scale_factor,  1.0f * scale_factor );

                                                glColor4f(1.0,1.0,1.0,1.0);
                                                glTexCoord2f(1.0, 0.0);
                                                glVertex3f(-1.0f * scale_factor ,  1.0f * scale_factor,  1.0f * scale_factor );

                                                glColor4f(1.0,1.0,1.0,1.0);
                                                glTexCoord2f(1.0, 1.0);
                                                glVertex3f(-1.0f * scale_factor ,  1.0f * scale_factor, -1.0f * scale_factor );

                                                glEnd();

                                                // *** FACE DE DROITE ***
                                                glBindTexture( GL_TEXTURE_2D, texture_diapo_cube[4] );

                                                glBegin(GL_QUADS);

                                                glColor4f(1.0,1.0,1.0,1.0);
                                                glTexCoord2f(1.0, 1.0);
                                                glVertex3f( 1.0f * scale_factor , -1.0f * scale_factor , -1.0f * scale_factor );

                                                glColor4f(1.0,1.0,1.0,1.0);
                                                glTexCoord2f(0.0, 1.0);
                                                glVertex3f( 1.0f * scale_factor ,  1.0f * scale_factor , -1.0f * scale_factor );

                                                glColor4f(1.0,1.0,1.0,1.0);
                                                glTexCoord2f(0.0, 0.0);
                                                glVertex3f( 1.0f * scale_factor ,  1.0f * scale_factor ,  1.0f * scale_factor );

                                                glColor4f(1.0,1.0,1.0,1.0);
                                                glTexCoord2f(1.0, 0.0);
                                                glVertex3f( 1.0f * scale_factor , -1.0f * scale_factor ,  1.0f * scale_factor );

                                                glEnd();

                                                // *** FACE AVANT ***
                                                glBindTexture( GL_TEXTURE_2D, texture_diapo_cube[5] );

                                                glBegin(GL_QUADS);

                                                glColor4f(1.0,1.0,1.0,1.0);
                                                glTexCoord2f(0.0, 0.0);
                                                glVertex3f(-1.0f * scale_factor , -1.0f * scale_factor ,  1.0f * scale_factor );

                                                glColor4f(1.0,1.0,1.0,1.0);
                                                glTexCoord2f(1.0, 0.0);
                                                glVertex3f( 1.0f * scale_factor , -1.0f * scale_factor ,  1.0f * scale_factor );

                                                glColor4f(1.0,1.0,1.0,1.0);
                                                glTexCoord2f(1.0, 1.0);
                                                glVertex3f( 1.0f * scale_factor ,  1.0f * scale_factor ,  1.0f * scale_factor );

                                                glColor4f(1.0,1.0,1.0,1.0);
                                                glTexCoord2f(0.0, 1.0);
                                                glVertex3f(-1.0f * scale_factor ,  1.0f * scale_factor ,  1.0f * scale_factor );

                                                glEnd();

                                                glEnable(GL_TEXTURE_2D);
                                                glDisable(GL_CULL_FACE);
                                            }
                                            else
                                            {
                                                if ( tab_diapo[wl_int_003][0].mid(1,1) == "7" )
                                                {
                                                    glDisable( GL_LIGHTING ) ;
                                                    glDisable( GL_LIGHT0 );
                                                    glEnable(GL_TEXTURE_2D);

                                                    glColor3f(1.0f,1.0f,1.0f);
                                                    glEnable(GL_CULL_FACE);
                                                    //GLfloat light_position[] = { 1.0, 1.0, 1.0, 0.0 };

                                                    glLoadName(wl_int_003);

                                                    /*glColorMaterial ( GL_FRONT_AND_BACK, GL_AMBIENT_AND_DIFFUSE );
                                                    glLightfv(GL_LIGHT0, GL_POSITION, light_position);

                                                    GLfloat light_ambient[] = { 0.4, 0.4, 0.4, 1.0};
                                                    glLightfv(GL_LIGHT0, GL_AMBIENT, light_ambient);*/

                                                    //glTranslatef(0, 0, -2.5*scale_factor);

                                                    glColor3ub(200,200,200);
                                                    quadric = gluNewQuadric();
                                                    gluQuadricNormals(quadric, GLU_SMOOTH );

                                                    gluQuadricTexture(quadric,GL_TRUE);
                                                    glBindTexture(GL_TEXTURE_2D,texture_diapo[44]);
                                                    gluSphere(quadric,1.0f*scale_factor,25,25);

                                                    //glDisable( GL_LIGHTING ) ;
                                                    //glDisable( GL_LIGHT0 );
                                                }
                                                else
                                                {
                                                    if ( tab_diapo[wl_int_003][0].mid(1,1) == "8" )
                                                    {
                                                        glEnable( GL_LIGHTING ) ;
                                                        glEnable( GL_LIGHT0 );
                                                        glEnable(GL_TEXTURE_2D);

                                                        glColor3f(1.0f,1.0f,1.0f);
                                                        glDisable(GL_CULL_FACE);
                                                        //GLfloat light_position[] = { 1.0, 1.0, 1.0, 0.0 };

                                                        glLoadName(wl_int_003);

                                                        glColorMaterial ( GL_FRONT_AND_BACK, GL_AMBIENT_AND_DIFFUSE );
                                                        //glLightfv(GL_LIGHT0, GL_POSITION, light_position);

                                                        GLfloat light_ambient[] = { 1.0, 1.0, 1.0, 1.0};
                                                        glLightfv(GL_LIGHT0, GL_AMBIENT, light_ambient);

                                                        //glTranslatef(0, 0, -2.5*scale_factor);

                                                        glBegin(GL_TRIANGLE_STRIP);

                                                        glColor3f(255,255,255);

                                                        glVertex3f(-7.0*scale_factor, 0.0*scale_factor, 2.0*scale_factor);
                                                        glVertex3f(-1.0*scale_factor, 0.0*scale_factor, 3.0*scale_factor);
                                                        glVertex3f(-1.0*scale_factor, 7.0*scale_factor, 3.0*scale_factor);
                                                        glVertex3f(0.0*scale_factor, 0.0*scale_factor, 0.0*scale_factor);
                                                        glVertex3f(0.0*scale_factor, 8.0*scale_factor, 0.0*scale_factor);
                                                        glVertex3f(1.0*scale_factor, 0.0*scale_factor, 3.0*scale_factor);
                                                        glVertex3f(1.0*scale_factor, 7.0*scale_factor, 3.0*scale_factor);
                                                        glVertex3f(7.0*scale_factor, 0.0*scale_factor, 2.0*scale_factor);

                                                        glEnd();

                                                        glDisable( GL_LIGHTING ) ;
                                                        glDisable( GL_LIGHT0 );
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                        glEnable(GL_TEXTURE_2D);
                    }

                    /*if ( wl_int_003 == num_select )
                    {
                        glLoadIdentity();

                        glTranslatef(tab_coo_select[0][0], tab_coo_select[0][1], tab_coo_select[0][2]+0.2);
                        glRotatef(tab_coo_select[0][5], 1.0, 0.0, 0.0);
                        glRotatef(tab_coo_select[0][6], 0.0, 1.0, 0.0);
                        glRotatef(tab_coo_select[0][7], 0.0, 0.0, 1.0);

                        glLoadName(42);
                        glBindTexture( GL_TEXTURE_2D, texture_diapo[42] );
                        glColor4f(1.0f,1.0f,1.0f,1.0f);
                        glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);

                        glBegin(GL_QUADS);

                        glTexCoord2f(1.0, 0.0);
                        glVertex3f(1.0f*tab_coo_select[0][8], -1.0f*tab_coo_select[0][8] , 0.0f);

                        glTexCoord2f(1.0, 1.0);
                        glVertex3f(1.0f*tab_coo_select[0][8] , 1.0f*tab_coo_select[0][8] , 0.0f);

                        glTexCoord2f(0.0, 1.0);
                        glVertex3f(-1.0f*tab_coo_select[0][8] , 1.0f*tab_coo_select[0][8] , 0.0f);

                        glTexCoord2f(0.0, 0.0);
                        glVertex3f(-1.0f*tab_coo_select[0][8] , -1.0f*tab_coo_select[0][8] , 0.0f);
                        glEnd();
                    }*/
                }
                //

                wl_int_001++;
            }
        }
    }
    else
    { // *** PAS D'ANAGLYPH ***
        wl_int_001 = 1;
        QString wl_strtr;
        while ( wl_int_001 < nombre_diapos+1 )
        {
            wl_int_003 = tab_order[wl_int_001][1];

            if ( tab_msk[wl_int_003] == true )
            {
                if ( tab_diapo[wl_int_003][0].mid(0,1) != "?" || tab_diapo[wl_int_003][0].mid(0,2) == "?9" )
                {
                    //qDebug() << wl_int_001 << " " << wl_int_003 << " " << scale_factor;
                    scale_factor = tab_diapo[wl_int_003][5].toFloat();

                    glLoadIdentity();
                    //glColor3f(1.0f,1.0f,1.0f);

                    glTranslatef(tab_coo[wl_int_003][0], tab_coo[wl_int_003][1], tab_coo[wl_int_003][2]);
                    glRotatef(tab_coo[wl_int_003][5], 1.0, 0.0, 0.0);
                    glRotatef(tab_coo[wl_int_003][6], 0.0, 1.0, 0.0);

                    if ( tab_diapo[wl_int_003][8] == "1" )
                    {
                        glRotatef(tab_coo[wl_int_003][7]+90, 0.0, 0.0, 1.0);
                    }
                    else
                    {
                        if ( tab_diapo[wl_int_003][8] == "2" )
                        {
                            glRotatef(tab_coo[wl_int_003][7]-90, 0.0, 0.0, 1.0);
                        }
                        else
                        {
                            glRotatef(tab_coo[wl_int_003][7], 0.0, 0.0, 1.0);
                        }
                    }

                    glLoadName(wl_int_003);

                    if ( tab_coo[wl_int_003][11] >= 0 )
                    {
                        //qDebug() << "APPMSK=" << wl_int_003 << " " << tab_coo[wl_int_003][11];
                        f_apply_mask(wl_int_003,tab_coo[wl_int_003][11]);
                    }

                    glBindTexture( GL_TEXTURE_2D, texture_diapo[wl_int_003] );

                    glColor4f(1.0f,1.0f,1.0f,(float)((float)100-(float)tab_coo[wl_int_003][9])/(float)100);
                    glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);

                    glBegin(GL_QUADS);

                    wl_strtr = QString::number(tab_coo[wl_int_003][8]);

                    if ( wl_strtr.mid(0,1).toInt() < 2 || tab_coo[wl_int_003][11] >= 0 ) // *** DIAPO STANDARD ***
                    {

                        //float wl_x = (float)(0-(2 * (tab_diapo[wl_int_003][1].toFloat() / tab_diapo[wl_int_003][2].toFloat()))) * -1;

                        if ( tab_diapo[wl_int_003][7] == "0/0/0/0" )
                        {
                            wl_x = (float)(0-(2 * (tab_diapo[wl_int_003][1].toFloat() / tab_diapo[wl_int_003][2].toFloat()))) * -1;
                        }
                        else
                        {
                            QStringList wl_explode = tab_diapo[wl_int_003][7].split("/",QString::KeepEmptyParts);

                            wl_x = (float)(0-(2 * ((wl_explode.at(2).toFloat()-wl_explode.at(0).toFloat()) / (wl_explode.at(3).toFloat()-wl_explode.at(1).toFloat())))) * -1;
                            //wl_x = (float)(0-(2 * (tab_diapo[wl_int_003][1].toFloat() / tab_diapo[wl_int_003][2].toFloat()))) * -1;
                        }

                        if ( wl_int_003 == num_select )
                        {
                            tab_coo_select[0][0] = tab_coo[wl_int_003][0];
                            tab_coo_select[0][1] = tab_coo[wl_int_003][1];
                            tab_coo_select[0][2] = tab_coo[wl_int_003][2];
                            tab_coo_select[0][5] = tab_coo[wl_int_003][5];
                            tab_coo_select[0][6] = tab_coo[wl_int_003][6];
                            tab_coo_select[0][7] = tab_coo[wl_int_003][7];
                            tab_coo_select[0][8] = scale_factor;
                            tab_coo_select[0][9] = wl_x;
                        }
                        
                        if ( tab_diapo[wl_int_003][1].toFloat() > tab_diapo[wl_int_003][2].toFloat() )
                        {
                            wg_tx = 1.0;
                            wg_ty = (float)((float)tab_diapo[wl_int_003][2].toFloat()/(float)1024);
                        }
                        else
                        {
                            wg_ty = 1.0;
                            wg_tx = (float)((float)tab_diapo[wl_int_003][1].toFloat()/(float)1024);
                        }

                        //qDebug() << wl_x << " " << scale_factor << " " << wg_tx << " " << wg_ty << " " << tab_diapo[wl_int_003][1] << " " << tab_diapo[wl_int_003][2];

                        glBindTexture( GL_TEXTURE_2D, texture_diapo[wl_int_003] );
                        glTexCoord2f(wg_tx, -wg_ty);
                        glVertex3f(wl_x*scale_factor , -2.0f*scale_factor , 0.0f);

                        glTexCoord2f(wg_tx, 0.0);
                        glVertex3f(wl_x*scale_factor , 2.0f*scale_factor , 0.0f);

                        glTexCoord2f(0.0, 0.0);
                        glVertex3f(-wl_x*scale_factor , 2.0f*scale_factor , 0.0f);

                        glTexCoord2f(0.0, -wg_ty);
                        glVertex3f(-wl_x*scale_factor , -2.0f*scale_factor , 0.0f);
                    }

                    glEnd();

                    if ( tab_diapo[wl_int_003][6] != "0" ) // *** REFLECT ***
                    {
                        if ( tab_diapo[wl_int_003][8] == "1" )
                        {
                            glRotatef(tab_coo[wl_int_003][7]-180, 0.0, 0.0, 1.0);
                            glTranslatef(+(wl_x*1.5)*scale_factor, 0.0, 0.0);
                            glScalef(1.0, -1.0, 1.0);

                            glShadeModel(GL_SMOOTH);

                            glBegin(GL_QUADS);

                            if ( wl_strtr.mid(0,1).toInt() < 2 || tab_coo[wl_int_003][11] >= 0 )
                            {
                                glColor4f(1.0,1.0,1.0,0.0);
                                //glTexCoord2f(1.0, 0.0);
                                glTexCoord2f(wg_tx/2, -wg_ty);
                                glVertex3f(wl_x*scale_factor/2 , -2.0f*scale_factor , 0.0f);

                                glColor4f(1.0,1.0,1.0,0.0);
                                //glTexCoord2f(1.0, 1.0);
                                glTexCoord2f(wg_tx/2, 0.0);
                                glVertex3f(wl_x*scale_factor/2 , 2.0f*scale_factor , 0.0f);

                                glColor4f(1.0,1.0,1.0,0.4*((float)((float)100-(float)tab_coo[wl_int_003][9])/(float)100));
                                //glTexCoord2f(0.0, 1.0);
                                glTexCoord2f(0.0, 0.0);
                                glVertex3f(-wl_x*scale_factor/2 , 2.0f*scale_factor , 0.0f);

                                glColor4f(1.0,1.0,1.0,0.4*((float)((float)100-(float)tab_coo[wl_int_003][9])/(float)100));
                                //glTexCoord2f(0.0, 0.0);
                                glTexCoord2f(0.0, -wg_ty);
                                glVertex3f(-wl_x*scale_factor/2 , -2.0f*scale_factor , 0.0f);
                            }
                        }
                        else
                        {
                            if ( tab_diapo[wl_int_003][8] == "2" )
                            {                               
                                glRotatef(tab_coo[wl_int_003][7]+180, 0.0, 0.0, 1.0);
                                glTranslatef(-(wl_x*1.5)*scale_factor, 0.0, 0.0);
                                glScalef(1.0, -1.0, 1.0);

                                glShadeModel(GL_SMOOTH);

                                glBegin(GL_QUADS);

                                if ( wl_strtr.mid(0,1).toInt() < 2 || tab_coo[wl_int_003][11] >= 0 )
                                {

                                    glColor4f(1.0,1.0,1.0,0.4*((float)((float)100-(float)tab_coo[wl_int_003][9])/(float)100));
                                    glTexCoord2f(wg_tx, -wg_ty);
                                    glVertex3f(wl_x*scale_factor/2 , -2.0f*scale_factor , 0.0f);

                                    glColor4f(1.0,1.0,1.0,0.4*((float)((float)100-(float)tab_coo[wl_int_003][9])/(float)100));
                                    glTexCoord2f(wg_tx, 0.0);
                                    glVertex3f(wl_x*scale_factor/2 , 2.0f*scale_factor , 0.0f);

                                    glColor4f(1.0,1.0,1.0,0.0);
                                    glTexCoord2f(wg_tx/2, 0.0);

                                    glVertex3f(-wl_x*scale_factor/2 , 2.0f*scale_factor , 0.0f);

                                    glColor4f(1.0,1.0,1.0,0.0);
                                    glTexCoord2f(wg_tx/2, -wg_ty);
                                    glVertex3f(-wl_x*scale_factor/2 , -2.0f*scale_factor , 0.0f);
                                }
                            }
                            else
                            {
                                glTranslatef(0.0, -3.0f*scale_factor, 0.0);
                                glScalef(1.0, -1.0, 1.0);

                                glShadeModel(GL_SMOOTH);

                                glBegin(GL_QUADS);

                                if ( wl_strtr.mid(0,1).toInt() < 2 || tab_coo[wl_int_003][11] >= 0 )
                                {
                                    glColor4f(1.0,1.0,1.0,0.4*((float)((float)100-(float)tab_coo[wl_int_003][9])/(float)100));
                                    glTexCoord2f(wg_tx, -wg_ty);
                                    glVertex3f(wl_x*scale_factor , -1.0f*scale_factor , 0.0f);

                                    glColor4f(1.0,1.0,1.0,0.0);
                                    glTexCoord2f(wg_tx, -wg_ty/2);
                                    glVertex3f(wl_x*scale_factor , 1.0f*scale_factor , 0.0f);

                                    glColor4f(1.0,1.0,1.0,0.0);
                                    glTexCoord2f(0.0, -wg_ty/2);
                                    glVertex3f(-wl_x*scale_factor , 1.0f*scale_factor , 0.0f);

                                    glColor4f(1.0,1.0,1.0,0.4*((float)((float)100-(float)tab_coo[wl_int_003][9])/(float)100));
                                    glTexCoord2f(0.0, -wg_ty);
                                    glVertex3f(-wl_x*scale_factor , -1.0f*scale_factor , 0.0f);
                                }
                            }
                        }

                        glEnd();
                        glShadeModel(GL_FLAT);
                    }
                }
                else
                {
                    // *********************
                    // *** AUTRES OBJETS ***
                    // *********************
                    scale_factor = tab_diapo[wl_int_003][5].toFloat();

                    if ( wl_int_003 == num_select )
                    {
                        tab_coo_select[0][0] = tab_coo[wl_int_003][0];
                        tab_coo_select[0][1] = tab_coo[wl_int_003][1];
                        tab_coo_select[0][2] = tab_coo[wl_int_003][2];
                        tab_coo_select[0][5] = tab_coo[wl_int_003][5];
                        tab_coo_select[0][6] = tab_coo[wl_int_003][6];
                        tab_coo_select[0][7] = tab_coo[wl_int_003][7];
                        tab_coo_select[0][8] = scale_factor;
                    }

                    if ( tab_diapo[wl_int_003][0].mid(1,1) == "1" )
                    {
                        glEnable( GL_LIGHTING ) ;
                        glEnable( GL_LIGHT0 );
                        glDisable(GL_TEXTURE_2D);

                        glColor3f(1.0f,1.0f,1.0f);
                        glLoadIdentity();
                        glEnable(GL_CULL_FACE);
                        GLfloat light_position[] = { 1.0, 1.0, 1.0, 0.0 };

                        glTranslatef(tab_coo[wl_int_003][0], tab_coo[wl_int_003][1], tab_coo[wl_int_003][2]);
                        glRotatef(tab_coo[wl_int_003][5], 1.0, 0.0, 0.0);
                        glRotatef(tab_coo[wl_int_003][6], 0.0, 1.0, 0.0);
                        glRotatef(tab_coo[wl_int_003][7], 0.0, 0.0, 1.0);

                        glLoadName(wl_int_003);

                        glColorMaterial ( GL_FRONT_AND_BACK, GL_AMBIENT_AND_DIFFUSE );
                        glLightfv(GL_LIGHT0, GL_POSITION, light_position);

                        GLfloat light_ambient[] = { 0.4, 0.0, 0.0, 1.0};
                        glLightfv(GL_LIGHT0, GL_AMBIENT, light_ambient);

                        glTranslatef(0, 0, -2.5*scale_factor);

                        glColor3ub(200,0,0);
                        quadric = gluNewQuadric();

                        gluQuadricNormals(quadric, GLU_SMOOTH );

                        gluCylinder(quadric, .5*scale_factor, .5*scale_factor, 5*scale_factor, 8, 2);

                        glTranslatef(0, 0, 5*scale_factor);
                        glColor3ub(240,215,160);
                        gluCylinder(quadric, .5*scale_factor, 0*scale_factor, 1*scale_factor, 8, 2);

                        glTranslatef(0, 0, 0.5*scale_factor);
                        glColor3ub(200,0,0);
                        gluCylinder(quadric, .25*scale_factor, 0*scale_factor, 0.5*scale_factor, 10, 2);

                        glTranslatef(0, 0, -5.5*scale_factor);
                        glColor3ub(200,0,0);
                        glRotatef(180, 0, 1, 0);
                        gluDisk(quadric,0,0.5*scale_factor,8*scale_factor,8*scale_factor);

                        glDisable(GL_CULL_FACE);
                        glEnable(GL_TEXTURE_2D);
                        glDisable( GL_LIGHTING ) ;
                        glDisable( GL_LIGHT0 );
                    }
                    else
                    {
                        if ( tab_diapo[wl_int_003][0].mid(1,1) == "2" )
                        {
                            glEnable( GL_LIGHTING ) ;
                            glEnable( GL_LIGHT0 );
                            glDisable(GL_TEXTURE_2D);

                            glColor3f(1.0f,1.0f,1.0f);
                            glLoadIdentity();
                            glEnable(GL_CULL_FACE);
                            GLfloat light_position[] = { 1.0, 1.0, 1.0, 0.0 };

                            glTranslatef(tab_coo[wl_int_003][0], tab_coo[wl_int_003][1], tab_coo[wl_int_003][2]);
                            glRotatef(tab_coo[wl_int_003][5], 1.0, 0.0, 0.0);
                            glRotatef(tab_coo[wl_int_003][6], 0.0, 1.0, 0.0);
                            glRotatef(tab_coo[wl_int_003][7], 0.0, 0.0, 1.0);

                            glLoadName(wl_int_003);

                            glColorMaterial ( GL_FRONT_AND_BACK, GL_AMBIENT_AND_DIFFUSE );
                            glLightfv(GL_LIGHT0, GL_POSITION, light_position);

                            GLfloat light_ambient[] = { 0.0, 0.4, 0.0, 1.0};
                            glLightfv(GL_LIGHT0, GL_AMBIENT, light_ambient);

                            glTranslatef(0, 0, -2.5*scale_factor);

                            glColor3ub(0,200,0);
                            quadric = gluNewQuadric();
                            gluQuadricNormals(quadric, GLU_SMOOTH );

                            gluCylinder(quadric, .5*scale_factor, .5*scale_factor, 5*scale_factor, 8, 2);

                            glTranslatef(0, 0, 5*scale_factor);
                            glColor3ub(240,215,160);
                            gluCylinder(quadric, .5*scale_factor, 0*scale_factor, 1*scale_factor, 8, 2);

                            glTranslatef(0, 0, 0.5*scale_factor);
                            glColor3ub(0,200,0);
                            gluCylinder(quadric, .25*scale_factor, 0*scale_factor, 0.5*scale_factor, 10, 2);

                            glTranslatef(0, 0, -5.5*scale_factor);
                            glColor3ub(0,200,0);
                            glRotatef(180, 0, 1, 0);
                            gluDisk(quadric,0,0.5*scale_factor,8*scale_factor,8*scale_factor);

                            glDisable(GL_CULL_FACE);
                            glDisable( GL_LIGHTING ) ;
                            glDisable( GL_LIGHT0 );
                            glEnable(GL_TEXTURE_2D);
                        }
                        else
                        {
                            if ( tab_diapo[wl_int_003][0].mid(1,1) == "3" )
                            {
                                glEnable( GL_LIGHTING ) ;
                                glEnable( GL_LIGHT0 );
                                glDisable(GL_TEXTURE_2D);

                                glColor3f(1.0f,1.0f,1.0f);
                                glLoadIdentity();
                                glEnable(GL_CULL_FACE);
                                GLfloat light_position[] = { 1.0, 1.0, 1.0, 0.0 };

                                glTranslatef(tab_coo[wl_int_003][0], tab_coo[wl_int_003][1], tab_coo[wl_int_003][2]);
                                glRotatef(tab_coo[wl_int_003][5], 1.0, 0.0, 0.0);
                                glRotatef(tab_coo[wl_int_003][6], 0.0, 1.0, 0.0);
                                glRotatef(tab_coo[wl_int_003][7], 0.0, 0.0, 1.0);

                                glLoadName(wl_int_003);

                                glColorMaterial ( GL_FRONT_AND_BACK, GL_AMBIENT_AND_DIFFUSE );
                                glLightfv(GL_LIGHT0, GL_POSITION, light_position);

                                GLfloat light_ambient[] = { 0.0, 0.0, 0.4, 1.0};
                                glLightfv(GL_LIGHT0, GL_AMBIENT, light_ambient);

                                glTranslatef(0, 0, -2.5*scale_factor);

                                glColor3ub(0,0,200);
                                quadric = gluNewQuadric();
                                gluQuadricNormals(quadric, GLU_SMOOTH );

                                gluCylinder(quadric, .5*scale_factor, .5*scale_factor, 5*scale_factor, 8, 2);

                                glTranslatef(0, 0, 5*scale_factor);
                                glColor3ub(240,215,160);
                                gluCylinder(quadric, .5*scale_factor, 0*scale_factor, 1*scale_factor, 8, 2);

                                glTranslatef(0, 0, 0.5*scale_factor);
                                glColor3ub(0,0,200);
                                gluCylinder(quadric, .25*scale_factor, 0*scale_factor, 0.5*scale_factor, 10, 2);

                                glTranslatef(0, 0, -5.5*scale_factor);
                                glColor3ub(0,0,200);
                                glRotatef(180, 0, 1, 0);
                                gluDisk(quadric,0,0.5*scale_factor,8*scale_factor,8*scale_factor);

                                glDisable(GL_CULL_FACE);
                                glDisable( GL_LIGHTING ) ;
                                glDisable( GL_LIGHT0 );
                                glEnable(GL_TEXTURE_2D);
                            }
                            else
                            {
                                if ( tab_diapo[wl_int_003][0].mid(1,1) == "4" )
                                {
                                    glEnable( GL_LIGHTING ) ;
                                    glEnable( GL_LIGHT0 );
                                    glDisable(GL_TEXTURE_2D);

                                    glColor3f(1.0f,1.0f,1.0f);
                                    glLoadIdentity();
                                    glEnable(GL_CULL_FACE);
                                    GLfloat light_position[] = { 1.0, 1.0, 1.0, 0.0 };

                                    glTranslatef(tab_coo[wl_int_003][0], tab_coo[wl_int_003][1], tab_coo[wl_int_003][2]);
                                    glRotatef(tab_coo[wl_int_003][5], 1.0, 0.0, 0.0);
                                    glRotatef(tab_coo[wl_int_003][6], 0.0, 1.0, 0.0);
                                    glRotatef(tab_coo[wl_int_003][7], 0.0, 0.0, 1.0);

                                    glLoadName(wl_int_003);

                                    glColorMaterial ( GL_FRONT_AND_BACK, GL_AMBIENT_AND_DIFFUSE );
                                    glLightfv(GL_LIGHT0, GL_POSITION, light_position);

                                    GLfloat light_ambient[] = { 0.4, 0.4, 0.4, 1.0};
                                    glLightfv(GL_LIGHT0, GL_AMBIENT, light_ambient);

                                    glTranslatef(0, 0, -2.5*scale_factor);

                                    glColor3ub(200,200,200);
                                    quadric = gluNewQuadric();
                                    gluQuadricNormals(quadric, GLU_SMOOTH );

                                    gluCylinder(quadric, .5*scale_factor, .5*scale_factor, 5*scale_factor, 8, 2);

                                    glTranslatef(0, 0, 5*scale_factor);
                                    glColor3ub(240,215,160);
                                    gluCylinder(quadric, .5*scale_factor, 0*scale_factor, 1*scale_factor, 8, 2);

                                    glTranslatef(0, 0, 0.5*scale_factor);
                                    glColor3ub(200,200,200);
                                    gluCylinder(quadric, .25*scale_factor, 0*scale_factor, 0.5*scale_factor, 10, 2);

                                    glTranslatef(0, 0, -5.5*scale_factor);
                                    glColor3ub(200,200,200);
                                    glRotatef(180, 0, 1, 0);
                                    gluDisk(quadric,0,0.5*scale_factor,8*scale_factor,8*scale_factor);

                                    glDisable(GL_CULL_FACE);
                                    glDisable( GL_LIGHTING ) ;
                                    glDisable( GL_LIGHT0 );
                                    glEnable(GL_TEXTURE_2D);
                                }
                                else
                                {
                                    if ( tab_diapo[wl_int_003][0].mid(1,1) == "5" ) // *** SNOWMAN ***
                                    {
                                        glEnable( GL_LIGHTING ) ;
                                        glEnable( GL_LIGHT0 );
                                        glDisable(GL_TEXTURE_2D);
                                        glEnable(GL_CULL_FACE);

                                        glLoadIdentity();

                                        glColor3f(1.0f,1.0f,1.0f);
                                        glEnable(GL_CULL_FACE);
                                        GLfloat light_position[] = { 1.0, 1.0, 1.0, 0.0 };

                                        glTranslatef(tab_coo[wl_int_003][0], tab_coo[wl_int_003][1], tab_coo[wl_int_003][2]);
                                        glRotatef(tab_coo[wl_int_003][5], 1.0, 0.0, 0.0);
                                        glRotatef(tab_coo[wl_int_003][6], 0.0, 1.0, 0.0);
                                        glRotatef(tab_coo[wl_int_003][7], 0.0, 0.0, 1.0);

                                        glLoadName(wl_int_003);

                                        glColorMaterial ( GL_FRONT_AND_BACK, GL_AMBIENT_AND_DIFFUSE );
                                        glLightfv(GL_LIGHT0, GL_POSITION, light_position);

                                        GLfloat light_ambient[] = { 0.4, 0.4, 0.4, 1.0};
                                        glLightfv(GL_LIGHT0, GL_AMBIENT, light_ambient);

                                        glColor3f(1.0f, 1.0f, 1.0f);
                                        quadric = gluNewQuadric();
                                        gluQuadricNormals(quadric, GLU_SMOOTH );

                                        glTranslatef(0.0f ,0.75f*scale_factor, 0.0f);
                                        gluSphere(quadric,0.75f*scale_factor,32,32);

                                        glTranslatef(0.0f, 0.95f*scale_factor, 0.0f);
                                        gluSphere(quadric,0.25f*scale_factor,32,32);

                                        glColor3f(0.0f,0.0f,0.0f);
                                        glTranslatef(0.1f*scale_factor, 0.0f, 0.18f*scale_factor);
                                        gluSphere(quadric,0.05f*scale_factor,10,10);
                                        glTranslatef(-0.2f*scale_factor, 0.0f, 0.0f);
                                        gluSphere(quadric,0.05f*scale_factor,10,10);

                                        glColor3f(1.0f, 0.5f , 0.5f);
                                        glTranslatef(0.1f*scale_factor, -0.08f*scale_factor, 0.0f);
                                        glRotatef(0.0f,1.0f, 0.0f, 0.0f);
                                        gluCylinder(quadric, 0.06*scale_factor, 0.0, 0.2*scale_factor, 8, 2);

                                        glDisable( GL_LIGHTING ) ;
                                        glDisable( GL_LIGHT0 );
                                        glEnable(GL_TEXTURE_2D);
                                        glDisable(GL_CULL_FACE);
                                    }
                                    else
                                    {
                                        if ( tab_diapo[wl_int_003][0].mid(1,1) == "6" )
                                        {
                                            glColor3f(1.0f,1.0f,1.0f);
                                            glLoadIdentity();

                                            glTranslatef(tab_coo[wl_int_003][0], tab_coo[wl_int_003][1], tab_coo[wl_int_003][2]);
                                            glRotatef(tab_coo[wl_int_003][5], 1.0, 0.0, 0.0);
                                            glRotatef(tab_coo[wl_int_003][6], 0.0, 1.0, 0.0);
                                            glRotatef(tab_coo[wl_int_003][7], 0.0, 0.0, 1.0);

                                            glLoadName(wl_int_003);
                                            glEnable(GL_CULL_FACE);

                                            glColorMaterial ( GL_FRONT_AND_BACK, GL_AMBIENT_AND_DIFFUSE );

                                            GLfloat light_ambient[] = { 1.0, 1.0, 1.0, 0.2};
                                            glLightfv(GL_LIGHT0, GL_AMBIENT, light_ambient);

                                            // *** FACE ARRIERE ***

                                            glBindTexture( GL_TEXTURE_2D, texture_diapo_cube[0] );

                                            glBegin(GL_QUADS);

                                            glColor4f(1.0,1.0,1.0,1.0);
                                            glTexCoord2f(0.0, 1.0);
                                            glVertex3f(-1.0f * scale_factor, -1.0f * scale_factor, -1.0f * scale_factor );

                                            glColor4f(1.0,1.0,1.0,1.0);
                                            glTexCoord2f(0.0, 0.0);
                                            glVertex3f(-1.0f * scale_factor,  1.0f * scale_factor, -1.0f * scale_factor );

                                            glColor4f(1.0,1.0,1.0,1.0);
                                            glTexCoord2f(1.0, 0.0);
                                            glVertex3f( 1.0f * scale_factor,  1.0f * scale_factor, -1.0f * scale_factor );

                                            glColor4f(1.0,1.0,1.0,1.0);
                                            glTexCoord2f(1.0, 1.0);
                                            glVertex3f( 1.0f * scale_factor, -1.0f * scale_factor, -1.0f * scale_factor );

                                            glEnd();

                                            // *** FACE DU HAUT ***
                                            glBindTexture( GL_TEXTURE_2D, texture_diapo_cube[1] );

                                            glBegin(GL_QUADS);

                                            glColor4f(1.0,1.0,1.0,1.0);
                                            glTexCoord2f(0.0, 1.0);
                                            glVertex3f(-1.0f * scale_factor,  1.0f * scale_factor , -1.0f * scale_factor );

                                            glColor4f(1.0,1.0,1.0,1.0);
                                            glTexCoord2f(0.0, 0.0);
                                            glVertex3f(-1.0f * scale_factor,  1.0f * scale_factor ,  1.0f * scale_factor );

                                            glColor4f(1.0,1.0,1.0,1.0);
                                            glTexCoord2f(1.0, 0.0);
                                            glVertex3f( 1.0f * scale_factor,  1.0f * scale_factor ,  1.0f * scale_factor );

                                            glColor4f(1.0,1.0,1.0,1.0);
                                            glTexCoord2f(1.0, 1.0);
                                            glVertex3f( 1.0f * scale_factor,  1.0f * scale_factor , -1.0f * scale_factor );

                                            glEnd();

                                            // *** FACE DU BAS ***
                                            glBindTexture( GL_TEXTURE_2D, texture_diapo_cube[2] );

                                            glBegin(GL_QUADS);

                                            glColor4f(1.0,1.0,1.0,1.0);
                                            glTexCoord2f(1.0, 1.0);
                                            glVertex3f(-1.0f * scale_factor , -1.0f * scale_factor , -1.0f * scale_factor );

                                            glColor4f(1.0,1.0,1.0,1.0);
                                            glTexCoord2f(0.0, 1.0);
                                            glVertex3f( 1.0f * scale_factor , -1.0f * scale_factor , -1.0f * scale_factor );

                                            glColor4f(1.0,1.0,1.0,1.0);
                                            glTexCoord2f(0.0, 0.0);
                                            glVertex3f( 1.0f * scale_factor , -1.0f * scale_factor ,  1.0f * scale_factor );

                                            glColor4f(1.0,1.0,1.0,1.0);
                                            glTexCoord2f(1.0, 0.0);
                                            glVertex3f(-1.0f * scale_factor , -1.0f * scale_factor ,  1.0f * scale_factor );

                                            glEnd();

                                            // *** FACE DE GAUCHE ***
                                            glBindTexture( GL_TEXTURE_2D, texture_diapo_cube[3] );

                                            glBegin(GL_QUADS);

                                            glColor4f(1.0,1.0,1.0,1.0);
                                            glTexCoord2f(0.0, 1.0);

                                            glVertex3f(-1.0f * scale_factor , -1.0f * scale_factor, -1.0f * scale_factor );

                                            glColor4f(1.0,1.0,1.0,1.0);
                                            glTexCoord2f(0.0, 0.0);
                                            glVertex3f(-1.0f * scale_factor , -1.0f * scale_factor,  1.0f * scale_factor );

                                            glColor4f(1.0,1.0,1.0,1.0);
                                            glTexCoord2f(1.0, 0.0);
                                            glVertex3f(-1.0f * scale_factor ,  1.0f * scale_factor,  1.0f * scale_factor );

                                            glColor4f(1.0,1.0,1.0,1.0);
                                            glTexCoord2f(1.0, 1.0);
                                            glVertex3f(-1.0f * scale_factor ,  1.0f * scale_factor, -1.0f * scale_factor );

                                            glEnd();

                                            // *** FACE DE DROITE ***
                                            glBindTexture( GL_TEXTURE_2D, texture_diapo_cube[4] );

                                            glBegin(GL_QUADS);

                                            glColor4f(1.0,1.0,1.0,1.0);
                                            glTexCoord2f(1.0, 1.0);
                                            glVertex3f( 1.0f * scale_factor , -1.0f * scale_factor , -1.0f * scale_factor );

                                            glColor4f(1.0,1.0,1.0,1.0);
                                            glTexCoord2f(0.0, 1.0);
                                            glVertex3f( 1.0f * scale_factor ,  1.0f * scale_factor , -1.0f * scale_factor );

                                            glColor4f(1.0,1.0,1.0,1.0);
                                            glTexCoord2f(0.0, 0.0);
                                            glVertex3f( 1.0f * scale_factor ,  1.0f * scale_factor ,  1.0f * scale_factor );

                                            glColor4f(1.0,1.0,1.0,1.0);
                                            glTexCoord2f(1.0, 0.0);
                                            glVertex3f( 1.0f * scale_factor , -1.0f * scale_factor ,  1.0f * scale_factor );

                                            glEnd();

                                            // *** FACE AVANT ***
                                            glBindTexture( GL_TEXTURE_2D, texture_diapo_cube[5] );

                                            glBegin(GL_QUADS);

                                            glColor4f(1.0,1.0,1.0,1.0);
                                            glTexCoord2f(0.0, 0.0);
                                            glVertex3f(-1.0f * scale_factor , -1.0f * scale_factor ,  1.0f * scale_factor );

                                            glColor4f(1.0,1.0,1.0,1.0);
                                            glTexCoord2f(1.0, 0.0);
                                            glVertex3f( 1.0f * scale_factor , -1.0f * scale_factor ,  1.0f * scale_factor );

                                            glColor4f(1.0,1.0,1.0,1.0);
                                            glTexCoord2f(1.0, 1.0);
                                            glVertex3f( 1.0f * scale_factor ,  1.0f * scale_factor ,  1.0f * scale_factor );

                                            glColor4f(1.0,1.0,1.0,1.0);
                                            glTexCoord2f(0.0, 1.0);
                                            glVertex3f(-1.0f * scale_factor ,  1.0f * scale_factor ,  1.0f * scale_factor );

                                            glEnd();
                                            glDisable(GL_CULL_FACE);
                                        }
                                        else
                                        {
                                            if ( tab_diapo[wl_int_003][0].mid(1,1) == "7" )
                                            {
                                                //glEnable( GL_LIGHTING ) ;
                                                //glEnable( GL_LIGHT0 );
                                                glEnable(GL_CULL_FACE);
                                                glEnable(GL_TEXTURE_2D);

                                                glColor3f(1.0f,1.0f,1.0f);
                                                glLoadIdentity();
                                                glEnable(GL_CULL_FACE);
                                                //GLfloat light_position[] = { 1.0, 1.0, 1.0, 0.0 };

                                                glTranslatef(tab_coo[wl_int_003][0], tab_coo[wl_int_003][1], tab_coo[wl_int_003][2]);
                                                glRotatef(tab_coo[wl_int_003][5], 1.0, 0.0, 0.0);
                                                glRotatef(tab_coo[wl_int_003][6], 0.0, 1.0, 0.0);
                                                glRotatef(tab_coo[wl_int_003][7], 0.0, 0.0, 1.0);

                                                glLoadName(wl_int_003);

                                               // glColorMaterial ( GL_FRONT_AND_BACK, GL_AMBIENT_AND_DIFFUSE );
                                                //glLightfv(GL_LIGHT0, GL_POSITION, light_position);

                                                //GLfloat light_ambient[] = { 1.0, 1.0, 1.0, 1.0};
                                                //glLightfv(GL_LIGHT0, GL_AMBIENT, light_ambient);

                                                //glTranslatef(0, 0, -2.5*scale_factor);

                                                glColor3ub(200,200,200);
                                                quadric = gluNewQuadric();
                                                gluQuadricNormals(quadric, GLU_SMOOTH );

                                                gluQuadricTexture(quadric,GL_TRUE);
                                                glBindTexture(GL_TEXTURE_2D,texture_diapo[44]);
                                                gluSphere(quadric,1.0f*scale_factor,32,32);

                                                //glDisable( GL_LIGHTING ) ;
                                                //glDisable( GL_LIGHT0 );
                                                glDisable(GL_CULL_FACE);
                                            }
                                            else
                                            {
                                                if ( tab_diapo[wl_int_003][0].mid(1,1) == "8" )
                                                {
                                                    glEnable( GL_LIGHTING ) ;
                                                    glEnable( GL_LIGHT0 );
                                                    glEnable(GL_TEXTURE_2D);

                                                    glColor3f(1.0f,1.0f,1.0f);
                                                    glLoadIdentity();
                                                    glDisable(GL_CULL_FACE);
                                                    //GLfloat light_position[] = { 1.0, 1.0, 1.0, 0.0 };

                                                    glTranslatef(tab_coo[wl_int_003][0], tab_coo[wl_int_003][1], tab_coo[wl_int_003][2]);
                                                    glRotatef(tab_coo[wl_int_003][5], 1.0, 0.0, 0.0);
                                                    glRotatef(tab_coo[wl_int_003][6], 0.0, 1.0, 0.0);
                                                    glRotatef(tab_coo[wl_int_003][7], 0.0, 0.0, 1.0);

                                                    glLoadName(wl_int_003);

                                                    glColorMaterial ( GL_FRONT_AND_BACK, GL_AMBIENT_AND_DIFFUSE );
                                                    //glLightfv(GL_LIGHT0, GL_POSITION, light_position);

                                                    GLfloat light_ambient[] = { 1.0, 1.0, 1.0, 1.0};
                                                    glLightfv(GL_LIGHT0, GL_AMBIENT, light_ambient);

                                                    //glTranslatef(0, 0, -2.5*scale_factor);

                                                    glBegin(GL_TRIANGLE_STRIP);

                                                    glColor3f(255,255,255);

                                                    glVertex3f(-7.0*scale_factor, 0.0*scale_factor, 2.0*scale_factor);
                                                    glVertex3f(-1.0*scale_factor, 0.0*scale_factor, 3.0*scale_factor);
                                                    glVertex3f(-1.0*scale_factor, 7.0*scale_factor, 3.0*scale_factor);
                                                    glVertex3f(0.0*scale_factor, 0.0*scale_factor, 0.0*scale_factor);
                                                    glVertex3f(0.0*scale_factor, 8.0*scale_factor, 0.0*scale_factor);
                                                    glVertex3f(1.0*scale_factor, 0.0*scale_factor, 3.0*scale_factor);
                                                    glVertex3f(1.0*scale_factor, 7.0*scale_factor, 3.0*scale_factor);
                                                    glVertex3f(7.0*scale_factor, 0.0*scale_factor, 2.0*scale_factor);

                                                    glEnd();

                                                    glDisable( GL_LIGHTING ) ;
                                                    glDisable( GL_LIGHT0 );
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
            //

            wl_int_001++;
        }
    }

    /*if ( num_select > 0 && tab_msk[num_select] == true && tab_diapo[num_select][0].mid(0,1) != "?" )
    {
        glLoadIdentity();

        glTranslatef(tab_coo_select[0][0], tab_coo_select[0][1], tab_coo_select[0][2]+0.1);
        glRotatef(tab_coo_select[0][5], 1.0, 0.0, 0.0);
        glRotatef(tab_coo_select[0][6], 0.0, 1.0, 0.0);
        glRotatef(tab_coo_select[0][7], 0.0, 0.0, 1.0);

        glLoadName(wl_int_001);
        glBindTexture( GL_TEXTURE_2D, texture_diapo[42] );
        glColor4f(1.0f,1.0f,1.0f,1.0f);
        glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);

        glBegin(GL_QUADS);

        glTexCoord2f(1.0, 0.0);
        glVertex3f(tab_coo_select[0][9]*tab_coo_select[0][8] , -tab_coo_select[0][9]*tab_coo_select[0][8] , 0.0f);

        glTexCoord2f(1.0, 1.0);
        glVertex3f(tab_coo_select[0][9]*tab_coo_select[0][8] , tab_coo_select[0][9]*tab_coo_select[0][8] , 0.0f);

        glTexCoord2f(0.0, 1.0);
        glVertex3f(-tab_coo_select[0][9]*tab_coo_select[0][8] , tab_coo_select[0][9]*tab_coo_select[0][8] , 0.0f);

        glTexCoord2f(0.0, 0.0);
        glVertex3f(-tab_coo_select[0][9]*tab_coo_select[0][8] , -tab_coo_select[0][9]*tab_coo_select[0][8] , 0.0f);

        glEnd();
    }*/

    /*glBegin(GL_LINES);
    glVertex3f(-2.0f, 2.0f, -4.0f);
    glVertex3f(2.0f, -2.0f, -4.0f);
    glEnd( );*/

    glDisable(GL_BLEND);

    if ( is_mblur > 0 )
    {
            if ( bcle_render == 1 )
            {
                    glClear(GL_ACCUM_BUFFER_BIT);
                    glAccum(GL_LOAD, 1.0);
                    bcle_render = 2;
            }
            else
            {
                    if ( bcle_render == 2 )
                    {
                            glAccum(GL_ACCUM, 0.1);
                            glAccum(GL_MULT, 0.9);
                            glAccum(GL_RETURN, 1.0);
                    }
            }
    }

    glFlush();
    glColorMask(GL_TRUE, GL_TRUE, GL_TRUE, GL_TRUE);
}

void Tetrahedron::f_apply_mask(int numtxt, int valpha)
{
    int alpha;
    QString wl_tmps = QString::number(valpha);
    alpha = wl_tmps.mid(0,wl_tmps.length()-2).toInt();

    glDeleteTextures(1, &texture_diapo[numtxt] );
    QImage wl_puis_001(1024,1024,QImage::Format_ARGB32_Premultiplied);

    if ( alpha == 0 )
    {
        wl_puis_001 = wg_table_photo[numtxt].copy ( 0, 0, 1024, 1024);


        QImage f = QGLWidget::convertToGLFormat( wl_puis_001 );

        glDeleteTextures (1,&texture_diapo[numtxt]);
        glGenTextures (1,&texture_diapo[numtxt]);
        glBindTexture (GL_TEXTURE_2D, texture_diapo[numtxt]);

        glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
        glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);

        glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, f.width(), f.height(),
                      0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits());

        return;
    }

    QImage wl_alpha;

    if ( wl_tmps.mid(wl_tmps.length()-2,2) == "01" )
    {
        wl_alpha.load(qApp->applicationDirPath()+"/Bibliotheque/Luma/Recouvrement_droite.png");
    }
    else
    {
        if ( wl_tmps.mid(wl_tmps.length()-2,2) == "02" )
        {
            wl_alpha.load(qApp->applicationDirPath()+"/Bibliotheque/Luma/Recouvrement_gauche.png");
        }
        else
        {
            if ( wl_tmps.mid(wl_tmps.length()-2,2) == "03" )
            {
                wl_alpha.load(qApp->applicationDirPath()+"/Bibliotheque/Luma/Recouvrement_haut.png");
            }
            else
            {
                if ( wl_tmps.mid(wl_tmps.length()-2,2) == "04" )
                {
                    wl_alpha.load(qApp->applicationDirPath()+"/Bibliotheque/Luma/Recouvrement_bas.png");
                }
                else
                {
                    if ( wl_tmps.mid(wl_tmps.length()-2,2) == "05" )
                    {
                        wl_alpha.load(qApp->applicationDirPath()+"/Bibliotheque/Luma/Coeur.png");
                    }
                    else
                    {
                        if ( wl_tmps.mid(wl_tmps.length()-2,2) == "06" )
                        {
                            wl_alpha.load(qApp->applicationDirPath()+"/Bibliotheque/Luma/Vague_001.png");
                        }
                        else
                        {
                            if ( wl_tmps.mid(wl_tmps.length()-2,2) == "07" )
                            {
                                wl_alpha.load(qApp->applicationDirPath()+"/Bibliotheque/Luma/Rond_001.png");
                            }
                            else
                            {
                                if ( wl_tmps.mid(wl_tmps.length()-2,2) == "08" )
                                {
                                    wl_alpha.load(qApp->applicationDirPath()+"/Bibliotheque/Luma/Sinus1.png");
                                }
                                else
                                {
                                    if ( wl_tmps.mid(wl_tmps.length()-2,2) == "09" )
                                    {
                                        wl_alpha.load(qApp->applicationDirPath()+"/Bibliotheque/Luma/Brule_002.png");
                                    }
                                    else
                                    {
                                        if ( wl_tmps.mid(wl_tmps.length()-2,2) == "10" )
                                        {
                                            wl_alpha.load(qApp->applicationDirPath()+"/Bibliotheque/Luma/Blob.png");
                                        }
                                        else
                                        {
                                            wl_alpha.load(qApp->applicationDirPath()+"/Bibliotheque/Luma/Vague_002.png");
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
    }
    wl_alpha = wl_alpha.scaled(tab_diapo[numtxt][1].toInt(), tab_diapo[numtxt][2].toInt(),Qt::IgnoreAspectRatio);
    QImage wl_alpha_2(1024,1024,QImage::Format_ARGB32_Premultiplied);

    wl_alpha_2 = wl_alpha.copy(0,0,1024,1024);

    wl_alpha = wl_alpha_2;

    QImage dstImage(1024,1024,QImage::Format_ARGB32);
    dstImage.fill(0);

    thmsk *mytmsk = new thmsk();

    mytmsk->wl_img_texture = wg_table_photo[numtxt];
    mytmsk->wl_tmps = wl_tmps;
    mytmsk->real_w = tab_diapo[numtxt][1].toInt();
    mytmsk->real_h = tab_diapo[numtxt][2].toInt();
    mytmsk->mix = 0;
    mytmsk->max = tab_diapo[numtxt][1].toInt();
    mytmsk->miy = 0;
    mytmsk->may = tab_diapo[numtxt][2].toInt()/2;
    mytmsk->dstImage = &dstImage;
    mytmsk->wl_alpha = &wl_alpha;

    thmsk *mytmsk2 = new thmsk();

    mytmsk2->wl_img_texture = wg_table_photo[numtxt];
    mytmsk2->wl_tmps = wl_tmps;
    mytmsk2->real_w = tab_diapo[numtxt][1].toInt();
    mytmsk2->real_h = tab_diapo[numtxt][2].toInt();
    mytmsk2->mix = 0;
    mytmsk2->max = tab_diapo[numtxt][1].toInt();
    mytmsk2->miy = tab_diapo[numtxt][2].toInt()/2;
    mytmsk2->may = tab_diapo[numtxt][2].toInt();
    mytmsk2->dstImage = &dstImage;
    mytmsk2->wl_alpha = &wl_alpha;

    mytmsk->start();
    mytmsk2->start();
    mytmsk->wait();
    mytmsk2->wait();

    QImage f = QGLWidget::convertToGLFormat( dstImage );

    glDeleteTextures (1,&texture_diapo[numtxt]);
    glGenTextures (1,&texture_diapo[numtxt]);
    glBindTexture (GL_TEXTURE_2D, texture_diapo[numtxt]);

    glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
    glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);

    glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, f.width(), f.height(),
                  0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits());

    delete mytmsk;
    delete mytmsk2;
}

void Tetrahedron::draw_select()
{
    glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);

    //glMatrixMode( GL_MODELVIEW );

    int wl_int_001 = 1;
    glInitNames();
    glPushName(-1);

    // *** CLASSEMENT ORDRE Z ***

    while ( wl_int_001 < nombre_diapos+1 )
    {
        tab_order[wl_int_001][0] = 10;
        tab_order[wl_int_001][1] = 0;
        wl_int_001++;
    }

    wl_int_001 = 1;
    int wl_int_002;
    int wl_int_003;
    float wl_x;

    while ( wl_int_001 < nombre_diapos+1 )
    {
        wl_int_002 = 1;
        while ( tab_coo[wl_int_001][2] > tab_order[wl_int_002][0] && tab_order[wl_int_002][1] != 0 )
        {
            wl_int_002++;
        }

        if ( tab_order[wl_int_002][1] < 1 )
        {
            tab_order[wl_int_002][0] = tab_coo[wl_int_001][2];
            tab_order[wl_int_002][1] = wl_int_001;
        }
        else
        {
            wl_int_003 = wl_int_002;
            while ( tab_order[wl_int_003][1] > 0 )
            {
                wl_int_003++;
            }
            while ( wl_int_003 > wl_int_002 )
            {
                tab_order[wl_int_003][0] = tab_order[wl_int_003-1][0];
                tab_order[wl_int_003][1] = tab_order[wl_int_003-1][1];
                wl_int_003--;
            }
            tab_order[wl_int_002][0] = tab_coo[wl_int_001][2];
            tab_order[wl_int_002][1] = wl_int_001;
        }
        wl_int_001++;
    }

    wl_int_001 = 1;
    quadric = gluNewQuadric();

    while ( wl_int_001 < nombre_diapos+1 )
    {
        glLoadIdentity();

        wl_int_003 = tab_order[wl_int_001][1];

        if ( tab_msk[wl_int_003] == true && tab_coo[wl_int_003][9] < 100 )
        {
            if ( tab_diapo[wl_int_003][0].mid(0,1) != "?" )
            {
                scale_factor = tab_diapo[wl_int_003][5].toFloat();

                glTranslatef(tab_coo[wl_int_003][0], tab_coo[wl_int_003][1], tab_coo[wl_int_003][2]);
                glRotatef(tab_coo[wl_int_003][5], 1.0, 0.0, 0.0);
                glRotatef(tab_coo[wl_int_003][6], 0.0, 1.0, 0.0);
                glRotatef(tab_coo[wl_int_003][7], 0.0, 0.0, 1.0);

                glLoadName(wl_int_003);

                glBegin(GL_QUADS);
                glColor3ub(10+(wl_int_003*10),0,0);

                //float wl_x = (float)(0-(2 * (tab_diapo[wl_int_001][1].toFloat() / tab_diapo[wl_int_001][2].toFloat()))) * -1;

                if ( tab_diapo[wl_int_003][7] == "0/0/0/0" )
                {
                    wl_x = (float)(0-(2 * (tab_diapo[wl_int_003][1].toFloat() / tab_diapo[wl_int_003][2].toFloat()))) * -1;
                }
                else
                {
                    QStringList wl_explode = tab_diapo[wl_int_003][7].split("/",QString::KeepEmptyParts);

                    wl_x = (float)(0-(2 * ((wl_explode.at(2).toFloat()-wl_explode.at(0).toFloat()) / (wl_explode.at(3).toFloat()-wl_explode.at(1).toFloat())))) * -1;
                }

                glVertex3f(wl_x*scale_factor , -2.0f*scale_factor , 0.0f);
                glVertex3f(wl_x*scale_factor , 2.0f*scale_factor , 0.0f);
                glVertex3f(-wl_x*scale_factor , 2.0f*scale_factor , 0.0f);
                glVertex3f(-wl_x*scale_factor , -2.0f*scale_factor , 0.0f);

                glEnd();
            }
            else
            {
                // *********************
                // *** AUTRES OBJETS ***
                // *********************
                scale_factor = tab_diapo[wl_int_003][5].toFloat();

                glTranslatef(tab_coo[wl_int_003][0], tab_coo[wl_int_003][1], tab_coo[wl_int_003][2]);
                glRotatef(tab_coo[wl_int_003][5], 1.0, 0.0, 0.0);
                glRotatef(tab_coo[wl_int_003][6], 0.0, 1.0, 0.0);
                glRotatef(tab_coo[wl_int_003][7], 0.0, 0.0, 1.0);

                //glLoadIdentity();
                glColor3ub(10+(wl_int_003*10),0,0);

                /*glTranslatef(tab_coo[wl_int_003][0], tab_coo[wl_int_003][1], tab_coo[wl_int_003][2]);
                glRotatef(tab_coo[wl_int_003][5], 1.0, 0.0, 0.0);
                glRotatef(tab_coo[wl_int_003][6], 0.0, 1.0, 0.0);
                glRotatef(tab_coo[wl_int_003][7], 0.0, 0.0, 1.0);*/

                if ( tab_diapo[wl_int_003][0].mid(1,1) == "1" )
                {
                    glLoadName(wl_int_003);

                    glTranslatef(0, 0, -2.5*scale_factor);

                    quadric = gluNewQuadric();
                    gluQuadricNormals(quadric, GLU_SMOOTH );

                    gluCylinder(quadric, .5*scale_factor, .5*scale_factor, 5*scale_factor, 8, 2);

                    glTranslatef(0, 0, 5*scale_factor);
                    gluCylinder(quadric, .5*scale_factor, 0*scale_factor, 1*scale_factor, 8, 2);

                    glTranslatef(0, 0, 0.5*scale_factor);
                    gluCylinder(quadric, .25*scale_factor, 0*scale_factor, 0.5*scale_factor, 10, 2);

                    glTranslatef(0, 0, -5.5*scale_factor);
                    glRotatef(180, 0, 1, 0);
                    gluDisk(quadric,0,0.5*scale_factor,8*scale_factor,8*scale_factor);
                }
                else
                {
                    if ( tab_diapo[wl_int_003][0].mid(1,1) == "2" )
                    {
                        glLoadName(wl_int_003);

                        glTranslatef(0, 0, -2.5*scale_factor);

                        quadric = gluNewQuadric();
                        gluQuadricNormals(quadric, GLU_SMOOTH );

                        gluCylinder(quadric, .5*scale_factor, .5*scale_factor, 5*scale_factor, 8, 2);

                        glTranslatef(0, 0, 5*scale_factor);
                        gluCylinder(quadric, .5*scale_factor, 0*scale_factor, 1*scale_factor, 8, 2);

                        glTranslatef(0, 0, 0.5*scale_factor);
                        gluCylinder(quadric, .25*scale_factor, 0*scale_factor, 0.5*scale_factor, 10, 2);

                        glTranslatef(0, 0, -5.5*scale_factor);
                        glRotatef(180, 0, 1, 0);
                        gluDisk(quadric,0,0.5*scale_factor,8*scale_factor,8*scale_factor);
                    }
                    else
                    {
                        if ( tab_diapo[wl_int_003][0].mid(1,1) == "3" )
                        {
                            glLoadName(wl_int_003);

                            glTranslatef(0, 0, -2.5*scale_factor);

                            quadric = gluNewQuadric();
                            gluQuadricNormals(quadric, GLU_SMOOTH );

                            gluCylinder(quadric, .5*scale_factor, .5*scale_factor, 5*scale_factor, 8, 2);

                            glTranslatef(0, 0, 5*scale_factor);
                            gluCylinder(quadric, .5*scale_factor, 0*scale_factor, 1*scale_factor, 8, 2);

                            glTranslatef(0, 0, 0.5*scale_factor);
                            gluCylinder(quadric, .25*scale_factor, 0*scale_factor, 0.5*scale_factor, 10, 2);

                            glTranslatef(0, 0, -5.5*scale_factor);
                            glRotatef(180, 0, 1, 0);
                            gluDisk(quadric,0,0.5*scale_factor,8*scale_factor,8*scale_factor);
                        }
                        else
                        {
                            if ( tab_diapo[wl_int_003][0].mid(1,1) == "4" )
                            {
                                glLoadName(wl_int_003);

                                glTranslatef(0, 0, -2.5*scale_factor);

                                quadric = gluNewQuadric();
                                gluQuadricNormals(quadric, GLU_SMOOTH );

                                gluCylinder(quadric, .5*scale_factor, .5*scale_factor, 5*scale_factor, 8, 2);

                                glTranslatef(0, 0, 5*scale_factor);
                                gluCylinder(quadric, .5*scale_factor, 0*scale_factor, 1*scale_factor, 8, 2);

                                glTranslatef(0, 0, 0.5*scale_factor);
                                gluCylinder(quadric, .25*scale_factor, 0*scale_factor, 0.5*scale_factor, 10, 2);

                                glTranslatef(0, 0, -5.5*scale_factor);
                                glRotatef(180, 0, 1, 0);
                                gluDisk(quadric,0,0.5*scale_factor,8*scale_factor,8*scale_factor);
                            }
                            else
                            {
                                if ( tab_diapo[wl_int_003][0].mid(1,1) == "5" )
                                {
                                    glLoadName(wl_int_003);

                                    glDisable( GL_LIGHTING ) ;
                                    glDisable( GL_LIGHT0 );
                                    glDisable(GL_TEXTURE_2D);

                                    //glBindTexture( GL_TEXTURE_2D, texture_diapo[43] );
                                    //glColor4f(1.0f,1.0f,1.0f,1.0f);
                                    //glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);

                                    /*glBegin(GL_QUADS);

                                    glColor4f(1.0,1.0,1.0,1.0);

                                    glTexCoord2f(1.0, 0.0);
                                    glVertex3f(2.0f*scale_factor , -2.0f*scale_factor , 0.0f);

                                    glTexCoord2f(1.0, 1.0);
                                    glVertex3f(2.0f*scale_factor , 2.0f*scale_factor , 0.0f);

                                    glTexCoord2f(0.0, 1.0);
                                    glVertex3f(-2.0f*scale_factor , 2.0f*scale_factor , 0.0f);

                                    glTexCoord2f(0.0, 0.0);
                                    glVertex3f(-2.0f*scale_factor , -2.0f*scale_factor , 0.0f);

                                    glEnd();*/

                                    //glColor3f(1.0f, 1.0f, 1.0f);
                                    quadric = gluNewQuadric();
                                    gluQuadricNormals(quadric, GLU_SMOOTH );

                                    glTranslatef(0.0f ,0.75f*scale_factor, 0.0f);
                                    gluSphere(quadric,0.75f*scale_factor,32,32);

                                    glTranslatef(0.0f, 0.95f*scale_factor, 0.0f);
                                    gluSphere(quadric,0.25f*scale_factor,32,32);

                                    glTranslatef(0.1f, 0.0f, 0.18f);
                                    gluSphere(quadric,0.05f*scale_factor,10,10);
                                    glTranslatef(-0.2f*scale_factor, 0.0f, 0.0f);
                                    gluSphere(quadric,0.05f*scale_factor,10,10);

                                    glTranslatef(0.1f*scale_factor, -0.08f*scale_factor, 0.0f);
                                    glRotatef(0.0f,1.0f, 0.0f, 0.0f);
                                    gluCylinder(quadric, 0.06*scale_factor, 0.0, 0.2*scale_factor, 8, 2);

                                    /*glColor3f(1.0f, 0.5f , 0.5f);
                                    glTranslatef(0.0f, -0.5f*scale_factor, -0.5f*scale_factor);
                                    glRotatef(90,0.0f, 1.0f, 0.0f);
                                    gluCylinder(quadric, 0.01*scale_factor, 0.01* scale_factor, 1.0*scale_factor, 8, 2);*/
                                }
                                else
                                {
                                    if ( tab_diapo[wl_int_003][0].mid(1,1) == "6" )
                                    {
                                        glLoadName(wl_int_003);

                                        glBegin(GL_QUADS);

                                        // *** FACE ARRIERE ***
                                        glVertex3f(-1.0f * scale_factor, -1.0f * scale_factor, -1.0f * scale_factor );
                                        glVertex3f(-1.0f * scale_factor,  1.0f * scale_factor, -1.0f * scale_factor );
                                        glVertex3f( 1.0f * scale_factor,  1.0f * scale_factor, -1.0f * scale_factor );
                                        glVertex3f( 1.0f * scale_factor, -1.0f * scale_factor, -1.0f * scale_factor );

                                        // *** FACE DU HAUT ***
                                        glVertex3f(-1.0f * scale_factor,  1.0f * scale_factor , -1.0f * scale_factor );
                                        glVertex3f(-1.0f * scale_factor,  1.0f * scale_factor ,  1.0f * scale_factor );
                                        glVertex3f( 1.0f * scale_factor,  1.0f * scale_factor ,  1.0f * scale_factor );
                                        glVertex3f( 1.0f * scale_factor,  1.0f * scale_factor , -1.0f * scale_factor );

                                        // *** FACE DU BAS ***
                                        glVertex3f(-1.0f * scale_factor , -1.0f * scale_factor , -1.0f * scale_factor );
                                        glVertex3f( 1.0f * scale_factor , -1.0f * scale_factor , -1.0f * scale_factor );
                                        glVertex3f( 1.0f * scale_factor , -1.0f * scale_factor ,  1.0f * scale_factor );
                                        glVertex3f(-1.0f * scale_factor , -1.0f * scale_factor ,  1.0f * scale_factor );

                                        // *** FACE DE GAUCHE ***
                                        glVertex3f(-1.0f * scale_factor , -1.0f * scale_factor, -1.0f * scale_factor );
                                        glVertex3f(-1.0f * scale_factor , -1.0f * scale_factor,  1.0f * scale_factor );
                                        glVertex3f(-1.0f * scale_factor ,  1.0f * scale_factor,  1.0f * scale_factor );
                                        glVertex3f(-1.0f * scale_factor ,  1.0f * scale_factor, -1.0f * scale_factor );

                                        // *** FACE DE DROITE ***
                                        glVertex3f( 1.0f * scale_factor , -1.0f * scale_factor , -1.0f * scale_factor );
                                        glVertex3f( 1.0f * scale_factor ,  1.0f * scale_factor , -1.0f * scale_factor );
                                        glVertex3f( 1.0f * scale_factor ,  1.0f * scale_factor ,  1.0f * scale_factor );
                                        glVertex3f( 1.0f * scale_factor , -1.0f * scale_factor ,  1.0f * scale_factor );

                                        // *** FACE AVANT ***
                                        glVertex3f(-1.0f * scale_factor , -1.0f * scale_factor ,  1.0f * scale_factor );
                                        glVertex3f( 1.0f * scale_factor , -1.0f * scale_factor ,  1.0f * scale_factor );
                                        glVertex3f( 1.0f * scale_factor ,  1.0f * scale_factor ,  1.0f * scale_factor );
                                        glVertex3f(-1.0f * scale_factor ,  1.0f * scale_factor ,  1.0f * scale_factor );

                                        glEnd();
                                    }
                                    else
                                    {
                                        if ( tab_diapo[wl_int_003][0].mid(1,1) == "7" )
                                        {
                                            glLoadName(wl_int_003);

                                            quadric = gluNewQuadric();
                                            gluQuadricNormals(quadric, GLU_SMOOTH );

                                            gluSphere(quadric,1.0f*scale_factor,25,25);
                                        }
                                        else
                                        {
                                            if ( tab_diapo[wl_int_003][0].mid(1,1) == "8" )
                                            {
                                                glLoadName(wl_int_003);

                                                glBegin(GL_TRIANGLE_STRIP);

                                                glVertex3f(-7.0*scale_factor, 0.0*scale_factor, 2.0*scale_factor);
                                                glVertex3f(-1.0*scale_factor, 0.0*scale_factor, 3.0*scale_factor);
                                                glVertex3f(-1.0*scale_factor, 7.0*scale_factor, 3.0*scale_factor);
                                                glVertex3f(0.0*scale_factor, 0.0*scale_factor, 0.0*scale_factor);
                                                glVertex3f(0.0*scale_factor, 8.0*scale_factor, 0.0*scale_factor);
                                                glVertex3f(1.0*scale_factor, 0.0*scale_factor, 3.0*scale_factor);
                                                glVertex3f(1.0*scale_factor, 7.0*scale_factor, 3.0*scale_factor);
                                                glVertex3f(7.0*scale_factor, 0.0*scale_factor, 2.0*scale_factor);

                                                glEnd();
                                            }
                                            else
                                            {
                                                scale_factor = tab_diapo[wl_int_003][5].toFloat();

                                                glLoadName(wl_int_003);

                                                glBegin(GL_QUADS);

                                                //float wl_x = (float)(0-(2 * (tab_diapo[wl_int_001][1].toFloat() / tab_diapo[wl_int_001][2].toFloat()))) * -1;

                                                if ( tab_diapo[wl_int_003][7] == "0/0/0/0" )
                                                {
                                                    wl_x = (float)(0-(2 * (tab_diapo[wl_int_003][1].toFloat() / tab_diapo[wl_int_003][2].toFloat()))) * -1;
                                                }
                                                else
                                                {
                                                    QStringList wl_explode = tab_diapo[wl_int_003][7].split("/",QString::KeepEmptyParts);

                                                    wl_x = (float)(0-(2 * ((wl_explode.at(2).toFloat()-wl_explode.at(0).toFloat()) / (wl_explode.at(3).toFloat()-wl_explode.at(1).toFloat())))) * -1;
                                                }

                                                glVertex3f(wl_x*scale_factor , -2.0f*scale_factor , 0.0f);
                                                glVertex3f(wl_x*scale_factor , 2.0f*scale_factor , 0.0f);
                                                glVertex3f(-wl_x*scale_factor , 2.0f*scale_factor , 0.0f);
                                                glVertex3f(-wl_x*scale_factor , -2.0f*scale_factor , 0.0f);

                                                glEnd();
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
        //

        wl_int_001++;
    }
}

// *****************************
// *** SELECTION DE L'OUTILS ***
// *****************************

void Tetrahedron::f_change_tool_grab()
{
    tool = 0;
    wg_has_mx = 0;
    wg_has_my = 0;
    wg_has_mz = 0;
    emit tool_change(0);
}

void Tetrahedron::f_change_tool_grab_x()
{
    tool = 0;
    wg_has_mx = 1;
    wg_has_my = 0;
    wg_has_mz = 0;
    emit tool_change(0);
}

void Tetrahedron::f_change_tool_grab_y()
{
    tool = 0;
    wg_has_mx = 0;
    wg_has_my = 1;
    wg_has_mz = 0;
    emit tool_change(0);
}

void Tetrahedron::f_change_tool_rotate_l()
{
    tool = 4;
    emit tool_change(4);
}

void Tetrahedron::f_change_tool_rotate_x()
{
    tool = 1;
    emit tool_change(1);
}

void Tetrahedron::f_change_tool_rotate_y()
{
    tool = 2;
    emit tool_change(2);
}

void Tetrahedron::f_change_tool_rotate_z()
{
    tool = 3;
    emit tool_change(3);
}

void Tetrahedron::f_change_tool_rotate_x_fi()
{
    tool = 1;
}

void Tetrahedron::f_change_tool_rotate_y_fi()
{
    tool = 2;
}

void Tetrahedron::f_change_tool_rotate_z_fi()
{
    tool = 3;
}

void Tetrahedron::f_change_tool_grab_fi()
{
    tool = 0;
}

void Tetrahedron::f_change_tool_rotate_l_fi()
{
    tool = 4;
}

// **************************
// *** FONCTIONS TIMELINE ***
// **************************

void Tetrahedron::f_mark_pos(int pos_timeline, int visible, int opacite, int blur)
{
    if ( num_select > 0 )
    {
        int j = 0;
        int ok = 0;
        QStringList wl_exp;

        while ( j < 20 && tab_coo_timeline[num_select][j] != "" && ok == 0 )
        {
            wl_exp = tab_coo_timeline[num_select][j].split(":",QString::SkipEmptyParts);
            if ( wl_exp.at(0).toInt() == pos_timeline || wl_exp.at(0).toInt() > pos_timeline )
            {
                ok = 1;
            }
            else
            {
                j++;
            }
        }

        if ( j == 20 )
        {
            QMessageBox::information(this, name_application, tr("Nombre maximum de keyframe pour cette image atteint."));
            return;
        }

        if ( ok == 1 )
        {
            if ( wl_exp.at(0).toInt() == pos_timeline )
            {
                if ( wl_exp.at(wl_exp.count()-3).toInt() != visible )
                {
                    tab_coo_timeline[num_select][j] = wl_exp.at(0) + ":" + wl_exp.at(1) + ":" + wl_exp.at(2) + ":" + wl_exp.at(3) + ":" + wl_exp.at(4) + ":" + wl_exp.at(5) + ":" + wl_exp.at(6) + ":" + QString::number(visible) + ":" + QString::number(opacite) + ":" + QString::number(blur);
                }
                else
                {
                    tab_coo_timeline[num_select][j] = QString::number(pos_timeline) + ":" + QString::number(tab_coo[num_select][0]) + ":" + QString::number(tab_coo[num_select][1]) + ":" + QString::number(tab_coo[num_select][2]) + ":" + QString::number(tab_coo[num_select][5]) + ":" + QString::number(tab_coo[num_select][6]) + ":" + QString::number(tab_coo[num_select][7]) + ":" + QString::number(visible) + ":" + QString::number(opacite) + ":" + QString::number(blur);
                }
                //qDebug() << opacite << " " << tab_coo_timeline[num_select][j] << " -- " << num_select << " " << j;
            }
            else
            {
                int wl_int_001 = j;
                while ( wl_int_001 < 20 && tab_coo_timeline[num_select][wl_int_001] != "" )
                {
                    wl_int_001++;
                }

                while ( wl_int_001 > j )
                {
                    tab_coo_timeline[num_select][wl_int_001] = tab_coo_timeline[num_select][wl_int_001-1];
                    wl_int_001--;
                }
                tab_coo_timeline[num_select][j] = QString::number(pos_timeline) + ":" + QString::number(tab_coo[num_select][0]) + ":" + QString::number(tab_coo[num_select][1]) + ":" + QString::number(tab_coo[num_select][2]) + ":" + QString::number(tab_coo[num_select][5]) + ":" + QString::number(tab_coo[num_select][6]) + ":" + QString::number(tab_coo[num_select][7]) + ":" + QString::number(visible) + ":" + QString::number(opacite) + ":" + QString::number(blur);

                j = 0;
                while ( j < 10 )
                {
                    j++;
                }
            }
        }
        else
        {
            tab_coo_timeline[num_select][j] = QString::number(pos_timeline) + ":" + QString::number(tab_coo[num_select][0]) + ":" + QString::number(tab_coo[num_select][1]) + ":" + QString::number(tab_coo[num_select][2]) + ":" + QString::number(tab_coo[num_select][5]) + ":" + QString::number(tab_coo[num_select][6]) + ":" + QString::number(tab_coo[num_select][7]) + ":" + QString::number(visible) + ":" + QString::number(opacite) + ":" + QString::number(blur);
        }

        emit dia_select(num_select);
    }
}

void Tetrahedron::f_mark_vis(int pos_timeline, int visible)
{
    if ( num_select > 0 )
    {
        int j = 0;
        int ok = 0;
        QStringList wl_exp;

        while ( j < 20 && tab_coo_timeline[num_select][j] != "" && ok == 0 )
        {
            wl_exp = tab_coo_timeline[num_select][j].split(":",QString::SkipEmptyParts);
            if ( wl_exp.at(0).toInt() == pos_timeline || wl_exp.at(0).toInt() > pos_timeline )
            {
                ok = 1;
            }
            else
            {
                j++;
            }
        }

        //qDebug() << "MVIS=" << tab_coo_timeline[num_select][j];

        if ( ok == 1 )
        {
            if ( wl_exp.at(0).toInt() == pos_timeline )
            {
                QString visibletr = QString::number(visible);
                    QString visibletr2;

                    if ( visibletr.mid(0,1) == "2" )
                    {
                        visibletr2 = "2" + visibletr.mid(1,visibletr.length()-1);
                    }
                    else
                    {
                        visibletr2 = "1" + visibletr.mid(1,visibletr.length()-1);
                    }

                    tab_coo_timeline[num_select][j] = wl_exp.at(0) + ":" + wl_exp.at(1) + ":" + wl_exp.at(2) + ":" + wl_exp.at(3) + ":" + wl_exp.at(4) + ":" + wl_exp.at(5) + ":" + wl_exp.at(6) + ":" + visibletr2 + ":" + wl_exp.at(8) + ":" + wl_exp.at(9);
            }
            else
            {
                qDebug() << "ERROR CHANGING VIEW STATE - NO MATCHING POINT FOUND (ERR 1)";
            }
        }
        else
        {
            qDebug() << "ERROR CHANGING VIEW STATE - NO MATCHING POINT FOUND (ERR 2)";
        }

        emit dia_select(num_select);
    }
}

void Tetrahedron::f_follow_timeline(int position)
{
    position_timeline = position;

    int i = 1;
    int j = 0;

    int minpos = 0;
    int maxpos = 10000;

    int minidx = 0;
    int maxidx = 0;

    float dep_px;
    float dep_py;
    float dep_pz;
    float dep_rx;
    float dep_ry;
    float dep_rz;
    float fin_px;
    float fin_py;
    float fin_pz;
    float fin_rx;
    float fin_ry;
    float fin_rz;
    int dep_opa = 0;
    int fin_opa = 0;
    int dep_blur = 0;
    int fin_blur = 0;

    int dep_pos;
    int fin_pos;

    float wl_cl = 0;
    int wl_ix = 0;

    float wl_rp;
    float rst;
    int fra;

    QStringList wl_explode;
    QImage wl_puis_001(1024,1024,QImage::Format_ARGB32_Premultiplied);
    QImage wl_img_texture;
    QImage f;
    QString wl_strtr;
    QString wl_tmps;

    while ( i <= nombre_diapos )
    {
        j = 0;

        while ( tab_coo_timeline[i][j] != "" )
        {
            wl_explode = tab_coo_timeline[i][j].split(":",QString::SkipEmptyParts); //QString::KeepEmptyParts);

            if ( wl_explode.at(0).toInt() < position && wl_explode.at(0).toInt() > minpos )
            {
                minidx = j;
                minpos = wl_explode.at(0).toInt();
            }
            if ( wl_explode.at(0).toInt() >= position && wl_explode.at(0).toInt() < maxpos )
            {
                maxidx = j;
                maxpos = wl_explode.at(0).toInt();
            }
            j++;
        }

        if ( tab_diapo[i][0].right(4) == ".gif" || tab_diapo[i][0].right(4) == ".GIF" )
        {
            // *** LECTURE FRAME GIF ANIME ***

            wl_cl = 0;
            wl_ix = 0;

            tabgif[i].jumpToFrame(0);

            while ( wl_ix < tabgif[i].frameCount() )
            {
                wl_cl = wl_cl + tabgif[i].nextFrameDelay();
                wl_ix++;
            }

            wl_rp = (float)(((float)position-10)*(float)length_diapo)/(float)680;
            wl_rp = wl_rp * 1000;

            rst = fmod(wl_rp,wl_cl);

            fra = (rst*(wl_ix-1))/wl_cl;

            tabgif[i].jumpToFrame(fra);

            wl_img_texture = tabgif[i].currentImage();

            if ( wl_img_texture.width() > wl_img_texture.height() )
            {
                wl_img_texture = wl_img_texture.scaledToWidth(1024,Qt::SmoothTransformation);
            }
            else
            {
                wl_img_texture = wl_img_texture.scaledToHeight(1024,Qt::SmoothTransformation);
            }

            wl_puis_001 = wl_img_texture.copy ( 0, 0, 1024, 1024); //1024, 1024);

            wg_table_photo[i] = wl_puis_001;

            glDeleteTextures (1,&texture_diapo[i]);
            f = QGLWidget::convertToGLFormat( wl_puis_001 );

            glGenTextures (1,&texture_diapo[i]);
            glBindTexture (GL_TEXTURE_2D, texture_diapo[i]);

            glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
            glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);

            glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, f.width(), f.height(),
                          0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits());
        }

        // *** CALCUL DE LA POSITION ***

        wl_explode = tab_coo_timeline[i][minidx].split(":",QString::SkipEmptyParts);

        dep_px = wl_explode.at(1).toFloat();
        dep_py = wl_explode.at(2).toFloat();
        dep_pz = wl_explode.at(3).toFloat();
        dep_rx = wl_explode.at(4).toFloat();
        dep_ry = wl_explode.at(5).toFloat();
        dep_rz = wl_explode.at(6).toFloat();

        dep_pos = wl_explode.at(0).toInt();
        tab_coo[i][8] = wl_explode.at(wl_explode.count()-3).toInt(); // *** VISIBILITE ***

        dep_opa = wl_explode.at(wl_explode.count()-2).toInt();
        dep_blur = wl_explode.at(wl_explode.count()-1).toInt();
        //is_visible = wl_explode.at(wl_explode.count()-1).toInt();

        wl_explode = tab_coo_timeline[i][maxidx].split(":",QString::SkipEmptyParts);

        fin_px = wl_explode.at(1).toFloat();
        fin_py = wl_explode.at(2).toFloat();
        fin_pz = wl_explode.at(3).toFloat();
        fin_rx = wl_explode.at(4).toFloat();
        fin_ry = wl_explode.at(5).toFloat();
        fin_rz = wl_explode.at(6).toFloat();

        fin_pos = wl_explode.at(0).toInt();

        fin_opa = wl_explode.at(wl_explode.count()-2).toInt();
        fin_blur = wl_explode.at(wl_explode.count()-1).toInt();

        wl_strtr = QString::number(tab_coo[i][8]);

        if ( wl_explode.at(wl_explode.count()-3).mid(1,2) != "0" &&  wl_explode.at(wl_explode.count()-3).mid(1,2) != "00" )
        {
            if ( wl_explode.at(wl_explode.count()-3).mid(0,1) == "2" && wl_strtr.mid(0,1) != "2" )
            {
                if ( position >= dep_pos )
                {
                    alpha_blend = (((position-dep_pos)*100)/(fin_pos-dep_pos));
                }
                else
                {
                    if ( tab_coo[i][11] > 0 )
                    {
                        alpha_blend = 0;
                    }
                    //alpha_blend = -1;
                }
            }
            else
            {
                if ( wl_explode.at(wl_explode.count()-3).mid(0,1) == "1" && wl_strtr.mid(0,1) == "2" )
                {
                    if ( position <= fin_pos && position >= dep_pos )
                    {
                        alpha_blend = 100-(((position-dep_pos)*100)/(fin_pos-dep_pos));
                    }
                    else
                    {
                        if ( tab_coo[i][11] > 0 )
                        {
                            alpha_blend = 0;
                        }
                    }
                }
                else
                {
                    if ( wl_explode.at(wl_explode.count()-3).mid(0,1) == "1" && wl_strtr.mid(0,1) != "1" && tab_coo[i][11] > 0 )
                    {
                        alpha_blend = 0;
                    }
                    else
                    {
                        if ( wl_explode.at(wl_explode.count()-3).mid(0,1) == "1" && wl_strtr.mid(0,1) != "2" && tab_coo[i][11] > 0 )
                        {
                            alpha_blend = 0;
                        }
                    }
                }
            }
            if ( alpha_blend > 0 )
            {
                wl_tmps = "";
                wl_tmps = QString::number(alpha_blend) + wl_explode.at(wl_explode.count()-3).mid(1,2);
                tab_coo[i][11] = wl_tmps.toInt();
            }
            else
            {
                tab_coo[i][11] = alpha_blend;
            }
        }
        else
        {
            if ( minidx >= 1 )
            {
                wl_explode = tab_coo_timeline[i][minidx-1].split(":",QString::SkipEmptyParts);
                wl_strtr = wl_explode.at(wl_explode.count()-3);

                if ( wl_strtr.mid(0,1) == "2" )
                {
                   tab_coo[i][11] = 0;
                }
                else
                {
                    if ( tab_coo[i][11] > 0 && tab_coo[i][11] < 1000 )
                    {
                        tab_coo[i][11] = -1;
                    }
                    else
                    {
                        tab_coo[i][11] = -1;
                    }
                }
            }
            else
            {
                if ( tab_coo[i][11] > 0 )
                {
                    tab_coo[i][11] = 0;
                }
                else
                {
                    tab_coo[i][11] = -1;
                }
            }
        }

        if ( dep_pos != position && fin_pos != position )
        {
            tab_coo[i][0] = dep_px+(((fin_px-dep_px)/(fin_pos-dep_pos))*(position-dep_pos));
            tab_coo[i][1] = dep_py+(((fin_py-dep_py)/(fin_pos-dep_pos))*(position-dep_pos));
            tab_coo[i][2] = dep_pz+(((fin_pz-dep_pz)/(fin_pos-dep_pos))*(position-dep_pos));

            tab_coo[i][5] = dep_rx+(((fin_rx-dep_rx)/(fin_pos-dep_pos))*(position-dep_pos));
            tab_coo[i][6] = dep_ry+(((fin_ry-dep_ry)/(fin_pos-dep_pos))*(position-dep_pos));
            tab_coo[i][7] = dep_rz+(((fin_rz-dep_rz)/(fin_pos-dep_pos))*(position-dep_pos));

            if ( dep_opa == 100 && fin_opa == 100 )
            {
                tab_coo[i][9] = 100;
            }
            else
            {
                if ( fin_opa < dep_opa )
                {
                    tab_coo[i][9] = (float)dep_opa+((((float)fin_opa-(float)dep_opa)/(float)((float)fin_pos-(float)dep_pos))*(float)((float)position-(float)dep_pos));
                }
                else
                {
                    if ( fin_opa > dep_opa )
                    {
                        tab_coo[i][9] = (float)((((float)fin_opa-(float)dep_opa)/(float)((float)fin_pos-(float)dep_pos))*(float)((float)position-(float)dep_pos));
                    }
                    else
                    {
                        tab_coo[i][9] = (float)fin_opa;
                    }
                }
            }

            if ( dep_blur == 0 && fin_blur == 0 )
            {
                tab_coo[i][10] = 0;
                if ( tab_old_blur[i] > 0 )
                {
                    f_reload_img(i);
                }
            }
            else
            {
                if ( fin_blur < dep_blur )
                {
                    tab_coo[i][10] = (float)dep_blur+((((float)fin_blur-(float)dep_blur)/(float)((float)fin_pos-(float)dep_pos))*(float)((float)position-(float)dep_pos));
                }
                else
                {
                    if ( fin_blur > dep_blur )
                    {
                        tab_coo[i][10] = (float)((((float)fin_blur-(float)dep_blur)/(float)((float)fin_pos-(float)dep_pos))*(float)((float)position-(float)dep_pos));
                    }
                    else
                    {
                        tab_coo[i][10] = (float)fin_blur;
                    }
                }

                f_reload_img(i);
            }
        }
        else
        {
            if ( dep_pos == position )
            {
                tab_coo[i][0] = dep_px;
                tab_coo[i][1] = dep_py;
                tab_coo[i][2] = dep_pz;

                tab_coo[i][5] = dep_rx;
                tab_coo[i][6] = dep_ry;
                tab_coo[i][7] = dep_rz;

                tab_coo[i][9] = dep_opa;
                tab_coo[i][10] = dep_blur;
            }
            else
            {
                tab_coo[i][0] = fin_px;
                tab_coo[i][1] = fin_py;
                tab_coo[i][2] = fin_pz;

                tab_coo[i][5] = fin_rx;
                tab_coo[i][6] = fin_ry;
                tab_coo[i][7] = fin_rz;

                tab_coo[i][9] = fin_opa;
                tab_coo[i][10] = fin_blur;
            }

            if ( dep_opa != 0 || fin_opa != 0 || tab_old_blur[i] > 0 || tab_coo[i][10] != tab_old_blur[i] )
            {
                f_reload_img(i);
            }
        }

        tab_old_blur[i] = tab_coo[i][10];

        if ( i == num_select )
        {
            emit update_coo();
        }

        minpos = 0;
        maxpos = 10000;

        minidx = 0;
        maxidx = 0;

        i++;
    }
    updateGL();
}

void Tetrahedron::f_save_diapo(int num_diapo)
{
    int wl_int_001 = 1;
    int wl_int_002;
    QString wg_str_001 = "";

    //qDebug() << "--------------------------------------";

    while ( wl_int_001 < nombre_diapos+1 )
    {
        wl_int_002 = 0;

        wg_str_001 = tab_diapo[wl_int_001][0] + "$";
        wg_str_001 = wg_str_001 + tab_diapo[wl_int_001][1] + "$";
        wg_str_001 = wg_str_001 + tab_diapo[wl_int_001][2] + "$";
        wg_str_001 = wg_str_001 + tab_diapo[wl_int_001][3] + "$";
        wg_str_001 = wg_str_001 + tab_diapo[wl_int_001][4] + "$";
        wg_str_001 = wg_str_001 + tab_diapo[wl_int_001][5] + "$"; // *** SCALE FACTOR ***
        wg_str_001 = wg_str_001 + tab_diapo[wl_int_001][6] + "$"; // *** REFLECT ***
        wg_str_001 = wg_str_001 + tab_diapo[wl_int_001][7] + "$"; // *** CROP ***
        wg_str_001 = wg_str_001 + tab_diapo[wl_int_001][8] + "$"; // *** SENS EXIF ***

        while ( tab_coo_timeline[wl_int_001][wl_int_002] != "" )
        {
            wg_str_001 = wg_str_001 + tab_coo_timeline[wl_int_001][wl_int_002] + "$";
            wl_int_002++;
        }
        tab_save_diapo[num_diapo][wl_int_001]=wg_str_001;
        //qDebug() << tab_save_diapo[num_diapo][wl_int_001];
        wl_int_001++;
    }
    tab_save_diapo[num_diapo][wl_int_001]="$#$";
    tab_save_diapo[num_diapo][wl_int_001+1]=QString::number(length_diapo);
    tab_save_diapo[num_diapo][wl_int_001+2]=back_color;
    tab_save_diapo[num_diapo][wl_int_001+3]=str_trans + "}" + QString::number(lgt_trans);
    tab_save_diapo[num_diapo][wl_int_001+4]=QString::number(is_mblur);
    tab_save_diapo[num_diapo][wl_int_001+5]=QString::number(is_fog) + ":" + QString::number(fog_red) + ":" + QString::number(fog_green) + ":" + QString::number(fog_blue);
}

void Tetrahedron::f_init_tabcoo()
{
    // *** INITIALISATION DES TABLES DE COORDONNEES ***

    int i = 0;
    int j = 0;

    while ( i < 20 )
    {
        j = 0;
        while ( j < 20 )
        {
            tab_coo_timeline[i][j] = "";
            tab_coo[i][j] = 0.0;

            j++;
        }
        //tab_old_blending[i] = -1;
        i++;
    }
}

void Tetrahedron::f_init_tabtex()
{
    // *** INITIALISATION DES TABLES DE COORDONNEES ***

    int i = 0;
    int j = 0;
    isback = 0;

    while ( i < 20 )
    {
        j = 0;
        while ( j < 7 ) //3
        {
            tab_diapo[i][j] = "";
            j++;
        }
        i++;
    }
}

void Tetrahedron::f_init_coo_one_slide(int numdia)
{
    int wl_int_001 = 0;

    while ( wl_int_001 < 20 )
    {
        tab_coo_timeline[numdia][wl_int_001] = "";
        wl_int_001++;
    }
}

// **************
// *** THEMES ***
// **************

void Tetrahedron::f_load_theme(QString thm, QString nameth)
{
    // *** NETTOYAGE DE L'ACCUM BUFFER ***
    glClearAccum(0.0, 0.0, 0.0, 1.0);
    glClear(GL_DEPTH_BUFFER_BIT);
    glAccum(GL_LOAD, 1.0);
    is_mblur = 0;
    updateGL();

    QStringList wl_exp;
    QStringList wl_exp_2;
    QStringList wl_exp_3;
    wl_exp = thm.split("_",QString::SkipEmptyParts);
    QImage wl_puis_001(1024,1024,QImage::Format_ARGB32_Premultiplied);
    QImage wl_img_texture;
    QImage f;
    QFont myfont;
    myfont.setPixelSize ( 400 );
    QPainter p;
    int wl_indx;
    int wl_nb_diap = 0;;
    int wl_exnew = 0;

    //f_init_tabcoo();

    //int tmpsup;

    if ( this->width() == 720 && ( wl_exp.at(0) == "0" || wl_exp.at(0) == "2" ) )
    {
        ratio_import=1.0;
    }
    else
    {
        ratio_import=1.4222222;
    }

    //qDebug() << nameth << " " << thm;

    emit change_length(wl_exp.at(1).toInt());
    is_mblur = wl_exp.at(2).toInt();
    //qDebug() << nombre_diapos;

    //if ( nameth.right(6) != "_theme" )
    //{
        for (int i = 3; i < wl_exp.size(); ++i)
        {
            wl_nb_diap = i-2;
            //qDebug() << wl_exp.at(i);

            if ( i-2 <= nombre_diapos )
            {  // *** UNE DIAPO AVEC LE MEME NUMERO EXISTE ***
                wl_exp_2 = wl_exp.at(i).split("$",QString::SkipEmptyParts); //SkipEmptyParts

                wl_indx = 0;
                while ( wl_indx < 20 )
                {
                    tab_coo_timeline[i-2][wl_indx] = "";
                    tab_coo[i-2][wl_indx] = 0.0;

                    wl_indx++;
                }

                for (int j = 0; j < wl_exp_2.size(); ++j)
                {
                        if ( j == 0 )
                        {
                            wl_exp_3 = wl_exp_2.at(j).split(":",QString::KeepEmptyParts);

                            tab_coo[i-2][0] = wl_exp_3.at(2).toFloat()*ratio_import;      // *** X ***
                            tab_coo[i-2][1] = wl_exp_3.at(3).toFloat();      // *** Y ***
                            tab_coo[i-2][2] = wl_exp_3.at(4).toFloat();      // *** Z ***
                            tab_coo[i-2][3] = wl_exp_3.at(2).toFloat()*ratio_import;      // *** OLD POS X ***
                            tab_coo[i-2][4] = wl_exp_3.at(3).toFloat();      // *** OLD POS Y ***
                            tab_coo[i-2][5] = wl_exp_3.at(5).toFloat();      // *** ROTATE X ***
                            tab_coo[i-2][6] = wl_exp_3.at(6).toFloat();      // *** ROTATE Y ***
                            tab_coo[i-2][7] = wl_exp_3.at(7).toFloat();      // *** ROTATE Z ***
                            tab_coo[i-2][8] = wl_exp_3.at(8).toFloat();      // *** VISIBLE ***
                            tab_coo[i-2][9] = wl_exp_3.at(9).toFloat();      // *** TRANSPARENCE ***
                            tab_diapo[i-2][6] = wl_exp_3.at(0);              // *** REFLECT ***
                            tab_diapo[i-2][7] = "0/0/0/0";                   // *** CROP ***
                            tab_diapo[i-2][3] = wl_exp_3.at(12);              // *** MASK ***
                            tab_diapo[i-2][3].replace(QString("underscore"), QString("_"));

                            tab_coo_timeline[i-2][j] = wl_exp_2.at(j).mid(6,wl_exp_2.at(j).lastIndexOf( ":" )-6);
                            //qDebug() << tab_coo_timeline[i-1][j];

                            //qDebug() << i-1 << " <-> " << tab_coo[i+1][0] << " " << tab_coo[i+1][1] << " " << tab_coo[i+1][2] << " " << tab_coo[i+1][5] << " " << tab_coo[i+1][6] << " " << tab_coo[i+1][7];
                        }
                        else
                        {
                            tab_coo_timeline[i-2][j] = wl_exp_2.at(j);
                            //qDebug() << "1 = " << tab_coo_timeline[i-1][j];
                        }
                }

                glDeleteTextures(1, &texture_diapo[i-2] );
                QImage wl_puis_001(1024,1024,QImage::Format_ARGB32); //_Premultiplied

                //qDebug() << qApp->applicationDirPath() + "/Bibliotheque/3d/" + nameth + "_" + QString::number(i-2) + ".png";

                if ( wl_img_texture.load(qApp->applicationDirPath() + "/Bibliotheque/3d/" + nameth + "_" + QString::number(i-2) + ".png") == true )
                {
                    if ( wl_img_texture.width() > wl_img_texture.height() )
                    {
                        wl_img_texture = wl_img_texture.scaledToWidth(1024,Qt::SmoothTransformation);
                    }
                    else
                    {
                        wl_img_texture = wl_img_texture.scaledToHeight(1024,Qt::SmoothTransformation);
                    }

                    wl_puis_001 = wl_img_texture.copy ( 0, 0, 1024, 1024);
                    wl_exnew = 1;
                }
                else
                {
                    if ( tab_diapo[i-2][0] == "NULL" )
                    {
                        p.begin(&wl_puis_001);
                        p.setBrush(QColor(50,50,50));
                        p.setPen(QColor(20,20,20));
                        p.drawRect(0,0,1024,1024);
                        p.setFont(myfont);
                        p.setPen(QColor(255,255,255));
                        p.drawText(QRect(0,0,1024,1024), Qt::AlignCenter,QString::number(i-2));
                        p.end();
                    }
                    else
                    {
                        wl_puis_001.load(tab_diapo[i-2][0]);
                        if ( wl_puis_001.width() > wl_puis_001.height() )
                        {
                            wl_puis_001 = wl_puis_001.scaledToWidth(1024,Qt::SmoothTransformation);
                        }
                        else
                        {
                            wl_puis_001 = wl_puis_001.scaledToHeight(1024,Qt::SmoothTransformation);
                        }
                    }
                    wl_exnew = 0;
                }

                if ( tab_diapo[i-2][3] != "" )
                {
                    QPainter g;

                    QPainter::CompositionMode mode = (QPainter::CompositionMode)6;

                    QStringList wl_explode = tab_diapo[i-2][3].split("%*",QString::KeepEmptyParts);

                    QImage wl_image_2(qApp->applicationDirPath()+"/Bibliotheque/Masks/"+wl_explode.at(0)+".png");

                    wl_image_2 = wl_image_2.scaled(wl_puis_001.width(),wl_puis_001.height());
                    wl_image_2 = wl_image_2.convertToFormat ( QImage::Format_ARGB32, Qt::AutoColor ); //_Premultiplied

                    g.begin(&wl_puis_001);
                    g.setCompositionMode ( mode );
                    g.drawImage(QRect(0,0,-1,-1),wl_image_2);

                    QImage wl_over_mask;

                    QString wl_str_001 = qApp->applicationDirPath() + "/Bibliotheque/Masks/2t_" + wl_explode.at(0) + ".png";

                    if ( wl_over_mask.load(wl_str_001) == true )
                    {
                        wl_over_mask = wl_over_mask.scaled(wl_puis_001.width(),wl_puis_001.height());

                        wl_over_mask = f_mutation_overmask(wl_over_mask,wl_explode.at(1) + "%*" + wl_explode.at(2) + "%*" + wl_explode.at(3) + "%*" + wl_explode.at(4));

                        wl_over_mask = wl_over_mask.convertToFormat ( QImage::Format_ARGB32, Qt::AutoColor ); //_Premultiplied
                        g.setCompositionMode ( (QPainter::CompositionMode)0 );
                        g.drawImage(QRect(0,0,-1,-1),wl_over_mask);
                    }

                    g.end();
                }
                if ( wl_exnew == 1 )
                {
                    tab_diapo[i-2][1] = QString::number(1024);
                    tab_diapo[i-2][2] = QString::number(1024/(wl_img_texture.width()/wl_img_texture.height()));
                }
                tab_diapo[i-2][5] = wl_exp_3.at(1);                                             // *** SCALE ***

                wg_table_photo[i-2] = wl_puis_001;
                f = QGLWidget::convertToGLFormat( wl_puis_001 );

                glDeleteTextures(1, &texture_diapo[i+1] );
                glGenTextures (1,&texture_diapo[i-2]);
                glBindTexture (GL_TEXTURE_2D, texture_diapo[i-2]);

                glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
                glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);

                glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, f.width(), f.height(),
                              0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits());
            }
            else
            { // *** IL FAUT CREER UNE DIAPO ***
                if ( wl_img_texture.load(qApp->applicationDirPath() + "/Bibliotheque/3d/" + nameth + "_" + QString::number(i-2) + ".png") == true )
                {
                    if ( wl_img_texture.width() > wl_img_texture.height() )
                    {
                        wl_img_texture = wl_img_texture.scaledToWidth(1024,Qt::SmoothTransformation);
                    }
                    else
                    {
                        wl_img_texture = wl_img_texture.scaledToHeight(1024,Qt::SmoothTransformation);
                    }

                    wl_puis_001 = wl_img_texture.copy ( 0, 0, 1024, 1024);
                    wl_exnew = 1;
                }
                else
                {
                    p.begin(&wl_puis_001);
                    p.setBrush(QColor(50,50,50));
                    p.setPen(QColor(20,20,20));
                    p.drawRect(0,0,1024,1024);
                    p.setFont(myfont);
                    p.setPen(QColor(255,255,255));
                    p.drawText(QRect(0,0,1024,1024), Qt::AlignCenter,QString::number(i-2));
                    p.end();
                    wl_exnew = 0;
                }

                wl_exp_2 = wl_exp.at(i).split("$",QString::SkipEmptyParts);

                wl_indx = 0;
                while ( wl_indx < 20 )
                {
                    tab_coo_timeline[i-2][wl_indx] = "";
                    tab_coo[i-2][wl_indx] = 0.0;

                    wl_indx++;
                }

                for (int j = 0; j < wl_exp_2.size(); ++j)
                {
                        if ( j == 0 )
                        {
                            wl_exp_3 = wl_exp_2.at(j).split(":",QString::KeepEmptyParts);
                            //qDebug() << wl_exp_2.at(j);

                            tab_coo[i-2][0] = wl_exp_3.at(2).toFloat()*ratio_import;      // *** X ***
                            tab_coo[i-2][1] = wl_exp_3.at(3).toFloat();      // *** Y ***
                            tab_coo[i-2][2] = wl_exp_3.at(4).toFloat();      // *** Z ***
                            tab_coo[i-2][3] = wl_exp_3.at(2).toFloat()*ratio_import;      // *** OLD POS X ***
                            tab_coo[i-2][4] = wl_exp_3.at(3).toFloat();      // *** OLD POS Y ***
                            tab_coo[i-2][5] = wl_exp_3.at(5).toFloat();      // *** ROTATE X ***
                            tab_coo[i-2][6] = wl_exp_3.at(6).toFloat();      // *** ROTATE Y ***
                            tab_coo[i-2][7] = wl_exp_3.at(7).toFloat();      // *** ROTATE Z ***
                            tab_coo[i-2][8] = wl_exp_3.at(8).toFloat();      // *** VISIBLE ***
                            tab_coo[i-2][9] = wl_exp_3.at(9).toFloat();      // *** TRANSPARENCE ***
                            tab_diapo[i-2][6] = wl_exp_3.at(0);              // *** REFLECT ***
                            tab_diapo[i-2][7] = "0/0/0/0";                   // *** CROP ***
                            tab_diapo[i-2][3] = wl_exp_3.at(12);              // *** MASK ***
                            tab_diapo[i-2][3].replace(QString("underscore"), QString("_"));

                            tab_coo_timeline[i-2][j] = wl_exp_2.at(j).mid(6,wl_exp_2.at(j).lastIndexOf( ":" )-6);

                            //qDebug() << i-1 << " <-> " << tab_coo[i+1][0] << " " << tab_coo[i+1][1] << " " << tab_coo[i+1][2] << " " << tab_coo[i+1][5] << " " << tab_coo[i+1][6] << " " << tab_coo[i+1][7];
                        }
                        else
                        {
                            tab_coo_timeline[i-2][j] = wl_exp_2.at(j);
                        }
                }

                if ( tab_diapo[i-2][3] != "" )
                {

                    QPainter g;

                    QPainter::CompositionMode mode = (QPainter::CompositionMode)6;

                    QStringList wl_explode = tab_diapo[i-2][3].split("%*",QString::KeepEmptyParts);

                    QImage wl_image_2(qApp->applicationDirPath()+"/Bibliotheque/Masks/"+wl_explode.at(0)+".png");

                    wl_image_2 = wl_image_2.scaled(wl_puis_001.width(),wl_puis_001.height());
                    wl_image_2 = wl_image_2.convertToFormat ( QImage::Format_ARGB32, Qt::AutoColor ); //_Premultiplied

                    g.begin(&wl_puis_001);
                    g.setCompositionMode ( mode );
                    g.drawImage(QRect(0,0,-1,-1),wl_image_2);

                    QImage wl_over_mask;

                    QString wl_str_001 = qApp->applicationDirPath() + "/Bibliotheque/Masks/2t_" + wl_explode.at(0) + ".png";

                    if ( wl_over_mask.load(wl_str_001) == true )
                    {
                        wl_over_mask = wl_over_mask.scaled(wl_puis_001.width(),wl_puis_001.height());

                        wl_over_mask = f_mutation_overmask(wl_over_mask,wl_explode.at(1) + "%*" + wl_explode.at(2) + "%*" + wl_explode.at(3) + "%*" + wl_explode.at(4));

                        wl_over_mask = wl_over_mask.convertToFormat ( QImage::Format_ARGB32, Qt::AutoColor ); //_Premultiplied
                        g.setCompositionMode ( (QPainter::CompositionMode)0 );
                        g.drawImage(QRect(0,0,-1,-1),wl_over_mask);
                    }

                    g.end();
                }

                wg_table_photo[i-2] = wl_puis_001;
                f = QGLWidget::convertToGLFormat( wl_puis_001 );

                glDeleteTextures(1, &texture_diapo[i-2] );
                glGenTextures (1,&texture_diapo[i-2]);
                glBindTexture (GL_TEXTURE_2D, texture_diapo[i-2]);

                glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
                glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);

                glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, f.width(), f.height(),
                              0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits());

                tab_diapo[i-2][0] = "NULL";                                                     // *** NOM DU FICHIER DIAPO ***
                if ( wl_exnew == 0 )
                {
                    tab_diapo[i-2][1] = QString::number(1024);
                    tab_diapo[i-2][2] = QString::number(1024);
                }
                else
                {
                    tab_diapo[i-2][1] = QString::number(1024);
                    tab_diapo[i-2][2] = QString::number(1024/(wl_img_texture.width()/wl_img_texture.height()));
                }

                tab_diapo[i-2][4] = "0:0";
                //tab_diapo[i-2][5] = "1";
                tab_diapo[i-2][5] = wl_exp_3.at(1);                                             // *** SCALE ***
                //qDebug() << "SCALE=" << tab_diapo[i-2][5];
                tab_diapo[i-2][7] = "0/0/0/0";                                                  // *** CROP ***
                tab_diapo[i-2][8] = "0";                                                        // *** ORIENTATION EXIF ***

                nombre_diapos++;

                emit add_diapo();
            }
        }

        // *** SUPPRESSION DES DIAPOS EN TROP ***

        int j;
        //wl_nb_diap++;
        int nbsup = 0;
        int wl_svix = wl_nb_diap-1;

        while ( wl_nb_diap < nombre_diapos )
        {
            if ( tab_diapo[wl_nb_diap+1][0] != "NULL" )
            {
                glDeleteTextures(1, &texture_diapo[wl_nb_diap+1] );
            }

            j = 0;
            while ( j < 20 )
            {
                tab_coo_timeline[wl_nb_diap+1][j] = "";
                tab_coo[wl_nb_diap+1][j] = 0.0;

                j++;
            }
            j = 0;
            while ( j < 7 )
            {
                tab_diapo[wl_nb_diap+1][j] = "";
                j++;
            }

            emit s_delete_diapo(wl_svix);

            wl_nb_diap++;
            nbsup++;
        }

        nombre_diapos=nombre_diapos-nbsup;

        num_select = 0;
        is_fog = 0;

        //QImage wl_img_texture;

        if ( wl_img_texture.load(qApp->applicationDirPath()+"/Bibliotheque/3d/" + nameth + ".jpg") == true )
        {
            if ( wl_img_texture.width() > wl_img_texture.height() )
            {
                wl_img_texture = wl_img_texture.scaledToWidth(1024,Qt::SmoothTransformation);
            }
            else
            {
                wl_img_texture = wl_img_texture.scaledToHeight(1024,Qt::SmoothTransformation);
            }

            QImage wl_puis_001(1024,1024,QImage::Format_ARGB32_Premultiplied);
            wl_puis_001 = wl_img_texture.copy ( 0, 0, 1024, 1024);

            wg_fd_tx = (float)wl_img_texture.width()/(float)1024;
            wg_fd_ty = (float)wl_img_texture.height()/(float)1024;

            QImage f = QGLWidget::convertToGLFormat( wl_puis_001 );

            glDeleteTextures (1,&texture_diapo[41]);
            glGenTextures (1,&texture_diapo[41]);
            glBindTexture (GL_TEXTURE_2D, texture_diapo[41]);

            glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
            glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);

            glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, f.width(), f.height(),
                          0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits());

            isback = 1;
            back_color = qApp->applicationDirPath()+"/Bibliotheque/3d/" + nameth + ".jpg";
            //updateGL();
        }
        else
        {
            isback = 0;
            back_color = "0:0:0";
        }

        //emit update_preview();
        emit move_start();
        //emit update_preview();
        //f_follow_timeline(10);
    /*}
    else
    {  // *** THEME DECORATION ***
        int j;
        int k = 0;

        //qDebug() << nombre_diapos;

        while ( k <= nombre_diapos )
        {
            if ( tab_diapo[k][0] != "NULL" )
            {
                glDeleteTextures(1, &texture_diapo[k] );
            }

            j = 0;
            while ( j < 20 )
            {
                tab_coo_timeline[k][j] = "";
                tab_coo[k][j] = 0.0;

                j++;
            }
            j = 0;
            while ( j < 7 )
            {
                tab_diapo[k][j] = "";
                j++;
            }

            emit s_delete_diapo(k-1);

            k++;
        }

        nombre_diapos = 0;
        QImage wl_puis_001(1024,1024,QImage::Format_ARGB32_Premultiplied);
        QImage wl_img_texture;

        for (int i = 3; i < wl_exp.size(); ++i)
        {
            wl_exp_2 = wl_exp.at(i).split("$",QString::SkipEmptyParts);

            wl_indx = 0;
            while ( wl_indx < 20 )
            {
                tab_coo_timeline[i-2][wl_indx] = "";
                tab_coo[i-2][wl_indx] = 0.0;

                wl_indx++;
            }

            //qDebug() << i << " " << wl_exp.at(i);

            for (int j = 0; j < wl_exp_2.size(); ++j)
            {
                    if ( j == 0 )
                    {
                        wl_exp_3 = wl_exp_2.at(j).split(":",QString::KeepEmptyParts);
                        //qDebug() << wl_exp_2.at(j);

                        tab_coo[i-2][0] = wl_exp_3.at(2).toFloat()*ratio_import;      // *** X ***
                        tab_coo[i-2][1] = wl_exp_3.at(3).toFloat();      // *** Y ***
                        tab_coo[i-2][2] = wl_exp_3.at(4).toFloat();      // *** Z ***
                        tab_coo[i-2][3] = wl_exp_3.at(2).toFloat()*ratio_import;      // *** OLD POS X ***
                        tab_coo[i-2][4] = wl_exp_3.at(3).toFloat();      // *** OLD POS Y ***
                        tab_coo[i-2][5] = wl_exp_3.at(5).toFloat();      // *** ROTATE X ***
                        tab_coo[i-2][6] = wl_exp_3.at(6).toFloat();      // *** ROTATE Y ***
                        tab_coo[i-2][7] = wl_exp_3.at(7).toFloat();      // *** ROTATE Z ***
                        tab_coo[i-2][8] = wl_exp_3.at(8).toFloat();      // *** VISIBLE ***
                        tab_coo[i-2][9] = wl_exp_3.at(9).toFloat();      // *** TRANSPARENCE ***
                        tab_diapo[i-2][6] = wl_exp_3.at(0);              // *** REFLECT ***
                        tab_diapo[i-2][7] = "0/0/0/0";                   // *** CROP ***
                        tab_diapo[i-2][3] = wl_exp_3.at(12);              // *** MASK ***
                        tab_diapo[i-2][3].replace(QString("underscore"), QString("_"));

                        tab_coo_timeline[i-2][j] = wl_exp_2.at(j).mid(6,wl_exp_2.at(j).lastIndexOf( ":" )-6);

                        //qDebug() << i-1 << " <-> " << tab_coo[i+1][0] << " " << tab_coo[i+1][1] << " " << tab_coo[i+1][2] << " " << tab_coo[i+1][5] << " " << tab_coo[i+1][6] << " " << tab_coo[i+1][7];
                    }
                    else
                    {
                        tab_coo_timeline[i-2][j] = wl_exp_2.at(j);
                    }
            }

            wl_img_texture.load(qApp->applicationDirPath() + "/Bibliotheque/3d/" + nameth + "_" + QString::number(i-2) + ".png");
            //qDebug() << qApp->applicationDirPath() + "/Bibliotheque/3d/" + nameth + "_" + QString::number(i-2) + ".png";

            if ( wl_img_texture.width() > wl_img_texture.height() )
            {
                wl_img_texture = wl_img_texture.scaledToWidth(1024,Qt::SmoothTransformation);
            }
            else
            {
                wl_img_texture = wl_img_texture.scaledToHeight(1024,Qt::SmoothTransformation);
            }

            wl_puis_001 = wl_img_texture.copy ( 0, 0, 1024, 1024);
            wg_table_photo[i-2] = wl_puis_001;

            f = QGLWidget::convertToGLFormat( wl_puis_001 );

            glGenTextures (1,&texture_diapo[i-2]);
            glBindTexture (GL_TEXTURE_2D, texture_diapo[i-2]);

            glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
            glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);

            glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, f.width(), f.height(),
                          0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits());

            tab_diapo[i-2][0] = qApp->applicationDirPath() + "/Bibliotheque/3d/" + nameth + "_" + QString::number(i-2) + ".png";               // *** NOM DU FICHIER DIAPO ***
            tab_diapo[i-2][1] = QString::number(1024);
            tab_diapo[i-2][2] = QString::number(1024/(wl_img_texture.width()/wl_img_texture.height()));
            tab_diapo[i-2][4] = "0:0";
            tab_diapo[i-2][5] = wl_exp_3.at(1);                                             // *** SCALE ***
            tab_diapo[i-2][7] = "0/0/0/0";                                                  // *** CROP ***
            tab_diapo[i-2][8] = "0";                                                        // *** ORIENTATION EXIF ***

            nombre_diapos++;

            emit add_diapo();
        }
        num_select = 0;
        is_fog = 0;

        if ( wl_img_texture.load(qApp->applicationDirPath()+"/Bibliotheque/3d/" + nameth + ".jpg") == true )
        {
            if ( wl_img_texture.width() > wl_img_texture.height() )
            {
                wl_img_texture = wl_img_texture.scaledToWidth(1024,Qt::SmoothTransformation);
            }
            else
            {
                wl_img_texture = wl_img_texture.scaledToHeight(1024,Qt::SmoothTransformation);
            }

            QImage wl_puis_001(1024,1024,QImage::Format_ARGB32_Premultiplied);
            wl_puis_001 = wl_img_texture.copy ( 0, 0, 1024, 1024);

            QImage f = QGLWidget::convertToGLFormat( wl_puis_001 );

            glDeleteTextures (1,&texture_diapo[41]);
            glGenTextures (1,&texture_diapo[41]);
            glBindTexture (GL_TEXTURE_2D, texture_diapo[41]);

            glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
            glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);

            glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, f.width(), f.height(),
                          0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits());

            isback = 1;
            back_color = qApp->applicationDirPath()+"/Bibliotheque/3d/" + nameth + ".jpg";
            //updateGL();
        }
        else
        {
            isback = 0;
            back_color = "0:0:0";
        }

        //emit update_preview();
        emit move_start();
    }*/
}

void Tetrahedron::f_delete_image()
{
    int wl_int_001 = num_select;
    int wl_int_002 = 0;
    //qDebug() << num_select << " " << nombre_diapos;
    QImage wl_puis_001(1024,1024,QImage::Format_ARGB32_Premultiplied);
    QImage wl_img_texture;
    QImage f;
    QPainter p;
    QFont myfont;
    myfont.setPixelSize ( 400 );

    glDeleteTextures(1, &texture_diapo[num_select] );

    if ( tab_diapo[wl_int_001][0].mid(0,2) == "?6" )
    {
        wg_nb_cube = 0;
    }

    while ( wl_int_001 < nombre_diapos )
    {
        tab_diapo[wl_int_001][0] = tab_diapo[wl_int_001+1][0];
        tab_diapo[wl_int_001][1] = tab_diapo[wl_int_001+1][1];
        tab_diapo[wl_int_001][2] = tab_diapo[wl_int_001+1][2];
        tab_diapo[wl_int_001][3] = tab_diapo[wl_int_001+1][3];
        tab_diapo[wl_int_001][4] = tab_diapo[wl_int_001+1][4];
        tab_diapo[wl_int_001][5] = tab_diapo[wl_int_001+1][5];
        tab_diapo[wl_int_001][6] = tab_diapo[wl_int_001+1][6];
        tab_diapo[wl_int_001][7] = tab_diapo[wl_int_001+1][7];
        tab_diapo[wl_int_001][8] = tab_diapo[wl_int_001+1][8];

        tab_coo[wl_int_001][0] = tab_coo[wl_int_001+1][0];
        tab_coo[wl_int_001][1] = tab_coo[wl_int_001+1][1];
        tab_coo[wl_int_001][2] = tab_coo[wl_int_001+1][2];
        tab_coo[wl_int_001][3] = tab_coo[wl_int_001+1][3];
        tab_coo[wl_int_001][4] = tab_coo[wl_int_001+1][4];
        tab_coo[wl_int_001][5] = tab_coo[wl_int_001+1][5];
        tab_coo[wl_int_001][6] = tab_coo[wl_int_001+1][6];
        tab_coo[wl_int_001][7] = tab_coo[wl_int_001+1][7];
        tab_coo[wl_int_001][8] = tab_coo[wl_int_001+1][8];
        tab_coo[wl_int_001][9] = tab_coo[wl_int_001+1][9];
        tab_coo[wl_int_001][10] = tab_coo[wl_int_001+1][10];
        tab_coo[wl_int_001][11] = tab_coo[wl_int_001+1][11];

        tabgif[wl_int_001].setFileName(tabgif[wl_int_001+1].fileName());
        tabgif[wl_int_002+1].setCacheMode( QMovie::CacheAll );
        tabgif[wl_int_002+1].jumpToFrame( 0 );

        wl_int_002 = 0;
        while ( wl_int_002 < 20 )
        {
            tab_coo_timeline[wl_int_001][wl_int_002] = tab_coo_timeline[wl_int_001+1][wl_int_002];
            wl_int_002++;
        }

        //qDebug() << wl_int_001 << " " << tab_diapo[wl_int_001+1][3];

        if ( tab_diapo[wl_int_001+1][3] == "" )
        {
            if ( tab_diapo[wl_int_001+1][0] == "NULL" )
            {
                p.begin(&wl_puis_001);
                p.setBrush(QColor(50,50,50));
                p.setPen(QColor(20,20,20));
                p.drawRect(0,0,1024,1024);
                p.setFont(myfont);
                p.setPen(QColor(255,255,255));
                p.drawText(QRect(0,0,1024,1024), Qt::AlignCenter,QString::number(wl_int_001));
                p.end();

                f = QGLWidget::convertToGLFormat( wl_puis_001 );

                glDeleteTextures(1, &texture_diapo[wl_int_001] );
                glGenTextures (1,&texture_diapo[wl_int_001]);
                glBindTexture (GL_TEXTURE_2D, texture_diapo[wl_int_001]);

                glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
                glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);

                glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, f.width(), f.height(),
                              0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits());
            }
            else
            {
                if ( wl_img_texture.load(tab_diapo[wl_int_001+1][0]) == true )
                {
                    glDeleteTextures(1, &texture_diapo[wl_int_001] );
                    if ( wl_img_texture.width() > wl_img_texture.height() )
                    {
                        wl_img_texture = wl_img_texture.scaledToWidth(1024,Qt::SmoothTransformation);
                    }
                    else
                    {
                        wl_img_texture = wl_img_texture.scaledToHeight(1024,Qt::SmoothTransformation);
                    }
                    //p.begin(&wl_puis_001);
                    //p.drawImage(0,0,wl_img_texture,0,0,1024, 1024);
                    wl_puis_001 = wl_img_texture.copy ( 0, 0, 1024, 1024);
                    //p.end();
                    f = QGLWidget::convertToGLFormat( wl_puis_001 );
                    glGenTextures (1,&texture_diapo[wl_int_001]);
                    glBindTexture (GL_TEXTURE_2D, texture_diapo[wl_int_001]);
                    glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
                    glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
                    glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, f.width(), f.height(),
                                  0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits());
                }
                else
                {
                    qDebug() << "ERROR LOADING TEXTURE ON f_delete_image : " << tab_diapo[wl_int_001+1][0];
                }
            }
        }
        else
        {
                qDebug() << wl_int_001 << " " << tab_diapo[wl_int_001][3];
                f_load_mask(tab_diapo[wl_int_001][3], wl_int_001);
        }

        wl_int_001++;
    }

    emit s_delete_diapo(num_select);

    //texture_diapo[num_select+1] = texture_diapo[num_select];
    nombre_diapos--;
    num_select = 0;
    updateGL();
    emit update_preview();
    emit dia_select(num_select);
}

void Tetrahedron::f_load_mask(QString msk, int num)
{
    tab_diapo[num][3] = msk;
    glDeleteTextures(1, &texture_diapo[num] );

    QImage wl_puis_001(1024,1024,QImage::Format_ARGB32);
    QImage wl_img_texture(1024,1024,QImage::Format_ARGB32);
    QPixmap wl_pix_texture;
    QImage f;
    QPainter p;
    QFont myfont;
    QImage wl_over_mask;
    myfont.setPixelSize ( 400 );

    if ( tab_diapo[num][0] != "NULL"  )
    {
        wl_pix_texture.fill(QColor(0,0,0,0));
        if ( wl_pix_texture.load(tab_diapo[num][0]) == true )
        {
            if ( wl_pix_texture.width() > wl_pix_texture.height() )
            {
                wl_pix_texture = wl_pix_texture.scaledToWidth(1024,Qt::SmoothTransformation);
            }
            else
            {
                wl_pix_texture = wl_pix_texture.scaledToHeight(1024,Qt::SmoothTransformation);
            }

            if ( tab_diapo[num][3] != "" )
            {
                QImage wl_image_2(qApp->applicationDirPath()+"/Bibliotheque/Masks/"+tab_diapo[num][3]+".png");
                wl_image_2 = wl_image_2.scaled(wl_pix_texture.width(),wl_pix_texture.height());
                wl_image_2 = wl_image_2.convertToFormat ( QImage::Format_ARGB32, Qt::AutoColor ); //_Premultiplied

                wl_img_texture = wl_pix_texture.toImage();

                wg_img_smile_effect = wl_img_texture;

                QStringList wl_exp_001 = tab_diapo[num][4].split(":",QString::SkipEmptyParts);

                f_effect_run(wl_exp_001.at(0).toInt(),wl_exp_001.at(1).toInt());

                wl_img_texture = wg_img_smile_effect.convertToFormat ( QImage::Format_ARGB32, Qt::AutoColor ); //_Premultiplied;

                //wl_img_texture = wl_img_texture.convertToFormat ( QImage::Format_ARGB32, Qt::AutoColor ); //_Premultiplied

                QPainter g;

                QPainter::CompositionMode mode = (QPainter::CompositionMode)6;

                g.begin(&wl_img_texture);
                g.setCompositionMode ( mode );
                g.drawImage(QRect(0,0,-1,-1),wl_image_2);

                QString wl_str_001 = qApp->applicationDirPath() + "/Bibliotheque/Masks/2t_" + tab_diapo[num][3] + ".png";

                if ( wl_over_mask.load(wl_str_001) == true )
                {

                    wl_over_mask = wl_over_mask.scaled(wl_pix_texture.width(),wl_pix_texture.height());

                    wl_over_mask = f_mutation_overmask(wl_over_mask,"255%*255%*255%*255");

                    //wl_over_mask.invertPixels(QImage::InvertRgb);
                    wl_over_mask = wl_over_mask.convertToFormat ( QImage::Format_ARGB32, Qt::AutoColor ); //_Premultiplied
                    g.setCompositionMode ( (QPainter::CompositionMode)0 );

                    g.drawImage(QRect(0,0,-1,-1),wl_over_mask);
                }

                tab_diapo[num][3] = msk + "%*255%*255%*255%*255";

                g.end();
            }
            else
            {
                wl_img_texture = wl_pix_texture.toImage();

                wg_img_smile_effect = wl_img_texture;

                QStringList wl_exp_001 = tab_diapo[num][4].split(":",QString::SkipEmptyParts);

                f_effect_run(wl_exp_001.at(0).toInt(),wl_exp_001.at(1).toInt());

                wl_img_texture = wg_img_smile_effect.convertToFormat ( QImage::Format_ARGB32, Qt::AutoColor ); //_Premultiplied;

                //wl_img_texture = wl_pix_texture.toImage();
            }

            if ( tab_coo[num][10] > 0 )
            {
                wl_img_texture = blur_shadow(wl_img_texture, tab_coo[num][10]);
            }

            //p.begin(&wl_puis_001);
            //p.drawImage(0,0,wl_img_texture,0,0,1024, 1024);
            wl_puis_001 = wl_img_texture.copy ( 0, 0, 1024, 1024);
            wg_table_photo[num] = wl_puis_001;

            //wl_puis_001 = wl_puis_001.convertToFormat ( QImage::Format_ARGB32, Qt::AutoColor );
            //p.end();
            f = QGLWidget::convertToGLFormat( wl_puis_001 );
            glDeleteTextures (1,&texture_diapo[num]);
            glGenTextures (1,&texture_diapo[num]);
            glBindTexture (GL_TEXTURE_2D, texture_diapo[num]);
            glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
            glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
            glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, f.width(), f.height(),
                          0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits());
        }
        else
        {
            qDebug() << "ERROR LOADING TEXTURE ON f_load_diapo 3 : " << tab_diapo[num][0];
        }
    }
    else
    {
        wl_pix_texture.load(":/Interface/Interface/error.png");
        wl_pix_texture = wl_pix_texture.scaled(1024,1024);
        wl_pix_texture.fill(QColor(0,0,0,0));

        p.begin(&wl_pix_texture);
        p.setBrush(QColor(50,50,50));
        p.setPen(QColor(20,20,20));
        p.drawRect(0,0,1024,1024);
        p.setFont(myfont);
        p.setPen(QColor(255,255,255));
        p.drawText(QRect(0,0,1024,1024), Qt::AlignCenter,QString::number(num));
        p.end();

        if ( tab_diapo[num][3] != "" )
        {
            QImage wl_image_2(qApp->applicationDirPath()+"/Bibliotheque/Masks/"+tab_diapo[num][3]+".png");
            wl_image_2 = wl_image_2.scaled(wl_pix_texture.width(),wl_pix_texture.height());
            wl_image_2 = wl_image_2.convertToFormat ( QImage::Format_ARGB32, Qt::AutoColor ); //_Premultiplied

            wl_img_texture = wl_pix_texture.toImage();

            wl_img_texture = wl_img_texture.convertToFormat ( QImage::Format_ARGB32, Qt::AutoColor ); //_Premultiplied

            QPainter g;

            QPainter::CompositionMode mode = (QPainter::CompositionMode)6;

            g.begin(&wl_img_texture);
            g.setCompositionMode ( mode );
            g.drawImage(QRect(0,0,-1,-1),wl_image_2);

            QString wl_str_001 = qApp->applicationDirPath() + "/Bibliotheque/Masks/2t_" + tab_diapo[num][3] + ".png";

            if ( wl_over_mask.load(wl_str_001) == true )
            {
                wl_over_mask = wl_over_mask.scaled(wl_pix_texture.width(),wl_pix_texture.height());

                wl_over_mask = f_mutation_overmask(wl_over_mask,"255%*255%*255%*255");

                wl_over_mask = wl_over_mask.convertToFormat ( QImage::Format_ARGB32, Qt::AutoColor ); //_Premultiplied
                g.setCompositionMode ( (QPainter::CompositionMode)0 );
                g.drawImage(QRect(0,0,-1,-1),wl_over_mask);
            }
            /*else
            {
                wl_img_texture = wl_pix_texture.toImage();
            }*/

            g.end();

            tab_diapo[num][3] = msk + "%*255%*255%*255%*255";
        }

        f = QGLWidget::convertToGLFormat( wl_img_texture );

        glDeleteTextures(1, &texture_diapo[num] );
        glGenTextures (1,&texture_diapo[num]);
        glBindTexture (GL_TEXTURE_2D, texture_diapo[num]);

        glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
        glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);

        glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, f.width(), f.height(),
                      0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits());
    }
    updateGL();
}

QImage Tetrahedron::f_mutation_overmask(QImage wl_msk, QString wl_msk_over)
{
        // *** MUTATION DES COULEURS OVER MASK ***

        if ( wl_msk_over != "" )
        {
                QStringList wl_explode = wl_msk_over.split("%*",QString::KeepEmptyParts);
                int lumi = 0;
                int cont = 0;
                int rouge = wl_explode.at(0).toInt();
                int vert = wl_explode.at(1).toInt();
                int bleu = wl_explode.at(2).toInt();
                int valueadd_R = 0;
                int valueadd_V = 0;
                int valueadd_B = 0;
                int opacity = wl_explode.at(3).toInt();
                QRgb srcPixel;
                QColor trtcolor;
                int c_r = 0;
                int c_v = 0;
                int c_b = 0;
                int ac_r = 0;
                int ac_v = 0;
                int ac_b = 0;
                //
                for (int y = 0; y < wl_msk.height(); y++)
                {
                        for (int x = 0; x < wl_msk.width(); x++)
                        {
                                srcPixel = wl_msk.pixel(x, y);
                                trtcolor = srcPixel;
                                //
                                if (qAlpha(srcPixel) > 1 )
                                {
                                        if ( cont < 0 )
                                        {
                                                ac_r = ( (float)((float)(c_r - trtcolor.red() ) / 100) * -cont);
                                                ac_v = ( (float)((float)(c_v - trtcolor.green() ) / 100) * -cont);
                                                ac_b = ( (float)((float)(c_b - trtcolor.blue() ) / 100) * -cont);
                                        }
                                        else
                                        {
                                                if ( cont > 0 )
                                                {
                                                        if ( trtcolor.red() < c_r )
                                                        {
                                                                ac_r = ( (float)((float)(0 - trtcolor.red() ) / 100) * -cont);
                                                        }
                                                        else
                                                        {
                                                                ac_r = ( (float)((float)(0 - (((trtcolor.red() + trtcolor.green() + trtcolor.blue())/3)) ) / 100) * -cont);
                                                        }

                                                        if ( trtcolor.green() < c_v )
                                                        {
                                                                ac_v = ( (float)((float)(0 - trtcolor.green() ) / 100) * -cont);
                                                        }
                                                        else
                                                        {
                                                                ac_v = ( (float)((float)(0 - (((trtcolor.red() + trtcolor.green() + trtcolor.blue())/3)) ) / 100) * -cont);
                                                        }

                                                        if ( trtcolor.blue() < c_b )
                                                        {
                                                                ac_b = ( (float)((float)(0 - trtcolor.blue() ) / 100) * -cont);
                                                        }
                                                        else
                                                        {
                                                                ac_b = ( (float)((float)(0 - (((trtcolor.red() + trtcolor.green() + trtcolor.blue())/3)) ) / 100) * -cont);
                                                        }
                                                }
                                                else
                                                {
                                                        ac_r = 0;
                                                        ac_v = 0;
                                                        ac_b = 0;
                                                }
                                        }

                                        //
                                        valueadd_R = lumi + rouge + ac_r;
                                        valueadd_V = lumi + vert + ac_v;
                                        valueadd_B = lumi + bleu + ac_b;
                                        //

                                        if ( valueadd_R > 0 )
                                        {
                                                if ( trtcolor.red() < 255 - valueadd_R)
                                                {
                                                        trtcolor.setRed(trtcolor.red() + valueadd_R);
                                                }
                                                else
                                                {
                                                        trtcolor.setRed(255);
                                                }
                                        }
                                        else
                                        {
                                                if ( trtcolor.red() > (valueadd_R*-1))
                                                {
                                                        trtcolor.setRed(trtcolor.red() + valueadd_R);
                                                }
                                                else
                                                {
                                                        trtcolor.setRed(0);
                                                }
                                        }

                                        if ( valueadd_V > 0 )
                                        {
                                                if ( trtcolor.green() < 255 - valueadd_V)
                                                {
                                                        trtcolor.setGreen(trtcolor.green() + valueadd_V);
                                                }
                                                else
                                                {
                                                        trtcolor.setGreen(255);
                                                }
                                        }
                                        else
                                        {
                                                if ( trtcolor.green() > (valueadd_V*-1))
                                                {
                                                        trtcolor.setGreen(trtcolor.green() + valueadd_V);
                                                }
                                                else
                                                {
                                                        trtcolor.setGreen(0);
                                                }
                                        }

                                        if ( valueadd_B > 0 )
                                        {
                                                if ( trtcolor.blue() < 255 - valueadd_B)
                                                {
                                                        trtcolor.setBlue(trtcolor.blue() + valueadd_B);
                                                }
                                                else
                                                {
                                                        trtcolor.setBlue(255);
                                                }
                                        }
                                        else
                                        {
                                                if ( trtcolor.blue() > (valueadd_B*-1))
                                                {
                                                        trtcolor.setBlue(trtcolor.blue() + valueadd_B);
                                                }
                                                else
                                                {
                                                        trtcolor.setBlue(0);
                                                }
                                        }
                                        //
                                        trtcolor.setAlpha(opacity);
                                        wl_msk.setPixel(x, y, trtcolor.rgba());
                                }
                                else
                                {
                                        trtcolor.setAlpha(0);
                                        wl_msk.setPixel(x, y, trtcolor.rgba());
                                }
                        }
                }
        }
        //
        return wl_msk;
}

/*void Tetrahedron::f_effect_run(int luma, int contraste)
{
        int cont =  contraste;
        int lumi = luma;

        QColor trtcolor;
        trtcolor.setRed(0);
        trtcolor.setGreen(0);
        trtcolor.setBlue(0);
        trtcolor.setAlpha(0);

        int rouge = 0;
        int vert = 0;
        int bleu = 0;
        int valueadd_R = 0;
        int valueadd_V = 0;
        int valueadd_B = 0;

        QRgb srcPixel;
        int c_r = 0;
        int c_v = 0;
        int c_b = 0;
        int ac_r;
        int ac_v;
        int ac_b;
        //int opacity;

        wg_img_smile_effect = wg_img_smile_effect.convertToFormat(QImage::Format_ARGB32_Premultiplied, Qt::AutoColor);

        for (int y = 0; y < wg_img_smile_effect.height(); y++)
        {
                for (int x = 0; x < wg_img_smile_effect.width(); x++)
                {
                        srcPixel = wg_img_smile_effect.pixel(x, y);
                        trtcolor = srcPixel;
                        c_r = c_r + trtcolor.red();
                        c_v = c_v + trtcolor.green();
                        c_b = c_b + trtcolor.blue();
                }
        }
        c_r = c_r / (wg_img_smile_effect.height()*wg_img_smile_effect.width());
        c_v = c_v / (wg_img_smile_effect.height()*wg_img_smile_effect.width());
        c_b = c_b / (wg_img_smile_effect.height()*wg_img_smile_effect.width());

        for (int y = 0; y < wg_img_smile_effect.height(); y++)
        {
                for (int x = 0; x < wg_img_smile_effect.width(); x++)
                {
                        srcPixel = wg_img_smile_effect.pixel(x, y);
                        trtcolor = srcPixel;
                        //
                        if (qAlpha(srcPixel) > 10 )
                        {
                                if ( cont < 0 )
                                {
                                        ac_r = ( (float)((float)(c_r - trtcolor.red() ) / 100) * -cont);
                                        ac_v = ( (float)((float)(c_v - trtcolor.green() ) / 100) * -cont);
                                        ac_b = ( (float)((float)(c_b - trtcolor.blue() ) / 100) * -cont);
                                }
                                else
                                {
                                        if ( cont > 0 )
                                        {
                                                if ( trtcolor.red() < c_r )
                                                {
                                                        ac_r = ( (float)((float)(0 - trtcolor.red() ) / 100) * -cont);
                                                }
                                                else
                                                {
                                                        ac_r = ( (float)((float)(0 - (((trtcolor.red() + trtcolor.green() + trtcolor.blue())/3)) ) / 100) * -cont);
                                                }

                                                if ( trtcolor.green() < c_v )
                                                {
                                                        ac_v = ( (float)((float)(0 - trtcolor.green() ) / 100) * -cont);
                                                }
                                                else
                                                {
                                                        ac_v = ( (float)((float)(0 - (((trtcolor.red() + trtcolor.green() + trtcolor.blue())/3)) ) / 100) * -cont);
                                                }

                                                if ( trtcolor.blue() < c_b )
                                                {
                                                        ac_b = ( (float)((float)(0 - trtcolor.blue() ) / 100) * -cont);
                                                }
                                                else
                                                {
                                                        ac_b = ( (float)((float)(0 - (((trtcolor.red() + trtcolor.green() + trtcolor.blue())/3)) ) / 100) * -cont);
                                                }
                                        }
                                        else
                                        {
                                                ac_r = 0;
                                                ac_v = 0;
                                                ac_b = 0;
                                        }
                                }

                                //
                                valueadd_R = lumi + rouge + ac_r;
                                valueadd_V = lumi + vert + ac_v;
                                valueadd_B = lumi + bleu + ac_b;
                                //

                                if ( valueadd_R > 0 )
                                {
                                        if ( trtcolor.red() < 255 - valueadd_R)
                                        {
                                                trtcolor.setRed(trtcolor.red() + valueadd_R);
                                        }
                                        else
                                        {
                                                trtcolor.setRed(255);
                                        }
                                }
                                else
                                {
                                        if ( trtcolor.red() > (valueadd_R*-1))
                                        {
                                                trtcolor.setRed(trtcolor.red() + valueadd_R);
                                        }
                                        else
                                        {
                                                trtcolor.setRed(0);
                                        }
                                }

                                if ( valueadd_V > 0 )
                                {
                                        if ( trtcolor.green() < 255 - valueadd_V)
                                        {
                                                trtcolor.setGreen(trtcolor.green() + valueadd_V);
                                        }
                                        else
                                        {
                                                trtcolor.setGreen(255);
                                        }
                                }
                                else
                                {
                                        if ( trtcolor.green() > (valueadd_V*-1))
                                        {
                                                trtcolor.setGreen(trtcolor.green() + valueadd_V);
                                        }
                                        else
                                        {
                                                trtcolor.setGreen(0);
                                        }
                                }

                                if ( valueadd_B > 0 )
                                {
                                        if ( trtcolor.blue() < 255 - valueadd_B)
                                        {
                                                trtcolor.setBlue(trtcolor.blue() + valueadd_B);
                                        }
                                        else
                                        {
                                                trtcolor.setBlue(255);
                                        }
                                }
                                else
                                {
                                        if ( trtcolor.blue() > (valueadd_B*-1))
                                        {
                                                trtcolor.setBlue(trtcolor.blue() + valueadd_B);
                                        }
                                        else
                                        {
                                                trtcolor.setBlue(0);
                                        }
                                }
                                //

                                trtcolor.setAlpha(255); //opacity);
                                wg_img_smile_effect.setPixel(x, y, trtcolor.rgba());
                        }
                }
        }
        //emit myfin();
        //exec();
}*/

void Tetrahedron::f_check_motion_blur(int value)
{
    is_mblur = value;
    updateGL();
}

void Tetrahedron::f_check_fog(int value)
{
    if ( value > 0 )
    {
        GLfloat fogColor[4] = {(float)fog_red/(float)255, (float)fog_green/(float)255, (float)fog_blue/(float)255, 0.8};

        glEnable (GL_FOG);
        glFogi (GL_FOG_MODE,  GL_LINEAR);
        glFogfv (GL_FOG_COLOR, fogColor);
        glFogf (GL_FOG_DENSITY, 0.2f);
        glHint (GL_FOG_HINT, GL_NICEST);
        glFogf(GL_FOG_START, 5.0f);
        glFogf(GL_FOG_END, 12.0f);

        is_fog = value;

        updateGL();
    }
    else
    {
        glDisable (GL_FOG);

        is_fog = value;

        updateGL();
    }
}

void Tetrahedron::f_check_anaglyph(int value)
{
    is_anaglyph = value;
    updateGL();
}

void Tetrahedron::f_combo_od_changed(int valpos)
{
    if ( valpos == 0 )
    {
        od_red = true;
        od_green = false;
        od_blue = false;

        updateGL();
        return;
    }

    if ( valpos == 1 )
    {
        od_red = false;
        od_green = true;
        od_blue = false;

        updateGL();
        return;
    }

    if ( valpos == 2 )
    {
        od_red = false;
        od_green = false;
        od_blue = true;

        updateGL();
        return;
    }

    if ( valpos == 3 )
    {
        od_red = true;
        od_green = false;
        od_blue = true;

        updateGL();
        return;
    }

    if ( valpos == 4 )
    {
        od_red = false;
        od_green = true;
        od_blue = true;

        updateGL();
        return;
    }
}

void Tetrahedron::f_combo_og_changed(int valpos)
{
    if ( valpos == 0 )
    {
        og_red = true;
        og_green = false;
        og_blue = false;

        updateGL();
        return;
    }

    if ( valpos == 1 )
    {
        og_red = false;
        og_green = true;
        og_blue = false;

        updateGL();
        return;
    }

    if ( valpos == 2 )
    {
        og_red = false;
        og_green = false;
        og_blue = true;

        updateGL();
        return;
    }

    if ( valpos == 3 )
    {
        og_red = true;
        og_green = false;
        og_blue = true;

        updateGL();
        return;
    }

    if ( valpos == 4 )
    {
        og_red = false;
        og_green = true;
        og_blue = true;

        updateGL();
        return;
    }
}

void Tetrahedron::f_sl_esp_ana(int valesp)
{
    wg_esp_ana = valesp;
    updateGL();
}

void Tetrahedron::f_sl_sca_diapo(int valsca)
{
    if ( num_select > 0 )
    {
        scale_factor = (float)valsca/(float)100;
        tab_diapo[num_select][5] = QString::number(scale_factor);
        updateGL();
    }
}

void Tetrahedron::f_mark_del(int pos)
{
    if ( num_select > 0 )
    {
        int j = 0;
        int ok = 0;
        QStringList wl_exp;

        while ( j < 20 && tab_coo_timeline[num_select][j] != "" && ok == 0 )
        {
            wl_exp = tab_coo_timeline[num_select][j].split(":",QString::SkipEmptyParts);
            if ( wl_exp.at(0).toInt() == pos )
            {
                ok = 1;
            }
            else
            {
                j++;
            }
        }

        if ( ok == 1 )
        {
            while ( tab_coo_timeline[num_select][j] != "" && j < 20 )
            {
                tab_coo_timeline[num_select][j] = tab_coo_timeline[num_select][j+1];
                j++;
            }
            f_apply_mask(num_select, 0);
            f_follow_timeline(position_timeline);
        }
        else
        {
            qDebug() << "ERROR DELETING KEYFRAME - NO MATCHING POINT FOUND";
        }

    }
}

void Tetrahedron::f_put_reflect(int state)
{
    tab_diapo[num_select][6] = QString::number(state);
    updateGL();
}

void Tetrahedron::f_netbuf()
{
    // *** NETTOYAGE DE L'ACCUM BUFFER ***
    bcle_render = 1;
    glClearAccum(0.0, 0.0, 0.0, 1.0);
    glClear(GL_DEPTH_BUFFER_BIT);
    updateGL();
}

void Tetrahedron::keyPressEvent( QKeyEvent *k )
{
    if ( k->key() == Qt::Key_X )
    {
        wg_has_mx = 1;
        wg_has_my = 0;
    }

    if ( k->key() == Qt::Key_Y )
    {
        wg_has_mx = 0;
        wg_has_my = 1;
    }

    if ( k->key() == Qt::Key_Delete && num_select > 0 )
    {
        f_delete_image();
    }
}

void Tetrahedron::f_reload_img(int numtex)
{
    if ( tab_diapo[numtex][0] == "NULL" || ( tab_diapo[numtex][0].mid(0,1) == "?" && tab_diapo[numtex][0].mid(0,2) != "?9") )
    {
        if ( tab_diapo[numtex][0] == "NULL" )
        {
            QImage wl_puis_001(1024,1024,QImage::Format_ARGB32);
            QFont myfont;
            myfont.setPixelSize ( 400 );

            QPainter p;

            p.begin(&wl_puis_001);
            p.setBrush(QColor(50,50,50));
            p.setPen(QColor(20,20,20));
            p.drawRect(0,0,1024,1024);
            p.setFont(myfont);
            p.setPen(QColor(255,255,255));
            p.drawText(QRect(0,0,1024,1024), Qt::AlignCenter,QString::number(numtex));
            p.end();

            QStringList wg_str_001;

            //QPixmap wl_pix_texture;
            //wl_pix_texture.fill(QColor(0,0,0,0));

            // *** CHARGEMENT DE LA TEXTURE ***

            glDeleteTextures(1, &texture_diapo[numtex] );
            //QImage wl_puis_001(1024,1024,QImage::Format_ARGB32); //_Premultiplied

            QImage wl_img_texture = wl_puis_001;

            if ( tab_diapo[numtex][7] != "0/0/0/0" )
            {
                wg_str_001 = tab_diapo[numtex][7].split("/",QString::KeepEmptyParts);

                wl_img_texture = wl_img_texture.copy(wg_str_001.at(0).toFloat(),wg_str_001.at(1).toFloat(),wg_str_001.at(2).toFloat()-wg_str_001.at(0).toFloat(),wg_str_001.at(3).toFloat()-wg_str_001.at(1).toFloat());
            }

            //qDebug() << wg_str_001.at(0).toFloat() << " " << wg_str_001.at(1).toFloat() << " " << wg_str_001.at(2).toFloat() << " " << wg_str_001.at(3);

            if ( wl_img_texture.width() > wl_img_texture.height() )
            {
                wl_img_texture = wl_img_texture.scaledToWidth(1024,Qt::SmoothTransformation);
            }
            else
            {
                wl_img_texture = wl_img_texture.scaledToHeight(1024,Qt::SmoothTransformation);
            }

            wl_img_texture = wl_img_texture.convertToFormat ( QImage::Format_ARGB32, Qt::AutoColor );

            wg_str_001 = tab_diapo[numtex][4].split(":",QString::SkipEmptyParts);

            if ( wg_str_001.at(0).toInt() != 0 || wg_str_001.at(1).toInt() != 0 )
            {
                wg_img_smile_effect = wl_img_texture;
                f_effect_run(wg_str_001.at(0).toInt(), wg_str_001.at(1).toInt());
                wl_img_texture = wg_img_smile_effect;
            }

            if ( tab_diapo[numtex][3] != "" )
            {
                QStringList wl_explode = tab_diapo[numtex][3].split("%*",QString::KeepEmptyParts);

                QImage wl_image_2(qApp->applicationDirPath()+"/Bibliotheque/Masks/"+wl_explode.at(0)+".png");

                wl_image_2 = wl_image_2.scaled(1024, 1024);
                wl_image_2 = wl_image_2.convertToFormat ( QImage::Format_ARGB32, Qt::AutoColor ); //_Premultiplied

                QPainter g;

                QPainter::CompositionMode mode = (QPainter::CompositionMode)6;

                g.begin(&wl_img_texture);
                g.setCompositionMode ( mode );
                g.drawImage(QRect(0,0,-1,-1),wl_image_2);

                QString wl_str_001 = qApp->applicationDirPath() + "/Bibliotheque/Masks/2t_" + wl_explode.at(0) + ".png";
                QImage wl_over_mask;

                if ( wl_over_mask.load(wl_str_001) == true )
                {
                    wl_over_mask = wl_over_mask.scaled(1024, 1024);

                    wl_over_mask = f_mutation_overmask( wl_over_mask, wl_explode.at(1) + "%*" + wl_explode.at(2) + "%*" + wl_explode.at(3) + "%*" + wl_explode.at(4) );

                    wl_over_mask = wl_over_mask.convertToFormat ( QImage::Format_ARGB32, Qt::AutoColor ); //_Premultiplied
                    g.setCompositionMode ( (QPainter::CompositionMode)0 );

                    g.drawImage(QRect(0,0,-1,-1),wl_over_mask);
                }

                g.end();
            }

            if ( tab_coo[numtex][10] > 0 )
            {
                wl_img_texture = blur_shadow(wl_img_texture, tab_coo[numtex][10]);
            }

            wg_table_photo[numtex] = wl_img_texture;
            wl_puis_001 = wl_img_texture.copy ( 0, 0, 1024, 1024);

            QImage f = QGLWidget::convertToGLFormat( wl_puis_001 );

            glDeleteTextures (1,&texture_diapo[numtex]);

            glGenTextures (1,&texture_diapo[numtex]);
            glBindTexture (GL_TEXTURE_2D, texture_diapo[numtex]);

            glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
            glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);

            glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, f.width(), f.height(),
                          0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits());

        }
        return;
    }
    else
    {
        //qDebug() << tab_diapo[numtex][0];
        if ( tab_diapo[numtex][0].mid(0,2) == "?9" )
        {
            int oldnum = num_select;
            num_select = numtex;
            f_reload_text();
            num_select = oldnum;

            return;
        }
    }

    QImage wl_img_texture(1024,1024,QImage::Format_ARGB32);
    QStringList wg_str_001;

    QPixmap wl_pix_texture;
    wl_pix_texture.fill(QColor(0,0,0,0));

    if ( wl_pix_texture.load(tab_diapo[numtex][0]) == true )
    {
        // *** CHARGEMENT DE LA TEXTURE ***

        glDeleteTextures(1, &texture_diapo[numtex] );
        QImage wl_puis_001(1024,1024,QImage::Format_ARGB32); //_Premultiplied

        wl_img_texture = wl_pix_texture.toImage();

        if ( tab_diapo[numtex][7] != "0/0/0/0" )
        {
            wg_str_001 = tab_diapo[numtex][7].split("/",QString::KeepEmptyParts);
            
            wl_img_texture = wl_img_texture.copy(wg_str_001.at(0).toFloat(),wg_str_001.at(1).toFloat(),wg_str_001.at(2).toFloat()-wg_str_001.at(0).toFloat(),wg_str_001.at(3).toFloat()-wg_str_001.at(1).toFloat());
        }

        //qDebug() << wg_str_001.at(0).toFloat() << " " << wg_str_001.at(1).toFloat() << " " << wg_str_001.at(2).toFloat() << " " << wg_str_001.at(3);

        if ( wl_img_texture.width() > wl_img_texture.height() )
        {
            wl_img_texture = wl_img_texture.scaledToWidth(1024,Qt::SmoothTransformation);
        }
        else
        {
            wl_img_texture = wl_img_texture.scaledToHeight(1024,Qt::SmoothTransformation);
        }

        wl_img_texture = wl_img_texture.convertToFormat ( QImage::Format_ARGB32, Qt::AutoColor );

        wg_str_001 = tab_diapo[numtex][4].split(":",QString::SkipEmptyParts);

        if ( wg_str_001.at(0).toInt() != 0 || wg_str_001.at(1).toInt() != 0 )
        {
            wg_img_smile_effect = wl_img_texture;
            f_effect_run(wg_str_001.at(0).toInt(), wg_str_001.at(1).toInt());
            wl_img_texture = wg_img_smile_effect;
        }

        if ( tab_diapo[numtex][3] != "" )
        {
            QStringList wl_explode = tab_diapo[numtex][3].split("%*",QString::KeepEmptyParts);

            QImage wl_image_2(qApp->applicationDirPath()+"/Bibliotheque/Masks/"+wl_explode.at(0)+".png");

            wl_image_2 = wl_image_2.scaled(wl_img_texture.width(), wl_img_texture.height());
            wl_image_2 = wl_image_2.convertToFormat ( QImage::Format_ARGB32, Qt::AutoColor ); //_Premultiplied

            QPainter g;

            QPainter::CompositionMode mode = (QPainter::CompositionMode)6;

            g.begin(&wl_img_texture);
            g.setCompositionMode ( mode );
            g.drawImage(QRect(0,0,-1,-1),wl_image_2);

            QString wl_str_001 = qApp->applicationDirPath() + "/Bibliotheque/Masks/2t_" + wl_explode.at(0) + ".png";
            QImage wl_over_mask;

            if ( wl_over_mask.load(wl_str_001) == true )
            {
                wl_over_mask = wl_over_mask.scaled(wl_img_texture.width(), wl_img_texture.height());

                wl_over_mask = f_mutation_overmask( wl_over_mask, wl_explode.at(1) + "%*" + wl_explode.at(2) + "%*" + wl_explode.at(3) + "%*" + wl_explode.at(4) );

                wl_over_mask = wl_over_mask.convertToFormat ( QImage::Format_ARGB32, Qt::AutoColor ); //_Premultiplied
                g.setCompositionMode ( (QPainter::CompositionMode)0 );

                g.drawImage(QRect(0,0,-1,-1),wl_over_mask);
            }

            g.end();
        }

        if ( tab_coo[numtex][10] > 0 )
        {
            wl_img_texture = blur_shadow(wl_img_texture, tab_coo[numtex][10]);
        }

        wg_table_photo[numtex] = wl_img_texture;
        wl_puis_001 = wl_img_texture.copy ( 0, 0, 1024, 1024);

        QImage f = QGLWidget::convertToGLFormat( wl_puis_001 );

        glDeleteTextures (1,&texture_diapo[numtex]);

        glGenTextures (1,&texture_diapo[numtex]);
        glBindTexture (GL_TEXTURE_2D, texture_diapo[numtex]);

        glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
        glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);

        glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, f.width(), f.height(),
                      0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits());
    }
    else
    {
        qDebug() << "ERROR RELOAD IMAGE SPECIAL ACTION BLUR : " << tab_diapo[numtex][0];
    }
    //updateGL();
}

void Tetrahedron::f_effect_run(int lumi, int cont)
{
        QColor trtcolor;
        trtcolor.setRed(0);
        trtcolor.setGreen(0);
        trtcolor.setBlue(0);
        trtcolor.setAlpha(0);

        int rouge = 0;
        int vert = 0;
        int bleu = 0;
        int valueadd_R = 0;
        int valueadd_V = 0;
        int valueadd_B = 0;

        QRgb srcPixel;
        int c_r = 0;
        int c_v = 0;
        int c_b = 0;
        int ac_r;
        int ac_v;
        int ac_b;

        wg_img_smile_effect = wg_img_smile_effect.convertToFormat(QImage::Format_ARGB32_Premultiplied, Qt::AutoColor);

        for (int y = 0; y < wg_img_smile_effect.height(); y++)
        {
                for (int x = 0; x < wg_img_smile_effect.width(); x++)
                {
                        srcPixel = wg_img_smile_effect.pixel(x, y);
                        trtcolor = srcPixel;
                        c_r = c_r + trtcolor.red();
                        c_v = c_v + trtcolor.green();
                        c_b = c_b + trtcolor.blue();
                }
        }

        int wl_surf = wg_img_smile_effect.height()*wg_img_smile_effect.width();

        c_r = c_r / wl_surf;
        c_v = c_v / wl_surf;
        c_b = c_b / wl_surf;

        for (int y = 0; y < wg_img_smile_effect.height(); y++)
        {
                for (int x = 0; x < wg_img_smile_effect.width(); x++)
                {
                        srcPixel = wg_img_smile_effect.pixel(x, y);
                        trtcolor = srcPixel;
                        //
                        if (qAlpha(srcPixel) > 10 )
                        {
                                if ( cont < 0 )
                                {
                                        ac_r = ( (float)((float)(c_r - trtcolor.red() ) / 100) * -cont);
                                        ac_v = ( (float)((float)(c_v - trtcolor.green() ) / 100) * -cont);
                                        ac_b = ( (float)((float)(c_b - trtcolor.blue() ) / 100) * -cont);
                                }
                                else
                                {
                                        if ( cont > 0 )
                                        {
                                                if ( trtcolor.red() < c_r )
                                                {
                                                        ac_r = ( (float)((float)(0 - trtcolor.red() ) / 100) * -cont);
                                                }
                                                else
                                                {
                                                        ac_r = ( (float)((float)(0 - (((trtcolor.red() + trtcolor.green() + trtcolor.blue())/3)) ) / 100) * -cont);
                                                }

                                                if ( trtcolor.green() < c_v )
                                                {
                                                        ac_v = ( (float)((float)(0 - trtcolor.green() ) / 100) * -cont);
                                                }
                                                else
                                                {
                                                        ac_v = ( (float)((float)(0 - (((trtcolor.red() + trtcolor.green() + trtcolor.blue())/3)) ) / 100) * -cont);
                                                }

                                                if ( trtcolor.blue() < c_b )
                                                {
                                                        ac_b = ( (float)((float)(0 - trtcolor.blue() ) / 100) * -cont);
                                                }
                                                else
                                                {
                                                        ac_b = ( (float)((float)(0 - (((trtcolor.red() + trtcolor.green() + trtcolor.blue())/3)) ) / 100) * -cont);
                                                }
                                        }
                                        else
                                        {
                                                ac_r = 0;
                                                ac_v = 0;
                                                ac_b = 0;
                                        }
                                }

                                //
                                valueadd_R = lumi + rouge + ac_r;
                                valueadd_V = lumi + vert + ac_v;
                                valueadd_B = lumi + bleu + ac_b;
                                //

                                if ( valueadd_R > 0 )
                                {
                                        if ( trtcolor.red() < 255 - valueadd_R)
                                        {
                                                trtcolor.setRed(trtcolor.red() + valueadd_R);
                                        }
                                        else
                                        {
                                                trtcolor.setRed(255);
                                        }
                                }
                                else
                                {
                                        if ( trtcolor.red() > (valueadd_R*-1))
                                        {
                                                trtcolor.setRed(trtcolor.red() + valueadd_R);
                                        }
                                        else
                                        {
                                                trtcolor.setRed(0);
                                        }
                                }

                                if ( valueadd_V > 0 )
                                {
                                        if ( trtcolor.green() < 255 - valueadd_V)
                                        {
                                                trtcolor.setGreen(trtcolor.green() + valueadd_V);
                                        }
                                        else
                                        {
                                                trtcolor.setGreen(255);
                                        }
                                }
                                else
                                {
                                        if ( trtcolor.green() > (valueadd_V*-1))
                                        {
                                                trtcolor.setGreen(trtcolor.green() + valueadd_V);
                                        }
                                        else
                                        {
                                                trtcolor.setGreen(0);
                                        }
                                }

                                if ( valueadd_B > 0 )
                                {
                                        if ( trtcolor.blue() < 255 - valueadd_B)
                                        {
                                                trtcolor.setBlue(trtcolor.blue() + valueadd_B);
                                        }
                                        else
                                        {
                                                trtcolor.setBlue(255);
                                        }
                                }
                                else
                                {
                                        if ( trtcolor.blue() > (valueadd_B*-1))
                                        {
                                                trtcolor.setBlue(trtcolor.blue() + valueadd_B);
                                        }
                                        else
                                        {
                                                trtcolor.setBlue(0);
                                        }
                                }

                                trtcolor.setAlpha(255); //opacity);
                                wg_img_smile_effect.setPixel(x, y, trtcolor.rgba());
                        }
                }
        }
}

// **********************************
// *** AJOUTER LE MEDIA AU PROJET ***
// **********************************
void Tetrahedron::dragEnterEvent(QDragEnterEvent *event)
{
        event->acceptProposedAction();
}

void Tetrahedron::dropEvent(QDropEvent *event)
{
        QList<QUrl> myurl = event->mimeData()->urls();
        QString wl_str_001;
        QStringList wl_mylist;
        int wl_int_001 = 0;
        int wl_int_002 = 0;

        while ( wl_int_001 < myurl.count() )
        {
            wl_str_001 = myurl[wl_int_001].toString(QUrl::None);
            if ( wl_str_001.mid(0,6) == "file:/" )
            {
                wl_mylist.append(wl_str_001.mid(7,wl_str_001.length()-7));
                wl_int_002++;
            }
            else
            {
                if ( wl_str_001.mid(0,4) == "$ANI" )
                {
                    f_load_object_from_drop(wl_str_001.mid(4,wl_str_001.length()-4));
                }
            }
            wl_int_001++;
        }

        if ( wl_int_002 > 0 )
        {
            f_load_image_step_2(wl_mylist);
        }

        //emit drop_to_editor();
}

#ifndef BLUR_CPP
#define BLUR_CPP
  /*   Copyright 2007 Jani Huhtanen <jani.huhtanen@tut.fi>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License version 2 as
  *   published by the Free Software Foundation
  *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *   GNU General Public License for more details
  *
  *   You should have received a copy of the GNU Library General Public
  *   License along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */

// Exponential blur, Jani Huhtanen, 2006
//
template<int aprec, int zprec>
static inline void blurinner(unsigned char *bptr, int &zR, int &zG, int &zB, int &zA, int alpha);

template<int aprec,int zprec>
static inline void blurrow( QImage & im, int line, int alpha);

template<int aprec, int zprec>
static inline void blurcol( QImage & im, int col, int alpha);
/*
*  expblur(QImage &img, int radius)
*
*  In-place blur of image 'img' with kernel
*  of approximate radius 'radius'.
*
*  Blurs with two sided exponential impulse
*  response.
*
*  aprec = precision of alpha parameter
*  in fixed-point format 0.aprec
*
*  zprec = precision of state parameters
*  zR,zG,zB and zA in fp format 8.zprec
*/
template<int aprec,int zprec>
void expblur( QImage &img, int radius )
{
        int alpha = (int)((1<<aprec)*(1.0f-std::exp(-2.3f/(radius+1.f))));
        for(int row=0;row<img.height();row++)
        {
                blurrow<aprec,zprec>(img,row,alpha);
        }
        for(int col=0;col<img.width();col++)
        {
                blurcol<aprec,zprec>(img,col,alpha);
        }
        return;
}

template<int aprec, int zprec>
static inline void blurinner(unsigned char *bptr, int &zR, int &zG, int &zB, int &zA, int alpha)
{
        int R,G,B,A;
        R = *bptr;
        G = *(bptr+1);
        B = *(bptr+2);
        A = *(bptr+3);

        zR += (alpha * ((R<<zprec)-zR))>>aprec;
        zG += (alpha * ((G<<zprec)-zG))>>aprec;
        zB += (alpha * ((B<<zprec)-zB))>>aprec;
        zA += (alpha * ((A<<zprec)-zA))>>aprec;

        *bptr =     zR>>zprec;
        *(bptr+1) = zG>>zprec;
        *(bptr+2) = zB>>zprec;
        *(bptr+3) = zA>>zprec;
}

template<int aprec,int zprec>
static inline void blurrow( QImage & im, int line, int alpha)
{
        int zR,zG,zB,zA;

        QRgb *ptr = (QRgb *)im.scanLine(line);

        zR = *((unsigned char *)ptr    )<<zprec;
        zG = *((unsigned char *)ptr + 1)<<zprec;
        zB = *((unsigned char *)ptr + 2)<<zprec;
        zA = *((unsigned char *)ptr + 3)<<zprec;

        for(int index=1; index<im.width(); index++)
        {
                blurinner<aprec,zprec>((unsigned char *)&ptr[index],zR,zG,zB,zA,alpha);
        }
        for(int index=im.width()-2; index>=0; index--)
        {
                blurinner<aprec,zprec>((unsigned char *)&ptr[index],zR,zG,zB,zA,alpha);
        }
}

template<int aprec, int zprec>
static inline void blurcol( QImage & im, int col, int alpha)
{
        int zR,zG,zB,zA;

        QRgb *ptr = (QRgb *)im.bits();
        ptr+=col;

        zR = *((unsigned char *)ptr    )<<zprec;
        zG = *((unsigned char *)ptr + 1)<<zprec;
        zB = *((unsigned char *)ptr + 2)<<zprec;
        zA = *((unsigned char *)ptr + 3)<<zprec;

        for(int index=im.width(); index<(im.height()-1)*im.width(); index+=im.width())
        {
                blurinner<aprec,zprec>((unsigned char *)&ptr[index],zR,zG,zB,zA,alpha);
        }

        for(int index=(im.height()-2)*im.width(); index>=0; index-=im.width())
        {
                blurinner<aprec,zprec>((unsigned char *)&ptr[index],zR,zG,zB,zA,alpha);
        }

}

template<class T>
inline const T& qClamp(const T &x, const T &low, const T &high)
{
        if      (x <  low) return low;
        else if (x > high) return high;
        else               return x;
}
#endif

QImage Tetrahedron::blur_shadow(QImage wl_ims_1, int radius)
{
        expblur <8, 8>(wl_ims_1, radius);
        return wl_ims_1;
}
